table = {
    "_m": "im",
    "aa": "a",
    "aa": "ad",
    "aa": "an",
    "aaa": "aka",
    "aaked": "asked",
    "aal": "all",
    "aamerica": "america",
    "aan": "an",
    "aan": "can",
    "aand": "and",
    "aanyone": "anyone",
    "aap": "app",
    "aapps": "apps",
    "aar": "car",
    "aare": "are",
    "ab": "a",
    "ab": "am",
    "ab": "an",
    "ab": "as",
    "ab": "at",
    "ab": "tab",
    "abailable": "available",
    "abbout": "about",
    "abc": "bbc",
    "abd": "and",
    "abe": "are",
    "abel": "able",
    "abillity": "ability",
    "abilty": "ability",
    "abit": "bit",
    "abiut": "about",
    "abke": "able",
    "abl": "all",
    "ablet": "able",
    "ablle": "able",
    "ablt": "able",
    "abnd": "and",
    "abobe": "adobe",
    "aboit": "about",
    "aboiut": "about",
    "abole": "able",
    "aboot": "about",
    "aboout": "about",
    "abot": "about",
    "abotu": "about",
    "abour": "about",
    "abouta": "about",
    "abouth": "about",
    "abouti": "about",
    "aboutr": "about",
    "aboutt": "about",
    "abouy": "about",
    "abouyt": "about",
    "abowt": "about",
    "aboyt": "about",
    "abput": "about",
    "abs": "as",
    "absolutley": "absolutely",
    "absolutly": "absolutely",
    "abt": "at",
    "abut": "about",
    "abwt": "abt",
    "ac": "a",
    "ac": "ad",
    "ac": "am",
    "ac": "an",
    "ac": "ap",
    "ac": "as",
    "ac": "at",
    "ac": "mac",
    "acase": "case",
    "acc": "fcc",
    "acccess": "access",
    "acccount": "account",
    "acces": "access",
    "accesories": "accessories",
    "accesss": "access",
    "accidentaly": "accidentally",
    "accoding": "according",
    "accont": "account",
    "acconut": "account",
    "accordind": "according",
    "accordng": "according",
    "accoreding": "according",
    "accoriding": "according",
    "accoumt": "account",
    "accoungts": "accounts",
    "accouns": "account",
    "accountu": "account",
    "accout": "account",
    "accoutn": "account",
    "accouts": "accounts",
    "accouunt": "account",
    "accroding": "according",
    "accross": "across",
    "accsess": "access",
    "acctually": "actually",
    "accually": "actually",
    "acess": "access",
    "acessories": "accessories",
    "acheck": "check",
    "acking": "acting",
    "acl": "all",
    "acn": "an",
    "acnt": "acct",
    "acocunt": "account",
    "acommercial": "commercial",
    "acoording": "according",
    "acoount": "account",
    "acording": "according",
    "acount": "account",
    "acouple": "couple",
    "acp": "app",
    "acquistion": "acquisition",
    "acquistions": "acquisitions",
    "acreen": "screen",
    "acroos": "across",
    "acs": "as",
    "acsess": "access",
    "actally": "actually",
    "actaully": "actually",
    "actinn": "acting",
    "actinq": "acting",
    "activite": "activate",
    "activtedfor": "activatedfor",
    "actuall": "actual",
    "actuallly": "actually",
    "actualy": "actually",
    "actully": "actually",
    "acually": "actually",
    "acutally": "actually",
    "ada": "aja",
    "adaptor": "adapter",
    "adavance": "advance",
    "adc": "ad",
    "addcited": "addicted",
    "addedd": "added",
    "addeed": "added",
    "adderss": "address",
    "addiccted": "addicted",
    "addiciton": "addiction",
    "addictd": "addicted",
    "addictied": "addicted",
    "additcted": "addicted",
    "addn": "add",
    "addres": "address",
    "addreses": "address",
    "addtion": "addition",
    "addwords": "adwords",
    "addz": "adds",
    "ade": "are",
    "ade": "de",
    "aded": "added",
    "adesnse": "adsense",
    "adicted": "addicted",
    "adition": "addition",
    "adk": "ads",
    "adm": "ads",
    "admitt": "admit",
    "adn": "an",
    "adn": "and",
    "adoby": "adobe",
    "adp": "app",
    "adquisitions": "acquisitions",
    "adress": "address",
    "adroid": "android",
    "adrwords": "adwords",
    "adsence": "adsense",
    "adsende": "adsense",
    "adsene": "adsense",
    "adsm": "ads",
    "adswords": "adwords",
    "adticle": "article",
    "advailable": "available",
    "advanage": "advantage",
    "advantge": "advantage",
    "advertizing": "advertising",
    "advetising": "advertising",
    "advicea": "advice",
    "advisoy": "advisory",
    "advoid": "avoid",
    "adwards": "adwords",
    "adworks": "adwords",
    "adwrods": "adwords",
    "adz": "ads",
    "ae": "a",
    "ae": "are",
    "ae": "as",
    "ae": "me",
    "aer": "are",
    "aexcuse": "excuse",
    "af": "a",
    "af": "if",
    "afaid": "afraid",
    "afair": "affair",
    "afeected": "affected",
    "afer": "after",
    "affectd": "affected",
    "afffected": "affected",
    "affliate": "affiliate",
    "affraid": "afraid",
    "afganistan": "afghanistan",
    "afl": "all",
    "afn": "an",
    "aford": "afford",
    "afp": "app",
    "afraind": "afraid",
    "afriad": "afraid",
    "afrom": "from",
    "afternood": "afternoon",
    "aftet": "after",
    "afther": "after",
    "aftr": "after",
    "ag": "a",
    "againest": "against",
    "againist": "against",
    "againt": "against",
    "agaisnt": "against",
    "agao": "ago",
    "agh": "ugh",
    "agon": "ago",
    "agoogle": "google",
    "agp": "app",
    "agraid": "afraid",
    "agreat": "great",
    "agreee": "agree",
    "agter": "after",
    "ahad": "had",
    "ahaha": "haha",
    "ahave": "have",
    "ahaving": "having",
    "ahd": "and",
    "ahd": "had",
    "ahha": "haha",
    "ahm": "am",
    "ahold": "hold",
    "ahome": "home",
    "ahot": "shot",
    "ahould": "should",
    "ahs": "as",
    "ahs": "has",
    "aht": "at",
    "ahuge": "huge",
    "ahve": "have",
    "ahy": "why",
    "ai": "a",
    "ai": "ap",
    "ai": "as",
    "ai": "at",
    "ai": "i",
    "ai": "ui",
    "aidso": "aids",
    "aight": "eight",
    "aight": "right",
    "aii": "api",
    "ain": "an",
    "ain": "in",
    "aing": "aint",
    "ainvite": "invite",
    "aiont": "aint",
    "aip": "app",
    "aiphone": "iphone",
    "aiport": "airport",
    "airpot": "airport",
    "ais": "his",
    "ais": "is",
    "aith": "with",
    "aj": "a",
    "aj": "an",
    "ajah": "aja",
    "aje": "aja",
    "ak": "a",
    "ak": "an",
    "ak": "as",
    "ak": "uk",
    "akak": "aka",
    "ake": "make",
    "ake": "take",
    "aking": "making",
    "aking": "taking",
    "akka": "aka",
    "al": "a",
    "al": "ad",
    "al": "all",
    "al": "an",
    "al": "aol",
    "al": "ap",
    "al": "as",
    "al": "at",
    "ala": "all",
    "albe": "able",
    "albulm": "album",
    "ald": "and",
    "aleast": "least",
    "alerady": "already",
    "alf": "all",
    "algo": "ago",
    "alhpa": "alpha",
    "ali": "all",
    "alil": "all",
    "alink": "link",
    "alittle": "little",
    "alk": "all",
    "alking": "talking",
    "alla": "all",
    "allance": "alliance",
    "alli": "all",
    "allience": "alliance",
    "alliw": "allow",
    "allk": "all",
    "alll": "all",
    "allmost": "almost",
    "allo": "all",
    "allready": "already",
    "alls": "calls",
    "allw": "allow",
    "allways": "always",
    "allz": "all",
    "alm": "all",
    "almoest": "almost",
    "almoust": "almost",
    "alo": "all",
    "alol": "all",
    "alook": "look",
    "alooks": "looks",
    "aloot": "alot",
    "alot": "lot",
    "alots": "lots",
    "alott": "alot",
    "alow": "allow",
    "alowed": "allowed",
    "alows": "allows",
    "alr": "all",
    "alrady": "already",
    "alre": "are",
    "alreadly": "already",
    "alreadt": "already",
    "alreay": "already",
    "alreayd": "already",
    "alredy": "already",
    "alrets": "alerts",
    "alrt": "alert",
    "als": "all",
    "als": "as",
    "alseep": "asleep",
    "alsow": "also",
    "alt": "all",
    "alt": "at",
    "alt": "halt",
    "altas": "atlas",
    "altenative": "alternative",
    "alterenative": "alternative",
    "alternateives": "alternatives",
    "althought": "although",
    "alu": "flu",
    "alunch": "launch",
    "alwasy": "always",
    "alwaysz": "always",
    "alwayz": "always",
    "alwso": "also",
    "alwys": "always",
    "ama": "aka",
    "ama": "am",
    "ama": "ima",
    "amac": "mac",
    "amaerican": "american",
    "amaing": "amazing",
    "amake": "make",
    "amasing": "amazing",
    "amazez": "amazed",
    "amaziong": "amazing",
    "amc": "amp",
    "amc": "mac",
    "amd": "and",
    "ame": "name",
    "ame": "same",
    "ameican": "american",
    "ameircans": "americans",
    "amera": "camera",
    "amercan": "american",
    "amercian": "american",
    "amercican": "american",
    "amerian": "american",
    "americain": "american",
    "american": "america",
    "americas": "american",
    "americas": "americans",
    "americn": "american",
    "amessage": "message",
    "amke": "make",
    "aml": "am",
    "amma": "imma",
    "ammount": "amount",
    "amn": "an",
    "amnd": "and",
    "amost": "most",
    "amother": "another",
    "amout": "amount",
    "ams": "ass",
    "amt": "art",
    "amuch": "much",
    "amuzing": "amazing",
    "amy": "am",
    "amy": "amp",
    "amy": "any",
    "amy": "may",
    "amy": "my",
    "amzaing": "amazing",
    "amzazon": "amazon",
    "amzing": "amazing",
    "ana": "an",
    "ana": "and",
    "anad": "and",
    "analaytics": "analytics",
    "analitics": "analytics",
    "analiytics": "analytics",
    "analtics": "analytics",
    "analtyics": "analytics",
    "analyics": "analytics",
    "analyitcs": "analytics",
    "analyitics": "analytics",
    "analystics": "analytics",
    "analytcs": "analytics",
    "analytica": "analytics",
    "analyttics": "analytics",
    "analyzing": "analysing",
    "ananlytics": "analytics",
    "anational": "national",
    "anayltics": "analytics",
    "anaytics": "analytics",
    "anbd": "and",
    "anbody": "anybody",
    "anc": "and",
    "anda": "and",
    "andaroid": "android",
    "andd": "and",
    "andi": "and",
    "ando": "and",
    "andoid": "android",
    "andr": "and",
    "andrid": "android",
    "andriod": "android",
    "andrioid": "android",
    "androd": "android",
    "andy": "and",
    "andy": "any",
    "ane": "and",
    "anf": "and",
    "ang": "an",
    "ang": "and",
    "ang": "any",
    "angainst": "against",
    "anglees": "angeles",
    "anh": "and",
    "anice": "nice",
    "aniiversary": "anniversary",
    "anit": "aint",
    "anlalytics": "analytics",
    "anlaytics": "analytics",
    "anlytics": "analytics",
    "anme": "name",
    "ann": "an",
    "ann": "and",
    "annd": "and",
    "anniverary": "anniversary",
    "anniversay": "anniversary",
    "annivesary": "anniversary",
    "annouce": "announce",
    "annouced": "announced",
    "annoucement": "announcement",
    "annouces": "announces",
    "annoucned": "announced",
    "announed": "announced",
    "anny": "any",
    "annyone": "anyone",
    "ano": "an",
    "anoher": "another",
    "anone": "anyone",
    "anotger": "another",
    "anothr": "another",
    "anounced": "announced",
    "anounces": "announces",
    "anouther": "another",
    "anoying": "annoying",
    "anoyone": "anyone",
    "anroid": "android",
    "ans": "and",
    "ans": "any",
    "ans": "as",
    "ansd": "and",
    "antalytics": "analytics",
    "antbody": "anybody",
    "anubody": "anybody",
    "anunciar": "anuncia",
    "anw": "and",
    "anwer": "answer",
    "anwesome": "awesome",
    "anwser": "answer",
    "anx": "and",
    "anybdy": "anybody",
    "anyboady": "anybody",
    "anybodya": "anybody",
    "anybodyy": "anybody",
    "anyhone": "anyone",
    "anyine": "anyone",
    "anyne": "anyone",
    "anyody": "anybody",
    "anyoen": "anyone",
    "anyome": "anyone",
    "anyonr": "anyone",
    "anyonw": "anyone",
    "anyoone": "anyone",
    "anyt": "any",
    "anythig": "anything",
    "anythimg": "anything",
    "anywone": "anyone",
    "anyy": "any",
    "anz": "and",
    "ao": "a",
    "ao": "so",
    "ao": "to",
    "aobut": "about",
    "aoc": "doc",
    "aocial": "social",
    "aod": "and",
    "aol": "all",
    "aomething": "something",
    "aon": "on",
    "aor": "for",
    "aout": "about",
    "aout": "out",
    "ap": "a",
    "ap": "ad",
    "ap": "am",
    "ap": "amp",
    "ap": "an",
    "ap": "app",
    "ap": "as",
    "ap": "at",
    "ap": "map",
    "ap": "tap",
    "ap": "up",
    "apa": "app",
    "aparently": "apparently",
    "apc": "app",
    "apear": "appear",
    "apears": "appears",
    "apha": "alpha",
    "api": "ap",
    "api": "app",
    "apicture": "picture",
    "apis": "apps",
    "apk": "app",
    "aple": "apple",
    "aplha": "alpha",
    "aplication": "application",
    "aplications": "applications",
    "aplle": "apple",
    "apllication": "application",
    "apm": "app",
    "apn": "an",
    "apn": "app",
    "apo": "app",
    "apod": "ipod",
    "apologise": "apologies",
    "apologises": "apologies",
    "apologises": "apologizes",
    "apon": "upon",
    "app": "amp",
    "app": "ap",
    "app": "api",
    "appa": "apps",
    "apparant": "apparent",
    "apparantly": "apparently",
    "apparentaly": "apparently",
    "apparentley": "apparently",
    "apparenty": "apparently",
    "apparetly": "apparently",
    "appart": "apart",
    "appartently": "apparently",
    "appearently": "apparently",
    "appeear": "appear",
    "appel": "apple",
    "appele": "apple",
    "appened": "happened",
    "apperent": "apparent",
    "apperently": "apparently",
    "appication": "application",
    "appilication": "application",
    "appl": "app",
    "appl": "apps",
    "applaication": "application",
    "applciation": "application",
    "applee": "apple",
    "applet": "apple",
    "appley": "apple",
    "appli": "apple",
    "appliacation": "application",
    "applicaion": "application",
    "applicaiton": "application",
    "applicaitons": "applications",
    "applicatoin": "application",
    "applicaton": "application",
    "applictaion": "application",
    "appliction": "application",
    "applie": "apple",
    "applr": "apple",
    "appls": "apps",
    "appoinment": "appointment",
    "appointmentt": "appointment",
    "appoitment": "appointment",
    "appologize": "apologize",
    "apporoved": "approved",
    "apportunity": "opportunity",
    "appp": "app",
    "appp": "apps",
    "appple": "apple",
    "appps": "apps",
    "appreaciate": "appreciate",
    "apprecaite": "appreciate",
    "appreciatet": "appreciated",
    "apprecite": "appreciate",
    "apprently": "apparently",
    "appriciate": "appreciate",
    "approvd": "approved",
    "appss": "apps",
    "appstroe": "appstore",
    "appsu": "apps",
    "appt": "app",
    "appt": "apps",
    "appts": "apps",
    "appy": "app",
    "appy": "happy",
    "appystore": "appstore",
    "appz": "app",
    "appz": "apps",
    "apreciate": "appreciate",
    "apreciated": "appreciated",
    "aps": "ads",
    "aps": "api",
    "aps": "app",
    "aps": "apps",
    "aps": "as",
    "aps": "maps",
    "apss": "apps",
    "apts": "apps",
    "apw": "app",
    "apz": "app",
    "aq": "a",
    "aq": "as",
    "aqe": "age",
    "aqo": "ago",
    "aqree": "agree",
    "aqs": "as",
    "aquire": "acquire",
    "aquired": "acquired",
    "aquisitions": "acquisitions",
    "ar": "a",
    "ar": "ad",
    "ar": "air",
    "ar": "am",
    "ar": "an",
    "ar": "as",
    "ar": "at",
    "ar": "bar",
    "ar": "car",
    "ar": "ear",
    "ar": "or",
    "ar": "r",
    "ara": "are",
    "araba": "arabia",
    "araid": "afraid",
    "arbia": "arabia",
    "archived": "archive",
    "ard": "add",
    "ard": "and",
    "ard": "hard",
    "arecord": "record",
    "aree": "are",
    "areh": "are",
    "arem": "arm",
    "arer": "are",
    "arg": "are",
    "arie": "are",
    "ariund": "around",
    "arive": "drive",
    "arleady": "already",
    "arn": "arm",
    "arnd": "and",
    "arne": "are",
    "arnt": "aint",
    "arond": "around",
    "aroud": "around",
    "aroudn": "around",
    "arouind": "around",
    "aroune": "around",
    "aroung": "around",
    "arouond": "around",
    "arre": "are",
    "arrivie": "arrive",
    "arround": "around",
    "aru": "are",
    "ary": "try",
    "asa": "as",
    "asd": "and",
    "ase": "are",
    "ashe": "she",
    "ashing": "washing",
    "asi": "ass",
    "aska": "ask",
    "askd": "ask",
    "askd": "asked",
    "askinf": "asking",
    "askn": "ask",
    "askng": "asking",
    "asknig": "asking",
    "aslo": "also",
    "asme": "same",
    "asmile": "smile",
    "aso": "also",
    "ast": "last",
    "astep": "step",
    "asu": "as",
    "asume": "assume",
    "aswine": "swine",
    "asz": "as",
    "ata": "at",
    "atacking": "attacking",
    "atarting": "starting",
    "atc": "at",
    "atempt": "attempt",
    "ath": "at",
    "athough": "though",
    "ati": "at",
    "ati": "gti",
    "atic": "attic",
    "aticle": "article",
    "atl": "all",
    "atlot": "alot",
    "atm": "am",
    "atm": "at",
    "ato": "to",
    "atomach": "stomach",
    "atomatically": "automatically",
    "atower": "tower",
    "atp": "app",
    "att": "at",
    "attemt": "attempt",
    "attetion": "attention",
    "atttention": "attention",
    "atually": "actually",
    "atv": "tv",
    "atweetment": "tweetment",
    "au": "a",
    "au": "at",
    "au": "u",
    "augemented": "augmented",
    "augh": "ugh",
    "augmentd": "augmented",
    "augmentef": "augmented",
    "augmentet": "augmented",
    "augmeted": "augmented",
    "augumented": "augmented",
    "aumented": "augmented",
    "aup": "up",
    "aupported": "supported",
    "aupports": "supports",
    "aus": "ads",
    "aus": "as",
    "aus": "us",
    "ause": "cause",
    "aust": "just",
    "australlia": "australia",
    "auth": "auto",
    "automagically": "automatically",
    "autopiot": "autopilot",
    "autorities": "authorities",
    "av": "a",
    "av": "am",
    "av": "an",
    "av": "as",
    "av": "at",
    "av": "fav",
    "av": "hav",
    "avaiable": "available",
    "avaialable": "available",
    "avaialble": "available",
    "avaidable": "available",
    "availabe": "available",
    "availablr": "available",
    "availabne": "available",
    "availabvle": "available",
    "availalbe": "available",
    "availalble": "available",
    "availale": "available",
    "availbale": "available",
    "availble": "available",
    "availiable": "available",
    "availible": "available",
    "availlable": "available",
    "avalable": "available",
    "avaliable": "available",
    "ave": "are",
    "ave": "gave",
    "ave": "have",
    "ave": "ive",
    "ave": "wave",
    "avery": "very",
    "avilable": "available",
    "avin": "havin",
    "aviod": "avoid",
    "avl": "all",
    "avnt": "aint",
    "avoud": "avoid",
    "avp": "app",
    "aw": "a",
    "aw": "an",
    "aw": "as",
    "aw": "at",
    "awarenss": "awareness",
    "awarness": "awareness",
    "awating": "awaiting",
    "awave": "wave",
    "aways": "always",
    "aways": "ways",
    "awayy": "away",
    "awd": "and",
    "aweful": "awful",
    "aweosme": "awesome",
    "awfil": "awful",
    "awfull": "awful",
    "awhole": "whole",
    "awine": "swine",
    "awords": "adwords",
    "aws": "ads",
    "awseome": "awesome",
    "awsome": "awesome",
    "awway": "away",
    "ax": "a",
    "ay": "a",
    "ay": "am",
    "ay": "an",
    "ay": "as",
    "ay": "at",
    "ay": "day",
    "ay": "my",
    "ay": "way",
    "ayone": "anyone",
    "ays": "as",
    "aything": "anything",
    "az": "a",
    "az": "am",
    "az": "an",
    "az": "as",
    "az": "at",
    "ba": "a",
    "ba": "bb",
    "ba": "be",
    "ba": "by",
    "bab": "bad",
    "bab": "bsb",
    "babay": "baby",
    "bac": "bad",
    "bac": "bar",
    "bac": "bc",
    "bac": "mac",
    "bacc": "back",
    "baccine": "vaccine",
    "bach": "back",
    "bacjground": "background",
    "backberry": "blackberry",
    "backi": "back",
    "backk": "back",
    "backround": "background",
    "backsreet": "backstreet",
    "backsteet": "backstreet",
    "backstrteet": "backstreet",
    "backtreet": "backstreet",
    "backwords": "backwards",
    "bacq": "back",
    "bact": "back",
    "badd": "bad",
    "baded": "based",
    "badu": "bad",
    "bady": "baby",
    "bady": "body",
    "bae": "be",
    "baest": "best",
    "baha": "haha",
    "bak": "back",
    "bak": "bad",
    "bak": "bar",
    "bakc": "back",
    "bakk": "back",
    "bakwards": "backwards",
    "balace": "balance",
    "balackberry": "blackberry",
    "balanace": "balance",
    "balckberry": "blackberry",
    "balled": "called",
    "ballon": "balloon",
    "balloom": "balloon",
    "baloon": "balloon",
    "balu": "bali",
    "bama": "obama",
    "bame": "game",
    "banc": "band",
    "bandn": "band",
    "bankf": "bank",
    "baout": "about",
    "baq": "bad",
    "barak": "barack",
    "barly": "barely",
    "barnd": "brand",
    "bart": "bar",
    "bart": "bat",
    "bart": "part",
    "bas": "has",
    "basd": "based",
    "bata": "beta",
    "batery": "battery",
    "batroom": "bathroom",
    "batt": "bat",
    "battary": "battery",
    "batteling": "battling",
    "batterly": "battery",
    "battey": "battery",
    "battleing": "battling",
    "battlinq": "battling",
    "battrey": "battery",
    "battry": "battery",
    "baught": "bought",
    "baught": "caught",
    "bb": "be",
    "bb": "bsb",
    "bb": "by",
    "bb": "cb",
    "bb": "fb",
    "bbc": "abc",
    "bbc": "bb",
    "bbcz": "bbc",
    "bbd": "bed",
    "bbe": "be",
    "bbeen": "been",
    "bblackberry": "blackberry",
    "bbm": "bb",
    "bbm": "ibm",
    "bbn": "bb",
    "bbq": "bb",
    "bbrother": "brother",
    "bbs": "bbm",
    "bbut": "but",
    "bby": "baby",
    "bby": "bay",
    "bby": "bb",
    "bc": "bb",
    "bc": "be",
    "bc": "by",
    "bc": "sc",
    "bcame": "came",
    "bcause": "because",
    "bck": "back",
    "bck": "bc",
    "bckground": "background",
    "bckwards": "backwards",
    "bcuz": "cuz",
    "bcz": "bc",
    "bd": "b",
    "bd": "bad",
    "bd": "bed",
    "bd": "by",
    "bday": "day",
    "bdm": "bbm",
    "bdy": "body",
    "bea": "be",
    "beacause": "because",
    "beacuse": "because",
    "bealtes": "beatles",
    "beardman": "beardyman",
    "beatiful": "beautiful",
    "beattles": "beatles",
    "beauiful": "beautiful",
    "beause": "because",
    "bec": "bc",
    "bec": "be",
    "bec": "bed",
    "becase": "because",
    "becasue": "because",
    "becauce": "because",
    "becaude": "because",
    "becaue": "because",
    "becaues": "because",
    "becme": "become",
    "becoause": "because",
    "becomming": "becoming",
    "becomnig": "becoming",
    "becouse": "because",
    "becuase": "because",
    "becuse": "because",
    "beda": "beta",
    "bedd": "bed",
    "bedi": "bed",
    "beeb": "been",
    "beebn": "been",
    "beecause": "because",
    "beee": "been",
    "beeen": "been",
    "beeing": "being",
    "beem": "been",
    "beeng": "being",
    "beeter": "better",
    "beetter": "better",
    "befoer": "before",
    "befoore": "before",
    "beforee": "before",
    "befre": "before",
    "befroe": "before",
    "begginning": "beginning",
    "beging": "begin",
    "beging": "being",
    "beginings": "beginnings",
    "beginnig": "beginning",
    "beginnins": "beginning",
    "beginnning": "beginning",
    "bei": "be",
    "beig": "being",
    "beign": "being",
    "beileve": "believe",
    "bein": "been",
    "bein": "brin",
    "beinga": "being",
    "beingg": "being",
    "beinn": "being",
    "beinq": "being",
    "beleive": "believe",
    "beliebe": "believe",
    "beliee": "believe",
    "believ": "belive",
    "belive": "believe",
    "bendy": "wendy",
    "bene": "been",
    "benifit": "benefit",
    "benifits": "benefits",
    "benn": "been",
    "beofre": "before",
    "beore": "before",
    "berfore": "before",
    "bern": "been",
    "bernadino": "bernardino",
    "bert": "best",
    "bertter": "better",
    "bery": "berry",
    "bery": "very",
    "bes": "bed",
    "bess": "best",
    "besst": "best",
    "bestr": "best",
    "bestt": "best",
    "beter": "better",
    "beth": "both",
    "bett": "best",
    "bett": "bet",
    "bettaer": "better",
    "bettar": "better",
    "bettee": "better",
    "betten": "better",
    "betterh": "better",
    "betteri": "better",
    "bettero": "better",
    "betterr": "better",
    "bettery": "battery",
    "bettery": "better",
    "bettet": "better",
    "betther": "better",
    "bettr": "better",
    "bettrr": "better",
    "bettter": "better",
    "betweeen": "between",
    "betweent": "between",
    "betwen": "between",
    "betwwen": "between",
    "beutiful": "beautiful",
    "bever": "never",
    "bew": "new",
    "bews": "news",
    "bewteen": "between",
    "bext": "best",
    "bext": "next",
    "bezt": "best",
    "bf": "bb",
    "bf": "be",
    "bf": "by",
    "bf": "if",
    "bf": "of",
    "bfe": "be",
    "bff": "off",
    "bfing": "being",
    "bfor": "for",
    "bfore": "before",
    "bfs": "bus",
    "bg": "bb",
    "bg": "be",
    "bg": "big",
    "bg": "by",
    "bgb": "bb",
    "bh": "b",
    "bh": "bb",
    "bhere": "here",
    "bhind": "behind",
    "bho": "who",
    "bi": "i",
    "bia": "via",
    "bic": "big",
    "bice": "nice",
    "bicth": "bitch",
    "bieng": "being",
    "bigg": "big",
    "bigo": "big",
    "biig": "big",
    "biit": "bit",
    "bil": "big",
    "bing": "being",
    "bing": "big",
    "bing": "bring",
    "bing": "king",
    "bing": "ping",
    "bings": "brings",
    "bio": "big",
    "biphone": "iphone",
    "bips": "tips",
    "biq": "big",
    "birdied": "birdies",
    "birf": "bird",
    "birght": "bright",
    "birtday": "birthday",
    "birthay": "birthday",
    "birthdaay": "birthday",
    "birthdayy": "birthday",
    "bis": "big",
    "bis": "his",
    "bis": "is",
    "bisrthday": "birthday",
    "bita": "bit",
    "bitchh": "bitch",
    "bithday": "birthday",
    "bitrhday": "birthday",
    "biuld": "build",
    "bix": "big",
    "biyfriend": "boyfriend",
    "biys": "boys",
    "bk": "b",
    "bk": "bb",
    "bk": "be",
    "bk": "ok",
    "bl": "bb",
    "bl": "by",
    "blabkberry": "blackberry",
    "blacberry": "blackberry",
    "blacc": "black",
    "blaccberry": "blackberry",
    "blackbarry": "blackberry",
    "blackbberry": "blackberry",
    "blackbeery": "blackberry",
    "blackberrry": "blackberry",
    "blackberryy": "blackberry",
    "blackbery": "blackberry",
    "blackblerry": "blackberry",
    "blackburry": "blackberry",
    "blackeberry": "blackberry",
    "blackerry": "blackberry",
    "blaclberry": "blackberry",
    "blad": "bad",
    "blakberry": "blackberry",
    "blakc": "black",
    "blakcberry": "blackberry",
    "blakk": "black",
    "blakkberry": "blackberry",
    "blance": "balance",
    "blaxkberry": "blackberry",
    "blck": "black",
    "blckberry": "blackberry",
    "bldg": "blog",
    "ble": "able",
    "blees": "bless",
    "blg": "big",
    "blieve": "believe",
    "bline": "line",
    "bling": "bing",
    "bling": "bring",
    "blmae": "blame",
    "blod": "blog",
    "bloge": "blog",
    "blogg": "blog",
    "blol": "lol",
    "blom": "blog",
    "bloor": "floor",
    "blowning": "blowing",
    "blst": "blast",
    "blt": "bit",
    "blu": "flu",
    "bm": "bb",
    "bmm": "bbm",
    "bmore": "more",
    "bmw": "bow",
    "bn": "an",
    "bn": "be",
    "bn": "by",
    "bn": "in",
    "bn": "on",
    "bne": "one",
    "bnew": "new",
    "bno": "no",
    "boad": "board",
    "bobdy": "body",
    "boey": "boy",
    "bof": "of",
    "boght": "bought",
    "boight": "bought",
    "boing": "going",
    "boiught": "bought",
    "boling": "bowling",
    "bolwing": "bowling",
    "boming": "coming",
    "bon": "on",
    "bong": "long",
    "bong": "pong",
    "bonk": "book",
    "boog": "boo",
    "boogle": "google",
    "bookr": "book",
    "bookz": "books",
    "boomz": "boom",
    "booo": "boo",
    "booo": "book",
    "boought": "bought",
    "bopy": "boy",
    "bopys": "boys",
    "borad": "bored",
    "bord": "bored",
    "bord": "word",
    "boreanez": "boreanaz",
    "boreanz": "boreanaz",
    "boredd": "bored",
    "borh": "born",
    "bork": "book",
    "bork": "work",
    "borked": "worked",
    "borks": "works",
    "borred": "bored",
    "bors": "bros",
    "borst": "worst",
    "borther": "brother",
    "borthers": "brothers",
    "bos": "bros",
    "bose": "nose",
    "bot": "bout",
    "bot": "box",
    "bot": "boy",
    "bot": "but",
    "bot": "got",
    "bot": "lot",
    "bot": "not",
    "bothh": "both",
    "botle": "bottle",
    "bots": "both",
    "bots": "boys",
    "bottem": "bottom",
    "botton": "bottom",
    "botton": "button",
    "botu": "bout",
    "bougt": "bought",
    "bouh": "bout",
    "bouht": "bought",
    "bouling": "bowling",
    "bouta": "bout",
    "boutt": "bout",
    "boutz": "bout",
    "bouy": "bout",
    "bowking": "bowling",
    "bowlef": "bowled",
    "bowlig": "bowling",
    "bowlinq": "bowling",
    "bowlng": "bowling",
    "bowt": "bout",
    "boyf": "boys",
    "boyz": "boy",
    "boyz": "boys",
    "bp": "up",
    "bphone": "iphone",
    "bpought": "bought",
    "bprn": "born",
    "bqck": "back",
    "br": "bar",
    "br": "be",
    "br": "by",
    "br": "or",
    "braek": "break",
    "brans": "brand",
    "braqnd": "brand",
    "bre": "be",
    "brea": "area",
    "breand": "brand",
    "breat": "beat",
    "bree": "free",
    "breif": "brief",
    "bren": "been",
    "brian": "brin",
    "briana": "brian",
    "briano": "brian",
    "brid": "bird",
    "bridqe": "bridge",
    "brigde": "bridge",
    "brimg": "bring",
    "brining": "bringing",
    "brinn": "brin",
    "bris": "brin",
    "brit": "bit",
    "britghtcove": "brightcove",
    "brithday": "birthday",
    "brither": "brother",
    "brke": "broke",
    "brlieve": "believe",
    "bro": "pro",
    "brocken": "broken",
    "broght": "brought",
    "bron": "brin",
    "broowser": "browser",
    "broser": "browser",
    "bross": "bros",
    "broswer": "browser",
    "brotherr": "brother",
    "brower": "browser",
    "browser": "browse",
    "brth": "birth",
    "brther": "brother",
    "brushn": "brush",
    "bry": "boy",
    "bryan": "brian",
    "bs": "as",
    "bs": "be",
    "bs": "is",
    "bs": "os",
    "bs": "vs",
    "bsafe": "safe",
    "bsb": "bb",
    "bsckup": "backup",
    "bsg": "big",
    "bsing": "using",
    "bsst": "best",
    "bst": "best",
    "bsuiness": "business",
    "bt": "at",
    "bt": "bb",
    "bt": "be",
    "bt": "bit",
    "bt": "but",
    "bt": "it",
    "btetter": "better",
    "bth": "both",
    "btich": "bitch",
    "btr": "bar",
    "btter": "better",
    "btween": "between",
    "bu": "be",
    "bu": "by",
    "buat": "but",
    "bub": "but",
    "buccanners": "buccaneers",
    "buch": "bunch",
    "bucs": "bus",
    "budle": "bundle",
    "bugg": "bug",
    "buggle": "boggle",
    "bugi": "bug",
    "bugz": "bug",
    "buh": "but",
    "buht": "but",
    "buiiding": "building",
    "builidng": "building",
    "builing": "building",
    "builld": "build",
    "buisness": "business",
    "buks": "bucks",
    "bul": "but",
    "buld": "build",
    "bulding": "building",
    "bulid": "build",
    "bult": "but",
    "bumber": "number",
    "bumch": "bunch",
    "buncha": "bunch",
    "bur": "but",
    "burd": "bird",
    "buring": "during",
    "busb": "bus",
    "busiiness": "business",
    "busines": "business",
    "busineses": "business",
    "businesess": "businesses",
    "businessem": "businesses",
    "businness": "business",
    "businss": "business",
    "buss": "bus",
    "bussiness": "business",
    "bussy": "busy",
    "buts": "puts",
    "buttom": "button",
    "buttond": "button",
    "buttonles": "buttonless",
    "butz": "but",
    "buu": "but",
    "buut": "but",
    "bux": "but",
    "bux": "buy",
    "buya": "buy",
    "buyinq": "buying",
    "buyng": "buying",
    "buyt": "buy",
    "buz": "but",
    "buz": "buy",
    "buzy": "busy",
    "bv": "bb",
    "bv": "be",
    "bve": "be",
    "bw": "b",
    "bw": "be",
    "bwe": "be",
    "bwitter": "twitter",
    "bwt": "but",
    "bx": "box",
    "bxtch": "bitch",
    "byo": "by",
    "byrd": "bird",
    "bytch": "bitch",
    "byuing": "buying",
    "caan": "can",
    "caant": "cant",
    "caccination": "vaccination",
    "cae": "came",
    "cae": "case",
    "caeses": "cases",
    "caf": "car",
    "cag": "car",
    "cahnge": "change",
    "caht": "chat",
    "cai": "can",
    "cai": "cari",
    "caight": "caught",
    "caint": "cant",
    "cal": "call",
    "cal": "can",
    "cal": "car",
    "calandar": "calendar",
    "calc": "call",
    "calcultor": "calculator",
    "cald": "call",
    "caleb": "celeb",
    "caled": "called",
    "calenar": "calendar",
    "calendary": "calendar",
    "cali": "call",
    "califorina": "california",
    "caling": "calling",
    "calld": "call",
    "calld": "called",
    "callendar": "calendar",
    "calll": "call",
    "callled": "called",
    "cals": "call",
    "camara": "camera",
    "camea": "camera",
    "camed": "came",
    "cameraa": "camera",
    "camr": "came",
    "camt": "cant",
    "cance": "chance",
    "cancle": "cancel",
    "cancled": "canceled",
    "cancon": "canon",
    "cand": "can",
    "cani": "can",
    "cann": "can",
    "cannnot": "cannot",
    "cannt": "cant",
    "canot": "cant",
    "canr": "cant",
    "cantt": "cant",
    "canu": "can",
    "canv": "can",
    "caought": "caught",
    "caould": "could",
    "capp": "app",
    "carefull": "careful",
    "carger": "charger",
    "carier": "carrier",
    "carii": "cari",
    "carnt": "cant",
    "carr": "car",
    "carr": "cart",
    "carres": "cares",
    "carring": "carrying",
    "cartt": "cart",
    "cary": "carry",
    "cas": "can",
    "casa": "case",
    "casec": "cases",
    "casn": "can",
    "cass": "case",
    "casses": "cases",
    "casued": "caused",
    "catched": "watched",
    "catchh": "catch",
    "catchig": "catching",
    "catchinn": "catching",
    "catchn": "catch",
    "catchng": "catching",
    "catcu": "catch",
    "cathc": "catch",
    "cathes": "catches",
    "catn": "can",
    "catvh": "catch",
    "caue": "case",
    "caughts": "caught",
    "caugt": "caught",
    "cauight": "caught",
    "cauqht": "caught",
    "causd": "caused",
    "causee": "cause",
    "cauvght": "caught",
    "cauz": "cuz",
    "cayght": "caught",
    "cayse": "cause",
    "caz": "can",
    "caze": "case",
    "cb": "fb",
    "cbc": "abc",
    "cbc": "cdc",
    "cbs": "lbs",
    "ccc": "cdc",
    "ccc": "fcc",
    "cchrome": "chrome",
    "ccntrol": "control",
    "ccuz": "cuz",
    "cd": "ad",
    "cd": "hd",
    "cdn": "cdc",
    "cdnt": "cant",
    "cds": "ads",
    "ce": "be",
    "ce": "me",
    "ceace": "cease",
    "ceck": "check",
    "cee": "see",
    "cehck": "check",
    "celbrating": "celebrating",
    "celebrtaes": "celebrates",
    "celi": "cell",
    "celly": "cell",
    "center": "enter",
    "centered": "entered",
    "ceo": "seo",
    "cetch": "catch",
    "cf": "of",
    "cfo": "ceo",
    "cganged": "changed",
    "cgn": "cnn",
    "cgrome": "chrome",
    "chace": "chance",
    "chack": "check",
    "chacne": "chance",
    "chad": "had",
    "chaeck": "check",
    "chaffeine": "caffeine",
    "chage": "change",
    "chager": "changer",
    "chaging": "changing",
    "challenage": "challenge",
    "chan": "can",
    "chanche": "chance",
    "chaned": "changed",
    "chaneged": "changed",
    "changend": "changed",
    "changer": "changes",
    "changer": "charger",
    "chanllenge": "challenge",
    "channal": "channel",
    "chante": "chance",
    "chapotle": "chipotle",
    "charer": "charger",
    "chargibg": "charging",
    "chargng": "charging",
    "chargr": "charger",
    "chargwr": "charger",
    "charing": "charging",
    "chas": "chad",
    "chatching": "catching",
    "chavs": "chaos",
    "chck": "check",
    "che": "the",
    "cheak": "check",
    "cheapo": "cheap",
    "cheapy": "cheap",
    "cheapz": "cheap",
    "checc": "check",
    "chech": "check",
    "chechk": "check",
    "checing": "checking",
    "checkd": "check",
    "checkd": "checked",
    "checkig": "checking",
    "cheerleeder": "cheerleader",
    "cheick": "check",
    "chek": "check",
    "chekcing": "checking",
    "chekcked": "checked",
    "cheking": "checking",
    "chichken": "chicken",
    "chickn": "chicken",
    "chiildren": "children",
    "childern": "children",
    "childrem": "children",
    "childrens": "children",
    "chili": "chilli",
    "chiliin": "chillin",
    "chilin": "chillin",
    "chillinq": "chillin",
    "chilln": "chillin",
    "chipolte": "chipotle",
    "chipotele": "chipotle",
    "chiptole": "chipotle",
    "chirstmas": "christmas",
    "chldren": "children",
    "chnace": "chance",
    "chnces": "chances",
    "chnge": "change",
    "chnged": "changed",
    "cho": "who",
    "chome": "chrome",
    "chool": "school",
    "chorme": "chrome",
    "chosing": "choosing",
    "chould": "could",
    "chrck": "check",
    "chrge": "charge",
    "christmans": "christmas",
    "christmass": "christmas",
    "christmasx": "christmas",
    "christmis": "christmas",
    "chrme": "chrome",
    "chroe": "chrome",
    "chromo": "chrome",
    "chromse": "chrome",
    "chrone": "chrome",
    "chroome": "chrome",
    "chs": "nhs",
    "chwecked": "checked",
    "chyllin": "chillin",
    "cick": "click",
    "cig": "pig",
    "cilent": "client",
    "cilnic": "clinic",
    "cing": "ping",
    "cinic": "clinic",
    "ciome": "come",
    "cirus": "cyrus",
    "cit": "it",
    "citay": "city",
    "cj": "cb",
    "ck": "chk",
    "ckan": "can",
    "ckant": "cant",
    "ckeck": "check",
    "ckick": "click",
    "ckome": "come",
    "ckrib": "crib",
    "clal": "call",
    "clas": "class",
    "clasd": "class",
    "clase": "class",
    "classs": "class",
    "clasz": "class",
    "clcik": "click",
    "clck": "click",
    "clebrating": "celebrating",
    "cleck": "click",
    "clevland": "cleveland",
    "cliams": "claims",
    "clicc": "click",
    "clickd": "click",
    "clicky": "click",
    "clik": "click",
    "clikc": "click",
    "cliking": "clicking",
    "cliks": "clicks",
    "climatd": "climate",
    "climete": "climate",
    "clinc": "clinic",
    "clincs": "clinics",
    "clinet": "client",
    "clinicis": "clinics",
    "clinincs": "clinics",
    "clinis": "clinic",
    "clinis": "clinics",
    "clkimate": "climate",
    "clnic": "clinic",
    "clniics": "clinics",
    "cloose": "close",
    "closr": "closer",
    "clould": "could",
    "clu": "flu",
    "cmae": "came",
    "cme": "came",
    "cme": "come",
    "cme": "me",
    "cmin": "comin",
    "cming": "coming",
    "cmo": "ceo",
    "cmpare": "compare",
    "cmr": "car",
    "cms": "mms",
    "cn": "an",
    "cn": "can",
    "cn": "in",
    "cn": "on",
    "cna": "can",
    "cname": "name",
    "cnat": "cant",
    "cnc": "cnn",
    "cnet": "net",
    "cnfirmed": "confirmed",
    "cnn": "can",
    "cnonsole": "console",
    "cnt": "cant",
    "cnt": "dnt",
    "cntrol": "control",
    "cny": "ny",
    "co": "ceo",
    "co": "do",
    "co": "go",
    "co": "to",
    "coatch": "coach",
    "coe": "come",
    "coee": "code",
    "coem": "come",
    "cofee": "coffee",
    "coference": "conference",
    "coffe": "coffee",
    "coiming": "coming",
    "coiuld": "could",
    "colaborate": "collaborate",
    "coldd": "cold",
    "cole": "code",
    "cole": "cold",
    "colection": "collection",
    "colf": "cold",
    "coll": "cool",
    "collaberate": "collaborate",
    "colleciton": "collection",
    "coller": "cooler",
    "colloboration": "collaboration",
    "colo": "cold",
    "com": "mom",
    "comand": "command",
    "combi": "combo",
    "combonation": "combination",
    "coment": "comment",
    "comercial": "commercial",
    "cometition": "competition",
    "comfirmed": "confirmed",
    "comig": "coming",
    "comign": "coming",
    "comination": "combination",
    "comingg": "coming",
    "cominng": "coming",
    "cominq": "coming",
    "comlains": "complains",
    "comm": "come",
    "comman": "common",
    "commen": "common",
    "commerial": "commercial",
    "commerical": "commercial",
    "commericial": "commercial",
    "commertial": "commercial",
    "commin": "comin",
    "comming": "coming",
    "commom": "common",
    "comms": "comes",
    "comn": "come",
    "comn": "comin",
    "comnbat": "combat",
    "comng": "coming",
    "comnig": "coming",
    "comning": "coming",
    "como": "come",
    "comon": "common",
    "comong": "coming",
    "comonly": "commonly",
    "comp": "come",
    "compaired": "compared",
    "comparision": "comparison",
    "compatbile": "compatible",
    "compatibe": "compatible",
    "compatition": "competition",
    "compertition": "competition",
    "competiton": "competition",
    "compites": "competes",
    "compleete": "complete",
    "compnay": "company",
    "compred": "compared",
    "comps": "comes",
    "compu": "comp",
    "computar": "computer",
    "computr": "computer",
    "comr": "come",
    "comunicate": "communicate",
    "comunity": "community",
    "comws": "comes",
    "conbination": "combination",
    "concers": "concerns",
    "concersn": "concern",
    "conclution": "conclusion",
    "conctract": "contract",
    "cond": "cold",
    "condelences": "condolences",
    "condolances": "condolences",
    "condoleces": "condolences",
    "condolensces": "condolences",
    "condolonces": "condolences",
    "conect": "connect",
    "conected": "connected",
    "conection": "connection",
    "conerned": "concerned",
    "confermed": "confirmed",
    "confimed": "confirmed",
    "confimrmed": "confirmed",
    "confired": "confirmed",
    "confirma": "confirms",
    "confirned": "confirmed",
    "confrence": "conference",
    "confrims": "confirms",
    "confussed": "confused",
    "congradulations": "congratulations",
    "congratz": "congrats",
    "coninced": "convinced",
    "conincide": "coincide",
    "conjuction": "conjunction",
    "conjuntion": "conjunction",
    "conncect": "connect",
    "connextion": "connection",
    "conputer": "computer",
    "conrtact": "contract",
    "consule": "console",
    "cont": "dont",
    "contacs": "contacts",
    "contactcs": "contacts",
    "contagiousa": "contagious",
    "contol": "control",
    "contractng": "contracting",
    "contrl": "control",
    "contrller": "controller",
    "contry": "country",
    "conver": "cover",
    "converned": "concerned",
    "convertor": "converter",
    "convice": "convince",
    "conviced": "convinced",
    "convience": "convince",
    "convitee": "convite",
    "cooh": "cool",
    "cooke": "cookie",
    "coolestz": "coolest",
    "coolist": "coolest",
    "coolsest": "coolest",
    "cooming": "coming",
    "coool": "cool",
    "copd": "cold",
    "cople": "couple",
    "copming": "coming",
    "coppy": "copy",
    "copss": "cops",
    "copuld": "could",
    "copuple": "couple",
    "coputer": "computer",
    "corde": "code",
    "corect": "correct",
    "coreect": "correct",
    "corris": "norris",
    "cosin": "cousin",
    "cossin": "cousin",
    "coud": "could",
    "coudl": "could",
    "couged": "coughed",
    "cought": "bought",
    "cought": "caught",
    "coulda": "could",
    "couldent": "couldnt",
    "couldn": "could",
    "couldnt": "wouldnt",
    "coulld": "could",
    "coulnt": "couldnt",
    "couls": "could",
    "coult": "could",
    "cound": "could",
    "cound": "found",
    "counsin": "cousin",
    "couole": "couple",
    "coupel": "couple",
    "coupla": "couple",
    "couplw": "couple",
    "couqh": "cough",
    "coures": "course",
    "courtesey": "courtesy",
    "courtisy": "courtesy",
    "courtsey": "courtesy",
    "couse": "cause",
    "couse": "course",
    "couse": "house",
    "cousing": "cousin",
    "cousion": "cousin",
    "cousre": "course",
    "coustom": "custom",
    "coutry": "country",
    "couz": "cuz",
    "coz": "cuz",
    "cp": "ap",
    "cp": "up",
    "cpc": "pc",
    "cpc": "ppc",
    "cphone": "iphone",
    "cpr": "car",
    "cpy": "copy",
    "cra": "car",
    "craap": "crap",
    "cracced": "cracked",
    "crae": "care",
    "craete": "create",
    "craked": "cracked",
    "crapi": "crap",
    "crapp": "crap",
    "crasing": "crashing",
    "crawlabe": "crawlable",
    "craz": "crap",
    "crd": "card",
    "cre": "cure",
    "creat": "treat",
    "creater": "creator",
    "creaters": "creators",
    "creati": "create",
    "crhome": "chrome",
    "cri": "cari",
    "criate": "create",
    "cristal": "crystal",
    "crm": "arm",
    "crnt": "cant",
    "crome": "chrome",
    "cron": "crown",
    "crontrol": "control",
    "cros": "cross",
    "crunk": "drunk",
    "cryus": "cyrus",
    "cs": "is",
    "cs": "us",
    "cses": "cases",
    "csrt": "cart",
    "css": "rss",
    "cst": "est",
    "csun": "sun",
    "ct": "at",
    "ct": "cb",
    "ct": "it",
    "ct": "rt",
    "ctach": "catch",
    "cto": "ceo",
    "cts": "its",
    "cty": "city",
    "cu": "icu",
    "cu": "u",
    "cuaght": "caught",
    "cuase": "case",
    "cuase": "cause",
    "cught": "caught",
    "cuh": "cuz",
    "cuhz": "cuz",
    "culd": "could",
    "cum": "cuz",
    "cuming": "coming",
    "cumz": "cuz",
    "cunty": "county",
    "cuple": "couple",
    "curently": "currently",
    "curiuos": "curious",
    "currenlty": "currently",
    "currentley": "currently",
    "currenty": "currently",
    "curtesy": "courtesy",
    "cus": "bus",
    "cus": "cuz",
    "cus": "us",
    "cuse": "cause",
    "cust": "just",
    "cust": "must",
    "customisable": "customizable",
    "customized": "customised",
    "cuty": "city",
    "cuzo": "cuz",
    "cuzz": "cuz",
    "cy": "my",
    "cyan": "can",
    "cyrius": "cyrus",
    "cz": "cuz",
    "da": "a",
    "da": "do",
    "da": "ds",
    "da": "la",
    "daa": "da",
    "daa": "data",
    "daay": "day",
    "dady": "dad",
    "dag": "day",
    "dah": "da",
    "dah": "day",
    "daignosed": "diagnosed",
    "daly": "day",
    "damagd": "damaged",
    "damb": "damn",
    "damm": "damn",
    "dammn": "damn",
    "damnn": "damn",
    "damoa": "samoa",
    "dan": "an",
    "dan": "can",
    "dan": "dad",
    "dan": "damn",
    "dan": "day",
    "dan": "man",
    "dane": "date",
    "dang": "hang",
    "dangerouse": "dangerous",
    "danm": "damn",
    "danson": "manson",
    "dap": "map",
    "dar": "bar",
    "dar": "far",
    "darw": "dare",
    "das": "as",
    "das": "dad",
    "das": "dans",
    "das": "day",
    "das": "has",
    "das": "was",
    "dat": "at",
    "dat": "da",
    "dat": "day",
    "dat": "hat",
    "dats": "days",
    "dats": "eats",
    "dau": "day",
    "daughtr": "daughter",
    "daugter": "daughter",
    "daugther": "daughter",
    "dave": "have",
    "dave": "save",
    "dave": "wave",
    "daw": "day",
    "dax": "day",
    "daya": "day",
    "dayi": "day",
    "daymn": "damn",
    "dayss": "days",
    "dayy": "day",
    "dayz": "day",
    "dayz": "days",
    "db": "bb",
    "db": "da",
    "db": "do",
    "db": "fb",
    "dc": "da",
    "dc": "do",
    "dc": "doc",
    "dc": "nc",
    "dcctors": "doctors",
    "dcs": "docs",
    "dctor": "doctor",
    "dd": "da",
    "dd": "dad",
    "dd": "did",
    "dd": "do",
    "ddi": "did",
    "ddnt": "didnt",
    "ddnt": "dont",
    "ddot": "dot",
    "ddsgusting": "disgusting",
    "de": "be",
    "de": "da",
    "de": "do",
    "de": "he",
    "de": "me",
    "de": "we",
    "deah": "death",
    "dealths": "deaths",
    "deap": "dead",
    "deaprtment": "department",
    "deask": "desk",
    "debatinn": "debating",
    "debo": "demo",
    "dec": "dev",
    "decal": "deal",
    "decalres": "declares",
    "deceided": "decided",
    "deciced": "decided",
    "decidded": "decided",
    "decied": "decided",
    "deciede": "decide",
    "decieded": "decided",
    "deciided": "decided",
    "decist": "desist",
    "decited": "decided",
    "deckk": "deck",
    "decktop": "desktop",
    "declaired": "declared",
    "declars": "declares",
    "decleared": "declared",
    "decloared": "declared",
    "declrared": "declared",
    "decsent": "decent",
    "ded": "dead",
    "dee": "see",
    "defenitely": "definitely",
    "definately": "definitely",
    "definetely": "definitely",
    "definiation": "definition",
    "definitelly": "definitely",
    "definitley": "definitely",
    "definitly": "definitely",
    "definityly": "definitely",
    "defintely": "definitely",
    "defintitely": "definitely",
    "defo": "demo",
    "defunitely": "definitely",
    "deh": "dev",
    "deinitely": "definitely",
    "dekstop": "desktop",
    "del": "dev",
    "dela": "deal",
    "delcared": "declared",
    "delcares": "declares",
    "delclared": "declared",
    "dem": "de",
    "dem": "dev",
    "dem": "oem",
    "demond": "demon",
    "dennis": "tennis",
    "denocracy": "democracy",
    "deosnt": "doesnt",
    "depa": "dept",
    "deparment": "department",
    "depeneds": "depends",
    "deperately": "desperately",
    "depnds": "depends",
    "der": "dem",
    "der": "dev",
    "der": "her",
    "dere": "here",
    "derive": "drive",
    "des": "does",
    "descide": "decide",
    "descovered": "discovered",
    "desgners": "designers",
    "deside": "decide",
    "desided": "decided",
    "desiging": "designing",
    "desing": "design",
    "desingners": "designers",
    "deskop": "desktop",
    "deskx": "desk",
    "desparately": "desperately",
    "desperatly": "desperately",
    "desse": "desde",
    "destkop": "desktop",
    "destop": "desktop",
    "det": "get",
    "detals": "details",
    "deth": "death",
    "dev": "de",
    "devcided": "decided",
    "deve": "dev",
    "develeper": "developer",
    "develepment": "development",
    "developerr": "developer",
    "developmers": "developers",
    "developp": "develop",
    "developp": "develops",
    "developper": "developer",
    "developpers": "developers",
    "develpo": "develop",
    "devided": "decided",
    "devie": "device",
    "devleoper": "developer",
    "devleoping": "developing",
    "devleopment": "development",
    "devloper": "developer",
    "devlopment": "development",
    "devoloper": "developer",
    "devolopment": "development",
    "dewd": "dead",
    "dext": "next",
    "dextor": "dexter",
    "dey": "day",
    "df": "do",
    "df": "if",
    "df": "of",
    "dfo": "do",
    "dg": "da",
    "dg": "do",
    "dh": "da",
    "dha": "da",
    "dhat": "that",
    "dhats": "thats",
    "dhe": "the",
    "dhey": "they",
    "dhis": "this",
    "dhot": "shot",
    "di": "da",
    "di": "do",
    "di": "i",
    "dia": "da",
    "dia": "die",
    "dia": "via",
    "diaganosed": "diagnosed",
    "diagnoesed": "diagnosed",
    "diagnoised": "diagnosed",
    "diagnoset": "diagnosed",
    "diagnsed": "diagnosed",
    "diangosed": "diagnosed",
    "dianosed": "diagnosed",
    "dicide": "decide",
    "dicked": "picked",
    "dicovered": "discovered",
    "dics": "docs",
    "dictor": "doctor",
    "didd": "did",
    "diddnt": "didnt",
    "dident": "didnt",
    "didi": "did",
    "didint": "didnt",
    "didmt": "didnt",
    "didn": "did",
    "didnr": "didnt",
    "didntb": "didnt",
    "didny": "didnt",
    "dids": "did",
    "didt": "did",
    "didt": "didnt",
    "diect": "direct",
    "diedd": "died",
    "dieds": "died",
    "diei": "die",
    "diend": "died",
    "diference": "difference",
    "diferent": "different",
    "differencce": "difference",
    "differeny": "different",
    "differewnce": "difference",
    "differnet": "different",
    "differnt": "different",
    "differrnt": "different",
    "diffrence": "difference",
    "diffrent": "different",
    "diffricult": "difficult",
    "diggign": "digging",
    "digitial": "digital",
    "dignosed": "diagnosed",
    "diid": "did",
    "diidnt": "didnt",
    "dimaond": "diamond",
    "ding": "ping",
    "diognosed": "diagnosed",
    "dir": "did",
    "directcly": "directly",
    "directley": "directly",
    "dis": "did",
    "dis": "his",
    "dis": "is",
    "disapointed": "disappointed",
    "disappeard": "disappears",
    "disappinted": "disappointed",
    "discoverd": "discovered",
    "discovererd": "discovered",
    "diseny": "disney",
    "disgnosed": "diagnosed",
    "disimisses": "dismisses",
    "disist": "desist",
    "dispite": "despite",
    "diss": "miss",
    "diss": "piss",
    "dissappointed": "disappointed",
    "dissed": "missed",
    "dissing": "missing",
    "distroy": "destroy",
    "dit": "it",
    "diwn": "down",
    "diwnload": "download",
    "diwnloaded": "downloaded",
    "dix": "six",
    "diy": "day",
    "diy": "did",
    "dj": "do",
    "dj": "doj",
    "dj": "ds",
    "djing": "doing",
    "djing": "dying",
    "dk": "do",
    "dk": "idk",
    "dk": "sdk",
    "dl": "do",
    "dling": "doing",
    "dll": "all",
    "dlove": "love",
    "dm": "am",
    "dm": "da",
    "dm": "de",
    "dm": "do",
    "dm": "im",
    "dmb": "dm",
    "dmb": "mb",
    "dmd": "did",
    "dming": "doing",
    "dmm": "dm",
    "dms": "mms",
    "dn": "an",
    "dn": "do",
    "dn": "in",
    "dn": "on",
    "dnd": "and",
    "dnd": "end",
    "dne": "done",
    "dno": "do",
    "dno": "kno",
    "dno": "no",
    "dnt": "dont",
    "doa": "do",
    "docotor": "doctor",
    "docotr": "doctor",
    "docs": "does",
    "docs": "dogs",
    "docter": "doctor",
    "docters": "doctors",
    "doctoe": "doctor",
    "doctoes": "doctors",
    "doctorb": "doctors",
    "doctori": "doctor",
    "doctorr": "doctor",
    "doctorss": "doctors",
    "dod": "did",
    "dod": "do",
    "doding": "doing",
    "dodnt": "dont",
    "doea": "does",
    "doed": "died",
    "doenst": "doesnt",
    "doent": "dont",
    "doesent": "doesnt",
    "doeses": "doses",
    "doesn": "does",
    "doesnot": "doesnt",
    "doest": "does",
    "doest": "doesnt",
    "doez": "does",
    "dogg": "dog",
    "doh": "do",
    "doh": "oh",
    "doi": "do",
    "doid": "did",
    "doiing": "doing",
    "doin": "down",
    "doin": "goin",
    "doin": "join",
    "doint": "dont",
    "doj": "do",
    "doktors": "doctors",
    "dollers": "dollars",
    "dollor": "dollar",
    "dom": "do",
    "dom": "doc",
    "doming": "coming",
    "domt": "dont",
    "dondt": "dont",
    "dong": "doing",
    "donic": "sonic",
    "donjt": "dont",
    "donk": "dont",
    "donkt": "dont",
    "donload": "download",
    "donlt": "dont",
    "donno": "dunno",
    "donnt": "dont",
    "dono": "dont",
    "donot": "dont",
    "donr": "done",
    "donr": "dont",
    "donst": "dont",
    "dont": "done",
    "dont": "wont",
    "dontt": "dont",
    "donut": "dont",
    "donw": "down",
    "donwgrade": "downgrade",
    "donwload": "download",
    "donwloaded": "downloaded",
    "donwnloaded": "downloaded",
    "dony": "dont",
    "doo": "do",
    "doo": "too",
    "dood": "good",
    "doodler": "doodle",
    "doodler": "doodles",
    "dooesnt": "doesnt",
    "doogle": "doodle",
    "dop": "do",
    "dopped": "dropped",
    "dopping": "dropping",
    "doqn": "down",
    "dor": "for",
    "dores": "does",
    "dork": "dock",
    "dork": "work",
    "dorking": "working",
    "dosent": "doesnt",
    "doslreports": "dslreports",
    "dosnt": "doesnt",
    "dosnt": "dont",
    "dotn": "dont",
    "dotor": "doctor",
    "dou": "do",
    "dou": "you",
    "doubht": "doubt",
    "dould": "would",
    "dous": "does",
    "dow": "do",
    "dow": "how",
    "dow": "now",
    "dowb": "down",
    "dowh": "down",
    "dowload": "download",
    "dowloaded": "downloaded",
    "dowloading": "downloading",
    "dowm": "down",
    "downdoad": "download",
    "downi": "down",
    "downkoad": "download",
    "downlaod": "download",
    "downlaoded": "downloaded",
    "downliad": "download",
    "downliaded": "downloaded",
    "downloaden": "downloaded",
    "downloadn": "download",
    "downloads": "dowloads",
    "downloaed": "downloaded",
    "downloan": "download",
    "downloard": "download",
    "downloded": "downloaded",
    "downoad": "download",
    "downoaded": "downloaded",
    "dox": "doc",
    "doz": "do",
    "dp": "do",
    "dp": "up",
    "dpends": "depends",
    "dplay": "play",
    "dr": "di",
    "dr": "dm",
    "dr": "do",
    "dr": "or",
    "dr": "ur",
    "dra": "dr",
    "draded": "dreaded",
    "dre": "are",
    "dre": "dry",
    "dreakm": "dream",
    "dredded": "dreaded",
    "dreded": "dreaded",
    "driend": "friend",
    "dril": "drill",
    "drilll": "drill",
    "driod": "droid",
    "dro": "do",
    "drobbox": "dropbox",
    "dropd": "drop",
    "droped": "dropped",
    "droping": "dropping",
    "dropox": "dropbox",
    "droppd": "dropped",
    "droppped": "dropped",
    "dropxox": "dropbox",
    "drpped": "dropped",
    "dryll": "drill",
    "ds": "ads",
    "ds": "as",
    "ds": "do",
    "ds": "is",
    "ds": "ms",
    "ds": "os",
    "ds": "us",
    "dsa": "usa",
    "dsi": "ds",
    "dsnt": "dont",
    "dsnt": "isnt",
    "dswine": "swine",
    "dt": "it",
    "dto": "to",
    "dtopped": "dropped",
    "dtunes": "itunes",
    "du": "da",
    "du": "do",
    "du": "u",
    "duaghter": "daughter",
    "dubt": "doubt",
    "duh": "due",
    "dum": "due",
    "dumn": "damn",
    "dungen": "dungeon",
    "dunnoo": "dunno",
    "dunnow": "dunno",
    "duno": "dunno",
    "dunt": "dnt",
    "dunt": "dont",
    "dup": "up",
    "dur": "due",
    "durinf": "during",
    "durng": "during",
    "durning": "during",
    "durring": "during",
    "dv": "tv",
    "dvd": "dad",
    "dvd": "did",
    "dw": "do",
    "dwas": "was",
    "dwess": "dress",
    "dwine": "swine",
    "dwn": "down",
    "dwnload": "download",
    "dwnloaded": "downloaded",
    "dwnloading": "downloading",
    "dwo": "do",
    "dwonload": "download",
    "dwonloaded": "downloaded",
    "dx": "do",
    "dx": "xd",
    "dy": "day",
    "dyeng": "dying",
    "dyinh": "dying",
    "dyou": "you",
    "dyying": "dying",
    "ea": "a",
    "ea": "tea",
    "ead": "dead",
    "ead": "head",
    "ead": "read",
    "eady": "ready",
    "ealier": "earlier",
    "ealy": "early",
    "eangine": "engine",
    "eant": "want",
    "earch": "search",
    "earching": "searching",
    "earh": "earth",
    "earhquake": "earthquake",
    "earht": "earth",
    "earleir": "earlier",
    "earler": "earlier",
    "earlies": "earlier",
    "earthquare": "earthquake",
    "earthqyake": "earthquake",
    "earthwom": "earthworm",
    "eartquake": "earthquake",
    "earty": "earth",
    "earyl": "early",
    "eas": "as",
    "eas": "has",
    "eas": "was",
    "easer": "easier",
    "easly": "easily",
    "easonal": "seasonal",
    "eastest": "easiest",
    "eastest": "fastest",
    "easyier": "easier",
    "eathquake": "earthquake",
    "eave": "wave",
    "eazy": "easy",
    "eb": "be",
    "eb": "web",
    "ebay": "bay",
    "eben": "been",
    "ebery": "every",
    "ebook": "book",
    "ebooks": "books",
    "ebst": "best",
    "eby": "ebay",
    "eccept": "except",
    "echfon": "echofon",
    "echofin": "echofon",
    "ecofon": "echofon",
    "ecpecially": "especially",
    "ecperience": "experience",
    "ed": "ad",
    "ed": "bed",
    "ed": "e",
    "ed": "en",
    "ed": "end",
    "editig": "editing",
    "editon": "edition",
    "edn": "end",
    "edtion": "edition",
    "educaitonal": "educational",
    "eearth": "earth",
    "eed": "need",
    "eee": "eve",
    "eee": "see",
    "eeek": "peek",
    "eek": "geek",
    "eeks": "weeks",
    "een": "been",
    "een": "even",
    "eer": "er",
    "eer": "ever",
    "eere": "were",
    "ef": "of",
    "effict": "effect",
    "egen": "even",
    "egift": "gift",
    "eglish": "english",
    "ehas": "has",
    "ehen": "when",
    "eher": "her",
    "eho": "who",
    "ehow": "how",
    "ei": "i",
    "eid": "kid",
    "eiffell": "eiffel",
    "eiffle": "eiffel",
    "eill": "will",
    "eim": "im",
    "ein": "in",
    "eit": "it",
    "eith": "with",
    "eithr": "either",
    "elae": "else",
    "elase": "else",
    "elce": "else",
    "elemantary": "elementary",
    "eles": "elses",
    "elese": "else",
    "elieve": "believe",
    "ell": "all",
    "elp": "help",
    "elsee": "else",
    "elus": "telus",
    "em": "am",
    "em": "e",
    "em": "fm",
    "em": "im",
    "em": "me",
    "emac": "mac",
    "email": "gmail",
    "email": "mail",
    "emaild": "email",
    "emaill": "email",
    "emal": "email",
    "eman": "man",
    "embedd": "embed",
    "embeed": "embed",
    "emercency": "emergency",
    "emergancy": "emergency",
    "emergencey": "emergency",
    "emergnecy": "emergency",
    "emerqency": "emergency",
    "emglish": "english",
    "emrgency": "emergency",
    "en": "an",
    "en": "e",
    "en": "in",
    "en": "on",
    "enalbe": "enable",
    "enaugh": "enough",
    "enchance": "enhance",
    "enen": "even",
    "energey": "energy",
    "enews": "news",
    "enfected": "infected",
    "eng": "end",
    "engilsh": "english",
    "engish": "english",
    "englih": "english",
    "englisch": "english",
    "engnies": "engines",
    "engrish": "english",
    "enigne": "engine",
    "eno": "end",
    "eno": "no",
    "enogh": "enough",
    "enought": "enough",
    "enougn": "enough",
    "enouqh": "enough",
    "enspired": "inspired",
    "ent": "went",
    "entere": "enter",
    "entierly": "entirely",
    "entirly": "entirely",
    "entorely": "entirely",
    "entre": "enter",
    "enuff": "enuf",
    "enugh": "enough",
    "envention": "invention",
    "envite": "invite",
    "enw": "new",
    "enybody": "anybody",
    "eof": "of",
    "eonline": "online",
    "eonly": "only",
    "eop": "top",
    "eople": "people",
    "eorge": "george",
    "eorks": "works",
    "eother": "other",
    "eould": "could",
    "eover": "over",
    "ep": "en",
    "ep": "up",
    "epademic": "epidemic",
    "epedemic": "epidemic",
    "ephone": "iphone",
    "epidmic": "epidemic",
    "epidsemic": "epidemic",
    "eportfolios": "portfolios",
    "epp": "app",
    "epxlain": "explain",
    "equivalrnt": "equivalent",
    "equvalent": "equivalent",
    "erally": "really",
    "erath": "earth",
    "ereader": "reader",
    "ericson": "ericsson",
    "erik": "eric",
    "erlier": "earlier",
    "ery": "try",
    "es": "as",
    "es": "ea",
    "es": "en",
    "es": "is",
    "es": "os",
    "es": "vs",
    "escpecially": "especially",
    "ese": "use",
    "esle": "else",
    "espacially": "especially",
    "especiallly": "especially",
    "especialy": "especially",
    "espeically": "especially",
    "espose": "expose",
    "espresson": "espresso",
    "essenger": "messenger",
    "est": "set",
    "est": "test",
    "eswine": "swine",
    "et": "at",
    "et": "get",
    "et": "it",
    "et": "let",
    "et": "rt",
    "etam": "team",
    "ethan": "than",
    "ethe": "the",
    "etsy": "easy",
    "etting": "setting",
    "etv": "tv",
    "eu": "e",
    "eu": "en",
    "eu": "u",
    "eugh": "ugh",
    "eun": "fun",
    "europex": "europe",
    "eurpean": "european",
    "ev": "dev",
    "evan": "even",
    "evar": "ever",
    "evean": "even",
    "evebn": "even",
    "eveen": "even",
    "evem": "ever",
    "evenn": "even",
    "everbody": "everybody",
    "evernyone": "everyone",
    "evero": "ever",
    "everone": "everyone",
    "everr": "ever",
    "everr": "every",
    "everthing": "everything",
    "evertything": "everything",
    "everyonee": "everyone",
    "everyonr": "everyone",
    "everyopne": "everyone",
    "everythig": "everything",
    "everythinq": "everything",
    "everythjng": "everything",
    "everyting": "everything",
    "evey": "every",
    "eveyone": "everyone",
    "eveything": "everything",
    "evindence": "evidence",
    "evn": "even",
    "evr": "ever",
    "evre": "ever",
    "evrrything": "everything",
    "evry": "every",
    "evry": "very",
    "evrybody": "everybody",
    "evryone": "everyone",
    "evrything": "everything",
    "evrytime": "everytime",
    "evul": "evil",
    "ew": "new",
    "ew": "w",
    "ewant": "want",
    "ews": "news",
    "exacly": "exactly",
    "exactky": "exactly",
    "examsa": "exams",
    "exaplain": "explain",
    "exatly": "exactly",
    "excactly": "exactly",
    "excected": "expected",
    "excercise": "exercise",
    "exchage": "exchange",
    "exchnage": "exchange",
    "excied": "excited",
    "excitd": "excited",
    "excitied": "excited",
    "excitted": "excited",
    "exclsuive": "exclusive",
    "exclusieve": "exclusive",
    "excpt": "except",
    "exctied": "excited",
    "exectly": "exactly",
    "exericise": "exercise",
    "exhcange": "exchange",
    "exhofon": "echofon",
    "exicited": "excited",
    "exicted": "excited",
    "existance": "existence",
    "exlporing": "exploring",
    "exlusive": "exclusive",
    "expain": "explain",
    "expalin": "explain",
    "expecially": "especially",
    "expectede": "expected",
    "expercience": "experience",
    "experia": "xperia",
    "experiecne": "experience",
    "experiense": "experience",
    "experince": "experience",
    "expierience": "experience",
    "explaied": "explained",
    "explaination": "explanation",
    "explaind": "explained",
    "explaing": "explain",
    "explan": "explain",
    "explanantion": "explanation",
    "explaned": "explained",
    "explaning": "explaining",
    "explantion": "explanation",
    "explenation": "explanation",
    "explian": "explain",
    "explination": "explanation",
    "exploder": "explorer",
    "explorring": "exploring",
    "explose": "expose",
    "exporer": "explorer",
    "exposded": "exposed",
    "expresso": "espresso",
    "exspecially": "especially",
    "exsplain": "explain",
    "ext": "next",
    "exta": "extra",
    "extention": "extension",
    "extentions": "extensions",
    "extre": "extra",
    "extreame": "extreme",
    "extry": "extra",
    "ey": "hey",
    "eyez": "eyes",
    "eyou": "you",
    "eyre": "eye",
    "ezperience": "experience",
    "f_ck": "fuck",
    "f_u": "flu",
    "facbook": "facebook",
    "facebbok": "facebook",
    "facebok": "facebook",
    "faceboon": "facebook",
    "facefook": "facebook",
    "faceook": "facebook",
    "fack": "fuck",
    "fackbook": "facebook",
    "facorite": "favorite",
    "facrbook": "facebook",
    "factbook": "facebook",
    "facus": "focus",
    "faebook": "facebook",
    "fael": "feel",
    "fainally": "finally",
    "fakt": "fact",
    "falking": "talking",
    "fally": "fall",
    "fam": "am",
    "fam": "fan",
    "fam": "far",
    "fam": "fm",
    "familar": "familiar",
    "familey": "family",
    "familier": "familiar",
    "familiy": "family",
    "familliar": "familiar",
    "familt": "family",
    "familu": "family",
    "familyy": "family",
    "famiy": "family",
    "famliy": "family",
    "fanally": "finally",
    "fanasy": "fantasy",
    "fanily": "family",
    "fanz": "fan",
    "faq": "far",
    "farward": "forward",
    "faught": "caught",
    "fave": "face",
    "fave": "have",
    "fave": "wave",
    "favo": "fav",
    "favoirte": "favorite",
    "favorate": "favorite",
    "favoritee": "favorite",
    "favortie": "favorite",
    "favorute": "favorite",
    "favouriye": "favourite",
    "favre": "farve",
    "favroite": "favorite",
    "faw": "fav",
    "fax": "fix",
    "fb": "bb",
    "fb": "fm",
    "fbook": "book",
    "fc": "fcc",
    "fcebook": "facebook",
    "fck": "fuck",
    "fcked": "fucked",
    "fcking": "fucking",
    "fcuk": "fuck",
    "fcukin": "fuckin",
    "fcuking": "fucking",
    "fcus": "focus",
    "fda": "da",
    "fdo": "do",
    "fdor": "for",
    "fe": "me",
    "feal": "feel",
    "fealing": "feeling",
    "featue": "feature",
    "feauture": "feature",
    "feautures": "features",
    "feaver": "fever",
    "feb": "few",
    "feb": "web",
    "feck": "fuck",
    "feck": "heck",
    "fecked": "fucked",
    "feedz": "feeds",
    "feeel": "feel",
    "feeeling": "feeling",
    "feeels": "feels",
    "feek": "feel",
    "feeld": "feel",
    "feeld": "feels",
    "feelf": "feel",
    "feelig": "feeling",
    "feelign": "feeling",
    "feelinn": "feeling",
    "feelinq": "feeling",
    "feelins": "feeling",
    "feell": "feel",
    "feell": "feels",
    "feelling": "feeling",
    "feeln": "feel",
    "feelng": "feeling",
    "feelong": "feeling",
    "feelt": "feel",
    "feelz": "feel",
    "feelz": "feels",
    "feening": "feeling",
    "feew": "few",
    "feh": "few",
    "feiel": "feel",
    "feiends": "friends",
    "fel": "feel",
    "feling": "feeling",
    "felliw": "fellow",
    "fellowed": "followed",
    "felp": "help",
    "fely": "felt",
    "femaile": "female",
    "fense": "fence",
    "fer": "for",
    "fergot": "forgot",
    "ferw": "few",
    "fesktop": "desktop",
    "fest": "best",
    "fest": "rest",
    "fest": "test",
    "festval": "festival",
    "fet": "get",
    "fetaures": "features",
    "feveer": "fever",
    "feverr": "fever",
    "fewls": "feels",
    "feww": "few",
    "ff": "fb",
    "ff": "if",
    "ff": "of",
    "ff": "off",
    "ffice": "office",
    "ffind": "find",
    "ffixed": "fixed",
    "ffor": "for",
    "ffrom": "from",
    "fght": "fight",
    "fgor": "for",
    "fhat": "that",
    "fhe": "the",
    "fi": "i",
    "fi": "if",
    "fiamily": "family",
    "fianally": "finally",
    "fianlly": "finally",
    "ficition": "fiction",
    "ficiton": "fiction",
    "fiest": "first",
    "figd": "find",
    "fighing": "fighting",
    "fightinhg": "fighting",
    "fightning": "fighting",
    "figiring": "figuring",
    "figture": "figure",
    "figue": "figure",
    "figuerd": "figured",
    "figuered": "figured",
    "figuire": "figure",
    "figurd": "figure",
    "figurd": "figured",
    "figuren": "figure",
    "fii": "fit",
    "fii": "wii",
    "fiinally": "finally",
    "fiind": "find",
    "fiirst": "first",
    "fiit": "fit",
    "filp": "flip",
    "fimally": "finally",
    "fina": "find",
    "finalley": "finally",
    "finallly": "finally",
    "finallt": "finally",
    "finaly": "finally",
    "finalyl": "finally",
    "finalzly": "finally",
    "finda": "find",
    "findd": "find",
    "findo": "find",
    "fineally": "finally",
    "finelly": "finally",
    "fing": "find",
    "fing": "ping",
    "fingure": "figure",
    "finially": "finally",
    "finilly": "finally",
    "finised": "finished",
    "finishd": "finished",
    "finlly": "finally",
    "finnally": "finally",
    "finnish": "finish",
    "finnished": "finished",
    "finshed": "finished",
    "finsihed": "finished",
    "fint": "find",
    "fintasy": "fantasy",
    "finully": "finally",
    "fiot": "fit",
    "firat": "first",
    "firday": "friday",
    "firend": "friend",
    "firends": "friends",
    "firest": "first",
    "firfox": "firefox",
    "firgure": "figure",
    "firmwave": "firmware",
    "firsr": "first",
    "fis": "is",
    "fisrt": "first",
    "fisure": "figure",
    "fitn": "fit",
    "fitst": "first",
    "fitt": "fit",
    "fiu": "flu",
    "fixd": "fixed",
    "fixex": "fixed",
    "fiy": "fit",
    "fk": "fm",
    "fkn": "fun",
    "fku": "flu",
    "fl": "nfl",
    "fla": "flu",
    "flach": "flash",
    "flavor": "favor",
    "fli": "flu",
    "flicke": "flickr",
    "flicky": "flickr",
    "flikr": "flickr",
    "fllowing": "following",
    "flo": "flu",
    "flook": "floor",
    "flor": "floor",
    "flove": "love",
    "flr": "flu",
    "fls": "flu",
    "flt": "flu",
    "flua": "flu",
    "fluck": "fuck",
    "flucking": "fucking",
    "flui": "flu",
    "flul": "flu",
    "fluo": "flu",
    "fluss": "fuss",
    "flut": "flu",
    "fluu": "flu",
    "fluv": "flu",
    "fluw": "flu",
    "fluy": "flu",
    "flv": "flu",
    "fm": "am",
    "fm": "dm",
    "fm": "im",
    "fmr": "for",
    "fms": "mms",
    "fmy": "my",
    "fn": "an",
    "fn": "fun",
    "fn": "on",
    "fnally": "finally",
    "fnd": "find",
    "fnding": "finding",
    "fnew": "new",
    "fo": "do",
    "fo": "no",
    "fo": "of",
    "fo": "so",
    "fo": "to",
    "foa": "for",
    "fock": "fuck",
    "focking": "fucking",
    "focos": "focus",
    "fod": "food",
    "fodd": "food",
    "foer": "for",
    "fof": "for",
    "fof": "of",
    "fogot": "forgot",
    "foh": "for",
    "foi": "for",
    "foing": "going",
    "foir": "for",
    "foitness": "fitness",
    "foll": "toll",
    "folllow": "follow",
    "followw": "follow",
    "follw": "follow",
    "folow": "follow",
    "folowing": "following",
    "folr": "for",
    "fom": "for",
    "fom": "from",
    "fon": "for",
    "fon": "fun",
    "fon": "on",
    "fonally": "finally",
    "fone": "done",
    "fone": "gone",
    "fone": "one",
    "fong": "long",
    "foo": "for",
    "foodd": "food",
    "foogle": "google",
    "fook": "book",
    "foood": "food",
    "foor": "for",
    "foos": "food",
    "foound": "found",
    "fora": "for",
    "forawrd": "forward",
    "forb": "for",
    "forceing": "forcing",
    "forcez": "forces",
    "fordward": "forward",
    "forevr": "forever",
    "foreward": "forward",
    "forf": "for",
    "forgott": "forgot",
    "forgrt": "forget",
    "forh": "for",
    "formerley": "formerly",
    "formware": "firmware",
    "forn": "for",
    "forr": "for",
    "forrmerly": "formerly",
    "forst": "first",
    "foru": "for",
    "forver": "forever",
    "forwad": "forward",
    "forword": "forward",
    "forwrad": "forward",
    "forwrard": "forward",
    "fory": "for",
    "fot": "for",
    "fot": "got",
    "fot": "not",
    "fotr": "for",
    "fou": "flu",
    "fou": "for",
    "fou": "you",
    "foud": "found",
    "foudn": "found",
    "fouind": "found",
    "foundd": "found",
    "founf": "found",
    "founfd": "found",
    "fouund": "found",
    "fow": "for",
    "foward": "forward",
    "fown": "down",
    "foy": "for",
    "fp": "ap",
    "fp": "up",
    "fpa": "fda",
    "fpr": "for",
    "fps": "gps",
    "fr": "for",
    "fr": "or",
    "fraid": "afraid",
    "fram": "from",
    "francsico": "francisco",
    "franfurt": "frankfurt",
    "franscisco": "francisco",
    "fransisco": "francisco",
    "fre": "free",
    "freacking": "freaking",
    "freakn": "freaks",
    "fred": "free",
    "freee": "free",
    "freek": "free",
    "freeked": "freaked",
    "freeking": "freaking",
    "freeks": "freaks",
    "freie": "free",
    "freind": "friend",
    "freinds": "friends",
    "fren": "free",
    "frenchy": "french",
    "frend": "friend",
    "frend": "trend",
    "frends": "friends",
    "fresers": "freshers",
    "frew": "free",
    "frgot": "forgot",
    "friand": "friend",
    "fridayy": "friday",
    "frieds": "friends",
    "friendss": "friends",
    "friendx": "friends",
    "friennd": "friend",
    "friens": "friends",
    "friiends": "friends",
    "frim": "from",
    "frind": "grind",
    "frinds": "friends",
    "frined": "friend",
    "frineds": "friends",
    "fring": "bring",
    "frist": "first",
    "frive": "drive",
    "frm": "from",
    "frnt": "front",
    "frolm": "from",
    "froma": "from",
    "frome": "from",
    "fromi": "from",
    "fromm": "from",
    "fromn": "from",
    "fromt": "from",
    "fromt": "front",
    "fromy": "from",
    "fron": "from",
    "frony": "front",
    "froom": "from",
    "fror": "for",
    "froward": "forward",
    "frpm": "from",
    "frpom": "from",
    "frr": "for",
    "frree": "free",
    "frshers": "freshers",
    "frst": "first",
    "frtom": "from",
    "fru": "flu",
    "fruck": "fuck",
    "frum": "from",
    "frun": "fun",
    "frunt": "front",
    "frye": "free",
    "fs": "as",
    "fs": "is",
    "fsu": "flu",
    "ftc": "fcc",
    "ftc": "htc",
    "fter": "after",
    "ftom": "from",
    "ftr": "for",
    "ftweeting": "tweeting",
    "fu": "fb",
    "fu": "flu",
    "fu": "u",
    "fuc": "fcc",
    "fucc": "fuck",
    "fucced": "fucked",
    "fuccin": "fuckin",
    "fuccing": "fucking",
    "fuch": "fuck",
    "fucka": "fuck",
    "fuckd": "fucked",
    "fucken": "fuckin",
    "fuckiing": "fucking",
    "fuckimg": "fucking",
    "fuckingg": "fucking",
    "fuckinh": "fucking",
    "fuckinn": "fucking",
    "fuckinq": "fucking",
    "fuckk": "fuck",
    "fuckkng": "fucking",
    "fuckn": "fuckin",
    "fuction": "fiction",
    "fud": "fun",
    "fue": "due",
    "fuguring": "figuring",
    "fuin": "fun",
    "fuji": "fiji",
    "fuk": "fuck",
    "fuk": "uk",
    "fukc": "fuck",
    "fuked": "fucked",
    "fukin": "fuckin",
    "fuking": "fucking",
    "fukk": "fuck",
    "fukkin": "fuckin",
    "fukn": "fun",
    "ful": "flu",
    "ful": "fun",
    "fulll": "full",
    "funally": "finally",
    "func": "fun",
    "funcina": "funciona",
    "fune": "fine",
    "fune": "fun",
    "funf": "fun",
    "funn": "fun",
    "funnest": "funniest",
    "funnn": "funny",
    "funnuest": "funniest",
    "funy": "funny",
    "fuoll": "full",
    "fuqk": "fuck",
    "fus": "fuss",
    "futeure": "future",
    "futher": "further",
    "futness": "fitness",
    "futre": "future",
    "fuul": "full",
    "fuun": "fun",
    "fux": "fun",
    "fuxk": "fuck",
    "fuxking": "fucking",
    "fw": "fm",
    "fwel": "feel",
    "fwhich": "which",
    "fwpwebhost": "wpwebhost",
    "fwrd": "fwd",
    "fx": "fm",
    "fxck": "fuck",
    "fxcking": "fucking",
    "fy": "my",
    "fyck": "fuck",
    "fye": "eye",
    "g_d": "god",
    "ga": "a",
    "ga": "go",
    "gabe": "game",
    "gace": "gave",
    "gadet": "gadget",
    "gadgert": "gadget",
    "gading": "gaming",
    "gae": "game",
    "gae": "gave",
    "gagdet": "gadget",
    "gald": "glad",
    "galexy": "galaxy",
    "gallary": "gallery",
    "galxy": "galaxy",
    "gamer": "game",
    "gamer": "games",
    "gamers": "games",
    "gamez": "game",
    "gamr": "game",
    "gan": "an",
    "ganalytics": "analytics",
    "gandi": "gandhi",
    "gane": "game",
    "ganhdi": "gandhi",
    "ganna": "gonna",
    "ganna": "wanna",
    "gapps": "apps",
    "gara": "para",
    "gardisil": "gardasil",
    "gatta": "gotta",
    "gb": "b",
    "gb": "go",
    "gbaby": "baby",
    "gbig": "big",
    "gbike": "bike",
    "gbm": "gym",
    "gc": "go",
    "gc": "pc",
    "gd": "go",
    "gd": "god",
    "gdamn": "damn",
    "gdata": "data",
    "gdc": "cdc",
    "gdocs": "docs",
    "gdt": "get",
    "ge": "be",
    "ge": "go",
    "ge": "he",
    "ge": "me",
    "geader": "reader",
    "geat": "great",
    "geath": "death",
    "ged": "get",
    "geek": "peek",
    "geek": "week",
    "geeks": "weeks",
    "geel": "feel",
    "geet": "get",
    "geetin": "gettin",
    "geeting": "getting",
    "geetting": "getting",
    "gef": "get",
    "geh": "get",
    "gek": "get",
    "generatd": "generated",
    "genertion": "generation",
    "genious": "genius",
    "genting": "getting",
    "genuis": "genius",
    "geo": "get",
    "geo": "go",
    "geo": "seo",
    "ger": "get",
    "germany": "german",
    "gero": "hero",
    "gert": "get",
    "gess": "guess",
    "geta": "get",
    "geth": "get",
    "getiing": "getting",
    "getin": "gettin",
    "geting": "getting",
    "getitng": "getting",
    "getn": "get",
    "getn": "gets",
    "gett": "get",
    "getta": "gotta",
    "getteing": "getting",
    "getten": "gettin",
    "gettig": "getting",
    "gettign": "getting",
    "gettihg": "getting",
    "gettiin": "gettin",
    "gettiing": "getting",
    "gettimg": "getting",
    "gettina": "getting",
    "gettinb": "getting",
    "gettingg": "getting",
    "gettinh": "getting",
    "gettinng": "getting",
    "gettinq": "getting",
    "gettins": "getting",
    "gettint": "getting",
    "gettitng": "getting",
    "gettling": "getting",
    "gettn": "gettin",
    "gettng": "getting",
    "gettong": "getting",
    "getts": "gets",
    "getttin": "gettin",
    "gettting": "getting",
    "gety": "get",
    "getying": "getting",
    "getz": "get",
    "getz": "gets",
    "geuss": "guess",
    "gey": "get",
    "gey": "hey",
    "geyt": "get",
    "gf": "go",
    "gf": "if",
    "gf": "of",
    "gflash": "flash",
    "gfor": "for",
    "gg": "go",
    "ggds": "gods",
    "gget": "get",
    "gh": "go",
    "ghave": "have",
    "ghe": "the",
    "ghet": "get",
    "gho": "go",
    "ghot": "got",
    "ghots": "shots",
    "gi": "go",
    "gi": "gti",
    "gi": "i",
    "gia": "via",
    "gid": "god",
    "gies": "goes",
    "giive": "give",
    "gilmpse": "glimpse",
    "gilr": "girl",
    "ging": "going",
    "giong": "going",
    "giot": "got",
    "girlss": "girls",
    "girly": "girl",
    "girlz": "girl",
    "girst": "first",
    "gis": "gps",
    "gis": "is",
    "gistory": "history",
    "git": "fit",
    "git": "get",
    "git": "got",
    "git": "it",
    "gith": "with",
    "gittin": "gettin",
    "gitting": "getting",
    "giude": "guide",
    "giuy": "guy",
    "giva": "give",
    "givaway": "giveaway",
    "givbe": "give",
    "giveway": "giveaway",
    "givien": "given",
    "givin": "given",
    "givn": "give",
    "givn": "given",
    "givng": "giving",
    "givs": "give",
    "givs": "gives",
    "givw": "give",
    "givz": "give",
    "gl": "go",
    "glaad": "glad",
    "glas": "glass",
    "glasss": "glass",
    "glimpes": "glimpse",
    "glist": "list",
    "glod": "god",
    "glu": "flu",
    "gluck": "luck",
    "gm": "go",
    "gm": "gym",
    "gmaes": "games",
    "gmail": "email",
    "gmail": "mail",
    "gmaili": "gmail",
    "gmaill": "gmail",
    "gmails": "emails",
    "gmailz": "gmail",
    "gmaps": "maps",
    "gme": "game",
    "gmsil": "gmail",
    "gmt": "get",
    "gn": "go",
    "gn": "in",
    "gn": "on",
    "gnna": "gonna",
    "gnoogle": "google",
    "gnow": "now",
    "goa": "go",
    "goanna": "gonna",
    "godd": "god",
    "godd": "good",
    "godgle": "google",
    "godness": "goodness",
    "goe": "go",
    "goe": "got",
    "goeing": "going",
    "goen": "goes",
    "goen": "goin",
    "goet": "get",
    "goet": "got",
    "goez": "goes",
    "gogle": "google",
    "gogole": "google",
    "goht": "got",
    "goi": "go",
    "goid": "good",
    "goig": "going",
    "goigle": "google",
    "goign": "going",
    "goiing": "going",
    "goijng": "going",
    "goina": "gonna",
    "goinfg": "going",
    "goingf": "going",
    "goingg": "going",
    "goingo": "going",
    "goinh": "going",
    "goini": "going",
    "goinn": "going",
    "goinng": "going",
    "goint": "going",
    "gol": "go",
    "goldgen": "golden",
    "gollf": "golf",
    "golng": "going",
    "goming": "coming",
    "goming": "going",
    "gomogle": "google",
    "gon": "go",
    "gon": "got",
    "gon": "on",
    "gona": "gone",
    "gona": "gonna",
    "gonan": "gonna",
    "gonig": "going",
    "gonin": "goin",
    "goning": "going",
    "gonnah": "gonna",
    "gonne": "gonna",
    "gonnna": "gonna",
    "goob": "good",
    "gooble": "google",
    "goodi": "good",
    "goodle": "google",
    "goofle": "google",
    "goog": "good",
    "googe": "google",
    "googel": "google",
    "googgle": "google",
    "googke": "google",
    "googlee": "google",
    "googlei": "google",
    "googler": "google",
    "googley": "google",
    "googlle": "google",
    "googlr": "google",
    "googlw": "google",
    "gooing": "going",
    "goole": "google",
    "goolge": "google",
    "goolgle": "google",
    "goona": "gonna",
    "goong": "going",
    "goood": "good",
    "gooogle": "google",
    "goot": "good",
    "goot": "got",
    "goota": "gotta",
    "goovle": "google",
    "gop": "go",
    "gop": "got",
    "gop": "top",
    "gopod": "good",
    "gopt": "got",
    "gor": "for",
    "gor": "go",
    "gor": "got",
    "gos": "god",
    "gose": "goes",
    "goses": "goes",
    "goshh": "gosh",
    "goss": "goes",
    "goss": "gots",
    "gota": "got",
    "gota": "gotta",
    "gotda": "gotta",
    "goten": "gotten",
    "gotn": "got",
    "goto": "got",
    "gotr": "got",
    "gots": "gets",
    "gots": "goes",
    "gots": "got",
    "gotsa": "gotta",
    "gotst": "gots",
    "gott": "got",
    "gottaa": "gotta",
    "gottah": "gotta",
    "gottal": "gotta",
    "gottan": "gotta",
    "gottan": "gotten",
    "gotting": "getting",
    "gottn": "gotta",
    "gottn": "gotten",
    "gotto": "gotta",
    "gotton": "gotten",
    "gotts": "gots",
    "gotts": "gotta",
    "gottta": "gotta",
    "gottten": "gotten",
    "goty": "got",
    "gotz": "got",
    "gouing": "going",
    "gould": "could",
    "gour": "our",
    "gov": "go",
    "gov": "god",
    "gov": "got",
    "gove": "give",
    "govenrment": "government",
    "goverement": "government",
    "goverment": "government",
    "govt": "got",
    "gowna": "gonna",
    "goy": "got",
    "gp": "gap",
    "gp": "go",
    "gp": "up",
    "gpg": "gps",
    "gphone": "iphone",
    "gphone": "phone",
    "gpl": "gps",
    "gpot": "got",
    "gprs": "gps",
    "gpt": "get",
    "gpt": "got",
    "gpush": "push",
    "gq": "go",
    "gr": "go",
    "gr": "or",
    "graal": "grail",
    "grabed": "grabbed",
    "gracesm": "graces",
    "grat": "great",
    "gray": "gay",
    "gray": "ray",
    "gre": "are",
    "greaat": "great",
    "greader": "reader",
    "grear": "great",
    "greate": "create",
    "greaty": "great",
    "greek": "green",
    "gren": "green",
    "grestest": "greatest",
    "gret": "get",
    "gret": "great",
    "greta": "great",
    "gretest": "greatest",
    "gring": "grind",
    "grl": "girl",
    "gro": "go",
    "groogle": "google",
    "grp": "gap",
    "grrl": "girl",
    "grt": "get",
    "grt": "got",
    "grt": "rt",
    "grug": "drug",
    "gs": "as",
    "gs": "gps",
    "gs": "is",
    "gs": "os",
    "gs": "us",
    "gsm": "gym",
    "gso": "go",
    "gspot": "spot",
    "gst": "get",
    "gsync": "sync",
    "gt": "at",
    "gt": "gb",
    "gt": "get",
    "gt": "go",
    "gt": "got",
    "gt": "it",
    "gt": "rt",
    "gtalk": "talk",
    "gtd": "gti",
    "gte": "get",
    "gthe": "the",
    "gto": "got",
    "gto": "to",
    "gtot": "got",
    "gtreat": "great",
    "gtta": "gotta",
    "gttin": "gettin",
    "gtting": "getting",
    "guap": "gap",
    "guardasil": "gardasil",
    "guees": "guess",
    "gues": "guess",
    "guesss": "guess",
    "gui": "ui",
    "guice": "guide",
    "guiford": "guilford",
    "guinean": "guinea",
    "guiode": "guide",
    "guiter": "guitar",
    "guitqr": "guitar",
    "guituar": "guitar",
    "guive": "give",
    "gunna": "gonna",
    "gunning": "running",
    "gurl": "girl",
    "gurls": "girls",
    "gus": "guys",
    "guss": "guess",
    "gutiar": "guitar",
    "guyes": "guys",
    "guyz": "guys",
    "gv": "go",
    "gv": "gq",
    "gv": "tv",
    "gvae": "gave",
    "gve": "gave",
    "gve": "give",
    "gvie": "give",
    "gving": "giving",
    "gvoice": "voice",
    "gw": "go",
    "gwave": "wave",
    "gweet": "tweet",
    "gwip": "grip",
    "gwoogle": "google",
    "gwot": "got",
    "gwt": "get",
    "gwtting": "getting",
    "gxt": "got",
    "gy": "guy",
    "gy": "my",
    "gz": "go",
    "haa": "has",
    "haad": "had",
    "haaha": "haha",
    "haas": "has",
    "haate": "hate",
    "haave": "have",
    "haaz": "haz",
    "hab": "had",
    "hab": "has",
    "hab": "hav",
    "habds": "hands",
    "habe": "have",
    "habing": "having",
    "hac": "had",
    "hac": "has",
    "hace": "hack",
    "hace": "have",
    "hacve": "have",
    "hada": "had",
    "hadd": "had",
    "hade": "had",
    "hade": "have",
    "hade": "made",
    "hads": "had",
    "hae": "has",
    "hae": "have",
    "haev": "have",
    "haf": "had",
    "haf": "has",
    "hafve": "have",
    "hah": "ha",
    "hah": "had",
    "hah": "has",
    "hahaa": "haha",
    "hahah": "haha",
    "hahh": "haha",
    "hahha": "haha",
    "hahha": "hahaha",
    "hai": "had",
    "hai": "has",
    "hai": "hi",
    "haing": "having",
    "haite": "hate",
    "hallo": "hello",
    "hallowen": "halloween",
    "halp": "help",
    "hame": "home",
    "han": "an",
    "han": "man",
    "handss": "hands",
    "handz": "hands",
    "hane": "have",
    "haning": "hanging",
    "hans": "hand",
    "hans": "hands",
    "haopen": "happen",
    "haox": "hoax",
    "hapen": "happen",
    "hapened": "happened",
    "hapening": "happening",
    "hapens": "happens",
    "happed": "happen",
    "happeded": "happened",
    "happedned": "happened",
    "happend": "happen",
    "happend": "happened",
    "happend": "happens",
    "happended": "happened",
    "happending": "happening",
    "happends": "happens",
    "happenedd": "happened",
    "happent": "happen",
    "happn": "happen",
    "happned": "happened",
    "happns": "happens",
    "happpened": "happened",
    "happpy": "happy",
    "happyy": "happy",
    "hapy": "happy",
    "har": "had",
    "har": "has",
    "har": "hear",
    "hardd": "hard",
    "harly": "hardly",
    "hasd": "had",
    "hase": "has",
    "hase": "have",
    "hasing": "having",
    "hasnt": "wasnt",
    "hass": "has",
    "hastag": "hashtag",
    "hasv": "has",
    "hasz": "has",
    "hater": "hate",
    "haters": "hates",
    "hatey": "hate",
    "hatey": "hates",
    "hatin": "havin",
    "hatte": "hate",
    "haue": "have",
    "hav": "had",
    "hav": "has",
    "hava": "hav",
    "hava": "have",
    "havd": "have",
    "havea": "have",
    "havein": "havin",
    "havet": "have",
    "haveu": "have",
    "havey": "have",
    "havibg": "having",
    "havig": "having",
    "havign": "having",
    "haviing": "having",
    "havina": "having",
    "havingg": "having",
    "havingh": "having",
    "havinh": "having",
    "havinq": "having",
    "havn": "hav",
    "havn": "have",
    "havng": "having",
    "havnig": "having",
    "havnt": "havent",
    "havr": "have",
    "havs": "have",
    "havt": "have",
    "havta": "hava",
    "havung": "having",
    "havv": "have",
    "havve": "have",
    "havw": "have",
    "havz": "have",
    "hax": "had",
    "hayt": "halt",
    "haz": "had",
    "haz": "has",
    "hbope": "hope",
    "hbp": "hop",
    "hc": "htc",
    "hd": "had",
    "hd": "he",
    "hdr": "her",
    "heaadphones": "headphones",
    "headace": "headache",
    "headd": "head",
    "headn": "head",
    "heae": "hear",
    "healhty": "healthy",
    "healty": "healthy",
    "hearding": "hearing",
    "heardly": "hardly",
    "heatd": "heard",
    "heatlh": "health",
    "heatlth": "health",
    "heb": "her",
    "heb": "web",
    "hecc": "heck",
    "hed": "had",
    "hed": "he",
    "hed": "head",
    "hedghog": "hedgehog",
    "hee": "her",
    "hee": "hey",
    "heek": "heck",
    "heey": "hey",
    "heh": "he",
    "heh": "her",
    "heh": "hey",
    "hehe": "here",
    "hek": "he",
    "hek": "heck",
    "hekk": "heck",
    "hekp": "help",
    "hel": "hell",
    "hel": "her",
    "helath": "health",
    "hella": "hell",
    "hella": "hello",
    "helll": "hell",
    "hellz": "hello",
    "helo": "help",
    "helpd": "helps",
    "hels": "help",
    "helth": "health",
    "heng": "hang",
    "heo": "hero",
    "hepl": "help",
    "herad": "heard",
    "heralda": "herald",
    "herer": "here",
    "heres": "theres",
    "herts": "hurts",
    "hest": "best",
    "het": "get",
    "het": "her",
    "heto": "hero",
    "hetting": "getting",
    "hever": "ever",
    "heya": "hey",
    "heyy": "hey",
    "hez": "he",
    "hez": "her",
    "hgappens": "happens",
    "hgd": "had",
    "hh": "he",
    "hha": "haha",
    "hha": "tha",
    "hhad": "had",
    "hhave": "have",
    "hhe": "the",
    "hhow": "how",
    "hhs": "has",
    "hhs": "his",
    "hieghts": "heights",
    "hierachy": "hierarchy",
    "hig": "big",
    "highight": "highlight",
    "highky": "highly",
    "hight": "high",
    "hii": "hi",
    "hii": "wii",
    "hile": "while",
    "hillarious": "hilarious",
    "hiltion": "hilton",
    "himb": "him",
    "hime": "him",
    "hin": "in",
    "hine": "nine",
    "hink": "think",
    "hipe": "hope",
    "hiphone": "iphone",
    "hippy": "happy",
    "hirung": "hiring",
    "hispital": "hospital",
    "hisz": "his",
    "hiting": "hitting",
    "hitler": "hilter",
    "hitt": "hit",
    "hittig": "hitting",
    "hiv": "him",
    "hiv": "hip",
    "hiv": "his",
    "hiv": "hit",
    "hiw": "how",
    "hjave": "have",
    "hjust": "just",
    "hk": "he",
    "hk": "uk",
    "hld": "hold",
    "hlep": "help",
    "hlp": "help",
    "hm": "am",
    "hm": "he",
    "hm": "him",
    "hm": "im",
    "hme": "home",
    "hme": "me",
    "hmm": "him",
    "hn": "on",
    "hobe": "hope",
    "hoem": "home",
    "hoep": "hope",
    "hoge": "home",
    "hoing": "going",
    "hol": "lol",
    "hola": "hold",
    "holdiay": "holiday",
    "holdn": "hold",
    "hollah": "holla",
    "hom": "how",
    "homa": "home",
    "hombrew": "homebrew",
    "homeopage": "homepage",
    "homg": "omg",
    "homie": "home",
    "homne": "home",
    "hompage": "homepage",
    "homw": "home",
    "homwe": "home",
    "hon": "how",
    "hon": "on",
    "hong": "bong",
    "honost": "honest",
    "hoo": "how",
    "hoo": "woo",
    "hoock": "hook",
    "hooe": "hope",
    "hooes": "hoes",
    "hooken": "hooked",
    "hooo": "hoo",
    "hoope": "hope",
    "hooper": "hopper",
    "hoose": "house",
    "hoow": "how",
    "hoox": "hook",
    "hopefuly": "hopefully",
    "hopefylly": "hopefully",
    "hopen": "hope",
    "hoper": "hope",
    "hopew": "hope",
    "hopfully": "hopefully",
    "hopig": "hoping",
    "hopiing": "hoping",
    "hopinf": "hoping",
    "hopital": "hospital",
    "hopn": "hope",
    "hopr": "hope",
    "hopsital": "hospital",
    "hopt": "hope",
    "hopw": "how",
    "hopwfully": "hopefully",
    "hoq": "how",
    "hor": "for",
    "hor": "how",
    "hor": "or",
    "hore": "hope",
    "horible": "horrible",
    "horking": "working",
    "horrable": "horrible",
    "horriable": "horrible",
    "horrile": "horrible",
    "horrrible": "horrible",
    "hors": "hours",
    "hos": "his",
    "hosbital": "hospital",
    "hosipital": "hospital",
    "hospitaized": "hospitalized",
    "hospitalised": "hospitalized",
    "hospitalm": "hospital",
    "hospitial": "hospital",
    "hospitol": "hospital",
    "hosptal": "hospital",
    "hosptial": "hospital",
    "hosptialized": "hospitalized",
    "hoston": "houston",
    "hostpital": "hospital",
    "hosue": "house",
    "hote": "hope",
    "hote": "hot",
    "hotoshop": "photoshop",
    "hots": "shots",
    "hott": "hot",
    "hould": "could",
    "hould": "should",
    "hould": "would",
    "hourr": "hour",
    "housee": "house",
    "housewifes": "housewives",
    "hov": "how",
    "howa": "how",
    "howd": "how",
    "hown": "how",
    "howt": "how",
    "howw": "how",
    "howz": "how",
    "hoy": "how",
    "hpe": "hope",
    "hpoe": "hope",
    "hpome": "home",
    "hpw": "how",
    "hq": "he",
    "hqs": "has",
    "hrd": "had",
    "hrd": "hard",
    "hre": "here",
    "hring": "hiring",
    "hrome": "chrome",
    "hrs": "has",
    "hrs": "his",
    "hs": "has",
    "hs": "he",
    "hs": "his",
    "hs": "is",
    "hs": "os",
    "hs": "us",
    "hsa": "has",
    "hse": "he",
    "hse": "use",
    "hshit": "shit",
    "hsm": "him",
    "hsnd": "hand",
    "hsve": "have",
    "hte": "hate",
    "hte": "the",
    "hthe": "the",
    "htink": "think",
    "htis": "this",
    "htought": "thought",
    "htv": "htc",
    "hu": "he",
    "hu": "u",
    "huck": "fuck",
    "huck": "hack",
    "hucked": "hacked",
    "hugh": "huge",
    "hurtn": "hurts",
    "hurty": "hurts",
    "hurtz": "hurts",
    "huse": "house",
    "husts": "hurts",
    "hv": "hav",
    "hv": "he",
    "hv": "tv",
    "hvae": "have",
    "hve": "have",
    "hve": "he",
    "hvent": "havent",
    "hving": "having",
    "hw": "how",
    "hwas": "was",
    "hwo": "how",
    "hwo": "who",
    "hws": "has",
    "hwy": "why",
    "hy": "why",
    "hype": "hope",
    "hype": "type",
    "hyped": "hype",
    "hyper": "hype",
    "hyprocrite": "hypocrite",
    "ia": "a",
    "ia": "i",
    "ia": "is",
    "ia": "it",
    "iage": "age",
    "ialarm": "alarm",
    "ialways": "always",
    "iam": "am",
    "iam": "im",
    "ian": "an",
    "ian": "can",
    "ian": "in",
    "iapp": "app",
    "iapps": "apps",
    "ias": "has",
    "ias": "is",
    "ib": "i",
    "ib": "in",
    "ib": "it",
    "ibe": "be",
    "iberlin": "berlin",
    "ibiker": "ibike",
    "ibm": "im",
    "ibook": "book",
    "ibricked": "bricked",
    "ibroken": "broken",
    "ic": "if",
    "ic": "in",
    "ic": "it",
    "icable": "cable",
    "ican": "can",
    "icant": "cant",
    "icc": "fcc",
    "ichanged": "changed",
    "ichat": "chat",
    "ick": "sick",
    "icrease": "increase",
    "ics": "pics",
    "ict": "it",
    "ida": "idea",
    "iddea": "idea",
    "idead": "dead",
    "idead": "idea",
    "idear": "idea",
    "ideia": "idea",
    "idek": "idea",
    "idek": "idk",
    "idid": "did",
    "idiodic": "idiotic",
    "idk": "id",
    "idk": "sdk",
    "idkk": "idk",
    "idnt": "dnt",
    "ido": "do",
    "idont": "dont",
    "idrive": "drive",
    "idrop": "drop",
    "idropped": "dropped",
    "ids": "ads",
    "ids": "is",
    "ids": "its",
    "ids": "kids",
    "idunno": "dunno",
    "ie": "be",
    "ie": "die",
    "ie": "i",
    "ie": "if",
    "ie": "in",
    "ie": "is",
    "ie": "it",
    "ie": "me",
    "ie": "we",
    "ieven": "even",
    "ievolution": "evolution",
    "ifa": "if",
    "ife": "life",
    "ifeel": "feel",
    "ifelt": "felt",
    "iff": "if",
    "iff": "off",
    "ifinger": "finger",
    "ifit": "fit",
    "iflash": "flash",
    "iforgot": "forgot",
    "ifound": "found",
    "ifriends": "friends",
    "ifrom": "from",
    "ifs": "is",
    "ifuckkin": "ifukkin",
    "ifun": "fun",
    "ig": "i",
    "ig": "is",
    "ig": "it",
    "igame": "game",
    "iget": "get",
    "igetting": "getting",
    "ight": "night",
    "ign": "in",
    "igoogle": "google",
    "igot": "got",
    "iguess": "guess",
    "iguiide": "iguide",
    "ih": "i",
    "ih": "in",
    "ih": "is",
    "ihad": "had",
    "ihate": "hate",
    "ihave": "have",
    "ihe": "he",
    "ihome": "home",
    "ihone": "iphone",
    "ihope": "hope",
    "ihpone": "iphone",
    "ihs": "is",
    "iht": "it",
    "ii": "i",
    "ii": "in",
    "ii": "is",
    "ii": "it",
    "ii": "wii",
    "iif": "if",
    "iight": "fight",
    "iight": "might",
    "iight": "night",
    "iight": "right",
    "iii": "wii",
    "iike": "like",
    "iim": "im",
    "iin": "in",
    "iinstead": "instead",
    "iinternet": "internet",
    "iinto": "into",
    "iinvite": "invite",
    "iiphone": "iphone",
    "iis": "is",
    "iis": "its",
    "iisten": "listen",
    "iit": "it",
    "iits": "its",
    "iive": "ive",
    "ijust": "just",
    "ik": "i",
    "ik": "is",
    "ik": "it",
    "ike": "like",
    "ikea": "idea",
    "ikeyboard": "keyboard",
    "iknow": "know",
    "ikon": "icon",
    "il": "i",
    "il": "if",
    "il": "im",
    "il": "in",
    "il": "is",
    "il": "it",
    "ilab": "lab",
    "ild": "old",
    "ilife": "life",
    "ilike": "like",
    "ilke": "like",
    "illl": "ill",
    "illn": "ill",
    "ilove": "love",
    "ilu": "flu",
    "iluv": "luv",
    "im": "am",
    "im": "dm",
    "im": "fm",
    "im": "him",
    "im": "i",
    "im": "ibm",
    "im": "if",
    "im": "in",
    "im": "is",
    "im": "it",
    "ima": "im",
    "imac": "mac",
    "imade": "made",
    "imagas": "images",
    "imagis": "images",
    "imags": "images",
    "iman": "man",
    "imap": "ima",
    "imap": "map",
    "imay": "may",
    "imb": "ibm",
    "imbed": "embed",
    "ime": "me",
    "imeages": "images",
    "imeant": "meant",
    "imf": "if",
    "imf": "im",
    "imgaes": "images",
    "imge": "image",
    "imges": "images",
    "imiss": "miss",
    "imm": "im",
    "immo": "imma",
    "immuned": "immune",
    "immuse": "immune",
    "imo": "im",
    "imobile": "mobile",
    "imortant": "important",
    "imporant": "important",
    "importanct": "important",
    "importnt": "important",
    "improvments": "improvements",
    "imprtant": "important",
    "imprve": "improve",
    "ims": "its",
    "imt": "it",
    "imune": "immune",
    "imvite": "invite",
    "imy": "my",
    "ina": "in",
    "inages": "images",
    "inatead": "instead",
    "inboxx": "inbox",
    "inc": "in",
    "incease": "increase",
    "inceases": "increases",
    "incitation": "invitation",
    "increaes": "increase",
    "increaes": "increases",
    "increse": "increase",
    "incvite": "invite",
    "ind": "and",
    "ind": "end",
    "ind": "find",
    "indiana": "indians",
    "indie": "india",
    "indoensia": "indonesia",
    "indonasia": "indonesia",
    "indoneasia": "indonesia",
    "indoneisa": "indonesia",
    "indoneshia": "indonesia",
    "indonesian": "indonesia",
    "indonesio": "indonesia",
    "indonessia": "indonesia",
    "indonisia": "indonesia",
    "indosnesia": "indonesia",
    "indstry": "industry",
    "ine": "line",
    "ineed": "need",
    "ineo": "into",
    "inernet": "internet",
    "inet": "net",
    "inews": "news",
    "inf": "if",
    "inf": "in",
    "infectede": "infected",
    "infecton": "infection",
    "infitation": "invitation",
    "infomation": "information",
    "infor": "info",
    "informaiton": "information",
    "informationi": "information",
    "infr": "info",
    "infringment": "infringement",
    "infrmed": "informed",
    "infromation": "information",
    "ing": "in",
    "ing": "ping",
    "ingrediants": "ingredients",
    "ingrediens": "ingredients",
    "ini": "in",
    "inisights": "insights",
    "inital": "initial",
    "initation": "invitation",
    "inite": "invite",
    "inivitation": "invitation",
    "inivite": "invite",
    "inivites": "invites",
    "inivtes": "invites",
    "inj": "in",
    "injectible": "injectable",
    "injectiong": "injection",
    "inlcuded": "included",
    "inline": "online",
    "innfested": "infested",
    "innites": "invites",
    "innoculations": "inoculations",
    "innvite": "invite",
    "ino": "no",
    "inocuations": "inoculations",
    "inow": "now",
    "inpiration": "inspiration",
    "inportant": "important",
    "inprove": "improve",
    "inpsired": "inspired",
    "inrerested": "interested",
    "inroduce": "introduce",
    "ins": "is",
    "insatlled": "installed",
    "insde": "inside",
    "instad": "instead",
    "instal": "install",
    "instala": "install",
    "instaled": "installed",
    "instaling": "installing",
    "insted": "instead",
    "instend": "instead",
    "instill": "install",
    "instslled": "installed",
    "int": "aint",
    "int": "in",
    "int": "it",
    "intalled": "installed",
    "intead": "instead",
    "integreate": "integrate",
    "intendo": "nintendo",
    "intenet": "internet",
    "intereactive": "interactive",
    "interenet": "internet",
    "interent": "internet",
    "interersted": "interested",
    "interesed": "interested",
    "intereseted": "interested",
    "interesing": "interesting",
    "interessed": "interested",
    "interessted": "interested",
    "interestng": "interesting",
    "interestong": "interesting",
    "interet": "internet",
    "intereting": "interesting",
    "intergrate": "integrate",
    "intergrated": "integrated",
    "intergrates": "integrates",
    "intergration": "integration",
    "internationl": "international",
    "internetz": "internet",
    "internrt": "internet",
    "internt": "internet",
    "interr": "intern",
    "interract": "interact",
    "interrested": "interested",
    "interrsted": "interested",
    "interseted": "interested",
    "interseting": "interesting",
    "intersted": "interested",
    "intersting": "interesting",
    "inti": "into",
    "intigrate": "integrate",
    "intitation": "invitation",
    "intite": "invite",
    "intl": "into",
    "intregrate": "integrate",
    "intrernet": "internet",
    "intrest": "interest",
    "intrested": "interested",
    "intresting": "interesting",
    "introudces": "introduces",
    "intruducing": "introducing",
    "intvite": "invite",
    "inty": "into",
    "inv": "in",
    "invantion": "invention",
    "invatation": "invitation",
    "invatations": "invitations",
    "invate": "invite",
    "invated": "invited",
    "invates": "invites",
    "inveite": "invite",
    "invetation": "invitation",
    "invete": "invite",
    "inveted": "invented",
    "inveted": "invited",
    "invetion": "invention",
    "inviatation": "invitation",
    "inviate": "invite",
    "inviation": "invitation",
    "inviations": "invitations",
    "invice": "invite",
    "invide": "invite",
    "invie": "invite",
    "invied": "invited",
    "invies": "invites",
    "inviet": "invite",
    "inviite": "invite",
    "invintation": "invitation",
    "invire": "invite",
    "invires": "invites",
    "invis": "invit",
    "invitacion": "invitation",
    "invitaction": "invitation",
    "invitaion": "invitation",
    "invitaition": "invitation",
    "invitaiton": "invitation",
    "invitanion": "invitation",
    "invitantion": "invitation",
    "invitarion": "invitation",
    "invitatiion": "invitation",
    "invitatioin": "invitation",
    "invitationb": "invitation",
    "invitatioon": "invitation",
    "invitaton": "invitation",
    "invitattion": "invitation",
    "invitei": "invite",
    "invitem": "invite",
    "inviter": "invite",
    "inviters": "invites",
    "invitez": "invite",
    "invitiation": "invitation",
    "invities": "invites",
    "invitr": "invite",
    "invits": "invite",
    "invits": "invites",
    "invitte": "invite",
    "invivte": "invite",
    "invlte": "invite",
    "invo": "info",
    "invo": "into",
    "involvedm": "involved",
    "invote": "invite",
    "invtation": "invitation",
    "invte": "invite",
    "invtie": "invite",
    "invutation": "invitation",
    "invutes": "invites",
    "invvite": "invite",
    "iny": "in",
    "io": "do",
    "io": "i",
    "io": "id",
    "io": "in",
    "io": "is",
    "io": "it",
    "io": "no",
    "io": "to",
    "iod": "ipod",
    "iol": "lol",
    "ionce": "once",
    "iont": "dont",
    "ior": "for",
    "ios": "is",
    "iost": "lost",
    "iot": "it",
    "iother": "other",
    "iout": "out",
    "iove": "love",
    "ioving": "loving",
    "ip": "hip",
    "ip": "i",
    "ip": "if",
    "ip": "in",
    "ip": "is",
    "ip": "it",
    "ip": "tip",
    "ip": "up",
    "ipad": "ipod",
    "ipcon": "icon",
    "ipd": "ipod",
    "ipdate": "update",
    "ipdod": "ipod",
    "ipgrade": "upgrade",
    "iphine": "iphone",
    "iphne": "iphone",
    "iphobe": "iphone",
    "iphod": "ipod",
    "iphode": "iphone",
    "iphoe": "iphone",
    "iphoen": "iphone",
    "iphone": "phone",
    "iphoned": "iphone",
    "iphonei": "iphone",
    "iphonel": "iphone",
    "iphonen": "iphone",
    "iphoner": "iphone",
    "iphones": "phones",
    "iphonex": "iphone",
    "iphoney": "iphone",
    "iphonez": "iphone",
    "iphonr": "iphone",
    "iphons": "iphone",
    "iphpne": "iphone",
    "ipjone": "iphone",
    "iplayer": "player",
    "ipnone": "iphone",
    "ipnvited": "invited",
    "ipode": "ipod",
    "ipodt": "ipod",
    "ipohne": "iphone",
    "ipohone": "iphone",
    "ipone": "iphone",
    "iportant": "important",
    "ipos": "ipod",
    "ipot": "ipod",
    "ipoud": "ipod",
    "ippd": "ipod",
    "ipphone": "iphone",
    "iproblems": "problems",
    "ipt": "it",
    "iput": "put",
    "iq": "i",
    "iq": "im",
    "iq": "in",
    "iq": "is",
    "iq": "it",
    "ir": "i",
    "ir": "in",
    "ir": "is",
    "ir": "it",
    "ir": "or",
    "ir": "ur",
    "ireal": "real",
    "ireally": "really",
    "ireport": "report",
    "irestore": "restore",
    "irock": "rock",
    "irs": "is",
    "irs": "its",
    "isa": "is",
    "isd": "is",
    "ise": "is",
    "ise": "use",
    "isee": "see",
    "isent": "sent",
    "isg": "is",
    "ish": "is",
    "ish": "wish",
    "ishould": "should",
    "isht": "isnt",
    "ising": "using",
    "isint": "isnt",
    "isit": "isnt",
    "isl": "is",
    "isn": "in",
    "isn": "is",
    "isn": "ist",
    "isntead": "instead",
    "iso": "is",
    "iso": "so",
    "isoftware": "software",
    "isp": "is",
    "iss": "is",
    "issuses": "issues",
    "ist": "is",
    "ist": "it",
    "ist": "its",
    "ist": "list",
    "istalled": "installed",
    "istening": "listening",
    "istill": "still",
    "istore": "store",
    "isu": "is",
    "isw": "is",
    "isx": "is",
    "isy": "is",
    "isz": "is",
    "ita": "it",
    "itablet": "tablet",
    "itake": "take",
    "italk": "talk",
    "itc": "htc",
    "itc": "it",
    "itc": "its",
    "itd": "it",
    "itd": "its",
    "itemsn": "items",
    "iteself": "itself",
    "ith": "with",
    "ithe": "the",
    "ithink": "think",
    "ithought": "thought",
    "iti": "it",
    "itis": "its",
    "itiuch": "itouch",
    "itll": "ill",
    "itll": "till",
    "itls": "its",
    "itms": "its",
    "itn": "in",
    "itn": "it",
    "itn": "its",
    "itnernet": "internet",
    "ito": "to",
    "itouch": "touch",
    "itrs": "its",
    "itry": "try",
    "itrying": "trying",
    "itslef": "itself",
    "itss": "its",
    "itsself": "itself",
    "itt": "it",
    "itts": "its",
    "itu": "it",
    "itunesu": "itunes",
    "itv": "it",
    "itv": "its",
    "itv": "tv",
    "itw": "it",
    "itweet": "tweet",
    "itwitter": "twitter",
    "ity": "it",
    "itype": "type",
    "itz": "it",
    "itz": "its",
    "iu": "i",
    "iu": "if",
    "iu": "u",
    "iui": "ui",
    "ium": "im",
    "iup": "up",
    "iupdated": "updated",
    "ius": "is",
    "ius": "us",
    "iuse": "use",
    "iut": "out",
    "iv": "i",
    "iv": "in",
    "iv": "is",
    "iv": "it",
    "iv": "tv",
    "ive": "give",
    "ive": "ice",
    "ive": "live",
    "iver": "over",
    "ivitation": "invitation",
    "ivitations": "invitations",
    "ivite": "invite",
    "ivited": "invited",
    "ivnite": "invite",
    "iw": "i",
    "iwanna": "wanna",
    "iwant": "want",
    "iwanted": "wanted",
    "iwas": "was",
    "iweb": "web",
    "iwent": "went",
    "iwill": "will",
    "iwish": "wish",
    "iwit": "wit",
    "iwll": "will",
    "iwonder": "wonder",
    "iwork": "work",
    "iwould": "would",
    "iwth": "with",
    "ix": "i",
    "ix": "it",
    "iy": "it",
    "iyou": "you",
    "iys": "is",
    "iz": "i",
    "iz": "if",
    "iz": "im",
    "iz": "in",
    "iz": "is",
    "iz": "it",
    "izoo": "zoo",
    "izpod": "ipod",
    "izza": "pizza",
    "ja": "a",
    "jaab": "jab",
    "jabb": "jab",
    "jackon": "jackson",
    "jad": "had",
    "jaibreak": "jailbreak",
    "jaibreaking": "jailbreaking",
    "jaibroken": "jailbroken",
    "jailbareak": "jailbreak",
    "jailbeak": "jailbreak",
    "jailboken": "jailbroken",
    "jailborken": "jailbroken",
    "jailbraek": "jailbreak",
    "jailbrak": "jailbreak",
    "jailbreack": "jailbreak",
    "jailbreaj": "jailbreak",
    "jailbreakd": "jailbreak",
    "jailbrean": "jailbreak",
    "jailbrek": "jailbreak",
    "jailbreking": "jailbreaking",
    "jailbrken": "jailbroken",
    "jailbroked": "jailbroken",
    "jailbroken": "jailbroke",
    "jailbrokn": "jailbroken",
    "jailbteak": "jailbreak",
    "jaillbreak": "jailbreak",
    "jaillbroken": "jailbroken",
    "jailreak": "jailbreak",
    "jaime": "jamie",
    "jake": "joke",
    "jake": "take",
    "jakrta": "jakarta",
    "jalbreak": "jailbreak",
    "james": "games",
    "jamesz": "james",
    "jan": "an",
    "jan": "can",
    "jan": "man",
    "jan": "san",
    "jaoan": "japan",
    "japenese": "japanese",
    "jard": "hard",
    "jas": "has",
    "jast": "just",
    "jave": "have",
    "jave": "wave",
    "javent": "havent",
    "javing": "having",
    "jb": "b",
    "jb": "bb",
    "jb": "gb",
    "jb": "job",
    "jbb": "job",
    "jbroke": "broke",
    "jcatch": "catch",
    "jdo": "do",
    "je": "be",
    "je": "me",
    "jea": "yea",
    "jee": "see",
    "jel": "gel",
    "jelous": "jealous",
    "jeneiro": "janeiro",
    "jersy": "jersey",
    "jes": "jus",
    "jew": "few",
    "jew": "new",
    "jews": "news",
    "jgo": "go",
    "jhas": "has",
    "jhate": "hate",
    "ji": "i",
    "jialbroken": "jailbroken",
    "jillion": "million",
    "jim": "him",
    "jim": "im",
    "jim": "sim",
    "jist": "just",
    "jist": "list",
    "jiust": "just",
    "jjust": "just",
    "jk": "ok",
    "jk": "uk",
    "jlove": "love",
    "jn": "in",
    "jo": "do",
    "jo": "no",
    "jo": "to",
    "joans": "jonas",
    "joba": "job",
    "jobb": "job",
    "joe": "job",
    "johnson": "johnston",
    "joind": "joined",
    "joinded": "joined",
    "joing": "join",
    "joingng": "joining",
    "joinn": "join",
    "jon": "job",
    "jon": "join",
    "jon": "on",
    "jones": "ones",
    "jong": "long",
    "jont": "jon",
    "joon": "soon",
    "jope": "hope",
    "jord": "lord",
    "jouin": "join",
    "jour": "your",
    "journalistss": "journalists",
    "jow": "how",
    "jp": "up",
    "jphone": "iphone",
    "jr": "or",
    "jruby": "ruby",
    "js": "as",
    "js": "is",
    "js": "jus",
    "js": "os",
    "js": "us",
    "jschool": "school",
    "jst": "just",
    "jsut": "just",
    "jt": "it",
    "ju": "u",
    "juast": "just",
    "juat": "just",
    "jucie": "juice",
    "judgd": "judged",
    "judt": "just",
    "juest": "just",
    "juica": "juice",
    "juicer": "juice",
    "juist": "just",
    "jujst": "just",
    "junt": "just",
    "jus": "us",
    "jusd": "just",
    "jusdt": "just",
    "jusf": "just",
    "jusr": "just",
    "jusrt": "just",
    "juss": "just",
    "jusst": "just",
    "justg": "just",
    "justt": "just",
    "justv": "just",
    "jusu": "just",
    "jusut": "just",
    "jusy": "just",
    "jusz": "just",
    "juszt": "just",
    "jut": "but",
    "jut": "just",
    "juts": "just",
    "juust": "just",
    "jux": "jus",
    "juz": "jus",
    "juzt": "just",
    "jvm": "jim",
    "jwhy": "why",
    "jy": "my",
    "ka": "a",
    "kalled": "called",
    "kam": "am",
    "kame": "came",
    "kan": "an",
    "kan": "ban",
    "kan": "can",
    "kant": "cant",
    "kant": "want",
    "kante": "kanye",
    "kard": "card",
    "kare": "care",
    "kares": "cares",
    "kari": "kart",
    "kark": "kart",
    "kart": "part",
    "kary": "kart",
    "kas": "was",
    "kases": "cases",
    "kat": "kart",
    "kate": "date",
    "kate": "hate",
    "kate": "late",
    "kause": "cause",
    "kay": "day",
    "kay": "may",
    "kayne": "kanye",
    "kbd": "kid",
    "kbnow": "know",
    "kdi": "kid",
    "ke": "be",
    "ke": "me",
    "keb": "web",
    "keeap": "keep",
    "keeep": "keep",
    "keeeps": "keeps",
    "keepm": "keep",
    "keept": "keep",
    "kelling": "killing",
    "kent": "sent",
    "kenw": "knew",
    "kep": "keep",
    "ket": "get",
    "ket": "let",
    "kew": "new",
    "kexp": "keep",
    "keybaord": "keyboard",
    "keyowrds": "keywords",
    "keywors": "keyword",
    "keywrd": "keyword",
    "keywrod": "keyword",
    "kfox": "fox",
    "ki": "di",
    "ki": "i",
    "kicced": "kicked",
    "kichen": "kitchen",
    "kickd": "kicked",
    "kicken": "kicked",
    "kicken": "kickin",
    "kickn": "kickin",
    "kicthen": "kitchen",
    "kidd": "kid",
    "kidd": "kids",
    "kidos": "kids",
    "kidz": "kid",
    "kidz": "kids",
    "kiids": "kids",
    "kiinds": "kinds",
    "kik": "kick",
    "kik": "kit",
    "kiked": "kicked",
    "kikin": "kickin",
    "kil": "kill",
    "killen": "killin",
    "killig": "killing",
    "killinq": "killing",
    "killled": "killed",
    "killling": "killing",
    "killng": "killing",
    "killr": "killer",
    "killy": "kill",
    "kilss": "kills",
    "kim": "him",
    "kim": "im",
    "kim": "kid",
    "kims": "kids",
    "kina": "kind",
    "kindaa": "kinda",
    "kindda": "kinda",
    "kindel": "kindle",
    "kindz": "kinds",
    "kinlde": "kindle",
    "kinle": "kindle",
    "kinna": "kinda",
    "kinow": "know",
    "kins": "kinds",
    "kirchen": "kitchen",
    "kisss": "kiss",
    "kittle": "little",
    "kjust": "just",
    "kk": "ok",
    "kkep": "keep",
    "kknew": "knew",
    "klass": "class",
    "klu": "flu",
    "kmow": "know",
    "kmz": "kml",
    "kn": "on",
    "knbow": "know",
    "knd": "kind",
    "kne": "kno",
    "knida": "kinda",
    "kniw": "know",
    "knkw": "know",
    "knmow": "know",
    "knmw": "know",
    "knnow": "know",
    "knnw": "know",
    "kno": "no",
    "knoe": "kno",
    "knoe": "know",
    "knoh": "kno",
    "knol": "know",
    "knoo": "kno",
    "knoo": "know",
    "knoow": "know",
    "knos": "know",
    "knoticed": "noticed",
    "knowi": "know",
    "knoww": "know",
    "knox": "know",
    "knu": "kno",
    "knw": "knew",
    "knw": "know",
    "knwo": "kno",
    "knwo": "know",
    "knws": "knows",
    "knww": "know",
    "ko": "go",
    "ko": "so",
    "ko": "to",
    "koi": "roi",
    "kol": "aol",
    "kol": "lol",
    "kold": "cold",
    "komes": "comes",
    "konda": "kinda",
    "kong": "long",
    "kong": "song",
    "konw": "know",
    "konws": "knows",
    "koo": "too",
    "koo": "zoo",
    "kooked": "hooked",
    "kooking": "looking",
    "kool": "cool",
    "kooler": "cooler",
    "korean": "korea",
    "kould": "could",
    "kould": "would",
    "kousin": "cousin",
    "kow": "know",
    "kphone": "iphone",
    "krap": "crap",
    "krib": "crib",
    "ks": "is",
    "ks": "us",
    "kso": "so",
    "ksrt": "kart",
    "kt": "at",
    "kt": "it",
    "ku": "u",
    "kun": "run",
    "kung": "king",
    "kust": "just",
    "kut": "put",
    "kuz": "cuz",
    "kwave": "wave",
    "kwith": "with",
    "kwow": "know",
    "ky": "key",
    "ky": "my",
    "labron": "lebron",
    "labtop": "laptop",
    "lac": "lab",
    "lac": "mac",
    "lackberry": "blackberry",
    "lagre": "large",
    "laking": "taking",
    "lan": "an",
    "lan": "can",
    "lan": "lab",
    "lan": "man",
    "lana": "lala",
    "lanched": "launched",
    "lang": "land",
    "lang": "long",
    "lant": "cant",
    "lappy": "happy",
    "laptob": "laptop",
    "lara": "lala",
    "las": "has",
    "las": "los",
    "lastest": "latest",
    "lasu": "last",
    "lasy": "last",
    "laszy": "lazy",
    "latitiude": "latitude",
    "latitute": "latitude",
    "lator": "later",
    "latte": "late",
    "lattitude": "latitude",
    "lattrell": "littrell",
    "lauch": "launch",
    "lauched": "launched",
    "lauches": "launches",
    "lauching": "launching",
    "laucnhes": "launches",
    "laught": "laugh",
    "lauing": "laying",
    "launcd": "launch",
    "launces": "launches",
    "launchd": "launched",
    "launchn": "launch",
    "launcht": "launch",
    "layed": "played",
    "layiing": "laying",
    "layin": "playin",
    "layn": "lay",
    "lazt": "lazy",
    "lazzy": "lazy",
    "lbs": "labs",
    "lbv": "lbs",
    "lcuk": "luck",
    "lds": "ads",
    "le": "be",
    "le": "me",
    "leaave": "leave",
    "leabron": "lebron",
    "leaened": "learned",
    "leah": "lead",
    "leakd": "leaked",
    "lealous": "jealous",
    "leapfrom": "leapfrog",
    "lear": "hear",
    "leared": "learned",
    "learing": "learning",
    "learnd": "learned",
    "learnnig": "learning",
    "leat": "least",
    "leat": "let",
    "leavez": "leaves",
    "leavng": "leaving",
    "lebraon": "lebron",
    "ledgend": "legend",
    "leed": "lead",
    "leed": "led",
    "leed": "need",
    "leeds": "needs",
    "leet": "left",
    "leftr": "left",
    "leftt": "left",
    "lego": "logo",
    "legron": "lebron",
    "leme": "lemme",
    "lemmie": "lemme",
    "leo": "ceo",
    "lepoard": "leopard",
    "leran": "learn",
    "lern": "learn",
    "lesft": "left",
    "leta": "lets",
    "leting": "letting",
    "lett": "let",
    "lettin": "gettin",
    "levison": "levinson",
    "lf": "of",
    "lfe": "life",
    "lfu": "flu",
    "lgive": "give",
    "li": "i",
    "libary": "library",
    "libraray": "library",
    "libray": "library",
    "libs": "labs",
    "libs": "ribs",
    "liek": "like",
    "liekd": "liked",
    "liike": "like",
    "liitle": "little",
    "liittle": "little",
    "lije": "like",
    "lik": "link",
    "lika": "like",
    "likd": "like",
    "likea": "like",
    "likea": "likes",
    "likedly": "likely",
    "likei": "like",
    "liken": "like",
    "liker": "like",
    "likey": "like",
    "likey": "likely",
    "likke": "like",
    "liks": "like",
    "likt": "like",
    "likw": "like",
    "lil": "ill",
    "lil": "lol",
    "lil": "til",
    "lile": "like",
    "liles": "files",
    "lill": "lil",
    "lilttle": "little",
    "lima": "loma",
    "limbugh": "limbaugh",
    "limitied": "limited",
    "limted": "limited",
    "lin": "in",
    "lin": "win",
    "lina": "line",
    "linie": "line",
    "linke": "like",
    "linky": "link",
    "linmk": "link",
    "linn": "link",
    "linne": "line",
    "liove": "love",
    "lis": "is",
    "lisa": "list",
    "lisening": "listening",
    "lisiten": "listen",
    "lisitening": "listening",
    "lisiting": "listing",
    "liss": "miss",
    "listeing": "listening",
    "listeni": "listen",
    "listenig": "listening",
    "listenign": "listening",
    "listeniing": "listening",
    "listeninf": "listening",
    "listenting": "listening",
    "lister": "listed",
    "listerning": "listening",
    "listien": "listen",
    "listin": "listen",
    "listings": "listing",
    "listining": "listening",
    "listneing": "listening",
    "listning": "listening",
    "liston": "listen",
    "lisztening": "listening",
    "lite": "late",
    "lite": "life",
    "lite": "like",
    "lite": "line",
    "lite": "live",
    "lite": "site",
    "liten": "listen",
    "literell": "littrell",
    "litle": "little",
    "litlle": "little",
    "litte": "little",
    "littel": "little",
    "litterell": "littrell",
    "litterll": "littrell",
    "littke": "little",
    "littley": "little",
    "littlw": "little",
    "litttle": "little",
    "liven": "live",
    "livv": "live",
    "liying": "liking",
    "ljust": "just",
    "lk": "uk",
    "lke": "like",
    "lkike": "like",
    "llatest": "latest",
    "llet": "let",
    "llike": "like",
    "llink": "link",
    "llisten": "listen",
    "llittrell": "littrell",
    "llke": "like",
    "llnk": "link",
    "llok": "look",
    "llol": "lol",
    "llost": "lost",
    "lm": "am",
    "lm": "im",
    "lml": "lol",
    "lmo": "lomo",
    "lmost": "almost",
    "ln": "in",
    "ln": "on",
    "lng": "long",
    "lnow": "know",
    "loacl": "local",
    "locl": "local",
    "locve": "love",
    "lod": "load",
    "loe": "love",
    "loev": "love",
    "lofl": "lol",
    "logg": "logo",
    "logo": "lego",
    "logon": "login",
    "logon": "logo",
    "loike": "like",
    "loiok": "look",
    "lok": "look",
    "loke": "like",
    "loking": "looking",
    "lokked": "looked",
    "lokking": "looking",
    "loks": "looks",
    "lol": "aol",
    "lol": "lil",
    "lol": "lot",
    "lold": "lol",
    "loli": "lol",
    "lolm": "lol",
    "lolz": "lol",
    "lome": "loma",
    "lond": "long",
    "loney": "lonely",
    "longg": "long",
    "longo": "logo",
    "lonng": "long",
    "lonq": "long",
    "loocking": "looking",
    "loog": "look",
    "loogle": "google",
    "looing": "looking",
    "lookd": "look",
    "lookd": "looked",
    "looken": "lookin",
    "lookig": "looking",
    "lookign": "looking",
    "lookiing": "looking",
    "lookind": "looking",
    "lookingg": "looking",
    "lookingn": "looking",
    "lookinq": "looking",
    "lookk": "look",
    "lookn": "look",
    "lookn": "looks",
    "lookng": "looking",
    "looky": "look",
    "lookz": "looks",
    "lool": "lol",
    "lool": "look",
    "loong": "long",
    "loook": "look",
    "loooking": "looking",
    "loooks": "looks",
    "looong": "loooong",
    "looooong": "loooong",
    "loove": "love",
    "looved": "loved",
    "lopve": "love",
    "los": "loss",
    "los": "lots",
    "losse": "lose",
    "losser": "loser",
    "losty": "lost",
    "lota": "lot",
    "lotes": "lotus",
    "lothain": "lothian",
    "lotsa": "lots",
    "lottle": "little",
    "lotz": "lot",
    "lotz": "lots",
    "lou": "you",
    "lounch": "launch",
    "louve": "love",
    "lov": "lol",
    "lovd": "love",
    "lovein": "lovin",
    "lovem": "love",
    "loven": "love",
    "lovez": "love",
    "lovie": "love",
    "lovinh": "loving",
    "lovley": "lovely",
    "lovly": "lovely",
    "lovve": "love",
    "lovvly": "lovely",
    "lovw": "love",
    "loyt": "lot",
    "lozt": "lost",
    "lplay": "play",
    "lr": "er",
    "ls": "as",
    "ls": "is",
    "lsat": "last",
    "lsiten": "listen",
    "lsitening": "listening",
    "lst": "last",
    "lst": "lost",
    "lst": "lot",
    "lsten": "listen",
    "lt": "it",
    "lt": "tl",
    "lte": "late",
    "lthe": "the",
    "lts": "lets",
    "lttle": "little",
    "lu": "flu",
    "lu": "u",
    "luagh": "laugh",
    "luanch": "launch",
    "luanched": "launched",
    "luch": "lunch",
    "luckilly": "luckily",
    "luckyf": "lucky",
    "luk": "luck",
    "luke": "like",
    "lul": "lol",
    "lurv": "luv",
    "luttrell": "littrell",
    "luvd": "luv",
    "luve": "love",
    "luved": "loved",
    "luving": "loving",
    "luvv": "luv",
    "luvz": "luv",
    "lv": "luv",
    "lve": "love",
    "lvoe": "love",
    "lx": "x",
    "ly": "by",
    "lyfe": "life",
    "lyke": "like",
    "lyon": "leon",
    "lytrell": "litrell",
    "maa": "mac",
    "maan": "man",
    "maange": "manage",
    "maaps": "maps",
    "mabe": "maybe",
    "maby": "may",
    "mabye": "maybe",
    "madd": "made",
    "madee": "made",
    "maden": "madden",
    "mae": "make",
    "mage": "page",
    "maginitude": "magnitude",
    "magintude": "magnitude",
    "magitude": "magnitude",
    "magnitdue": "magnitude",
    "magnitiude": "magnitude",
    "magnitue": "magnitude",
    "magnitutde": "magnitude",
    "magnitute": "magnitude",
    "mah": "mac",
    "mah": "man",
    "mahr": "maher",
    "mai": "ma",
    "mai": "man",
    "maibe": "maybe",
    "mainia": "mania",
    "maio": "mario",
    "maj": "man",
    "maj": "map",
    "maje": "make",
    "majoirty": "majority",
    "majori": "major",
    "mak": "map",
    "maka": "make",
    "makea": "make",
    "maken": "makes",
    "maken": "makin",
    "makews": "makes",
    "makez": "makes",
    "makie": "make",
    "makiin": "makin",
    "makingg": "making",
    "makinn": "making",
    "makinq": "making",
    "makke": "make",
    "makkng": "making",
    "makn": "make",
    "makn": "makin",
    "makng": "making",
    "makr": "make",
    "maks": "makes",
    "mal": "mail",
    "mal": "may",
    "malled": "mauled",
    "mame": "game",
    "mame": "made",
    "mame": "make",
    "mamma": "momma",
    "mana": "many",
    "manaaged": "managed",
    "mand": "and",
    "mandantory": "mandatory",
    "mandetory": "mandatory",
    "manditory": "mandatory",
    "mandotory": "mandatory",
    "mang": "man",
    "manga": "mania",
    "manged": "managed",
    "mani": "man",
    "mann": "man",
    "manny": "many",
    "mano": "many",
    "manps": "maps",
    "manua": "mania",
    "manyy": "many",
    "mao": "map",
    "mapas": "maps",
    "mapd": "maps",
    "maped": "mapped",
    "mapes": "maps",
    "mapi": "api",
    "mapi": "map",
    "mapp": "map",
    "mapps": "maps",
    "maralyn": "marilyn",
    "marekting": "marketing",
    "maret": "market",
    "marin": "main",
    "mariok": "mario",
    "marion": "mario",
    "marioo": "mario",
    "mariyln": "marilyn",
    "marliyn": "marilyn",
    "marlyn": "marilyn",
    "maroi": "mario",
    "marolyn": "marilyn",
    "maroo": "mario",
    "marrio": "mario",
    "mary": "many",
    "mary": "may",
    "marylyn": "marilyn",
    "mas": "has",
    "mas": "man",
    "mas": "may",
    "masive": "massive",
    "masrilyn": "marilyn",
    "mater": "matter",
    "mau": "may",
    "maube": "maybe",
    "mave": "have",
    "mave": "wave",
    "max": "mac",
    "max": "man",
    "max": "map",
    "max": "may",
    "max": "mix",
    "maxes": "makes",
    "maxing": "making",
    "maxx": "max",
    "mayb": "may",
    "maye": "maybe",
    "mayne": "maybe",
    "mayy": "may",
    "mb": "bb",
    "mb": "me",
    "mb": "my",
    "mbox": "box",
    "mbp": "map",
    "mbp": "mb",
    "mbps": "maps",
    "mc": "mac",
    "mc": "me",
    "mc": "my",
    "mcbook": "macbook",
    "mce": "me",
    "mch": "much",
    "mcuh": "much",
    "md": "ad",
    "md": "me",
    "md": "my",
    "mddle": "middle",
    "mde": "made",
    "mea": "me",
    "meann": "meant",
    "meannt": "meant",
    "meanss": "means",
    "meantion": "mention",
    "meany": "many",
    "meany": "mean",
    "mechant": "merchant",
    "med": "bed",
    "med": "me",
    "meda": "media",
    "medecine": "medicine",
    "meds": "feds",
    "mee": "me",
    "mee": "see",
    "meens": "means",
    "meer": "meet",
    "meetp": "meets",
    "meg": "me",
    "meh": "me",
    "mei": "me",
    "mek": "me",
    "meke": "make",
    "mel": "me",
    "mena": "mean",
    "mens": "means",
    "mens": "mend",
    "ment": "meant",
    "ment": "meet",
    "ment": "sent",
    "ment": "went",
    "meny": "many",
    "meon": "moon",
    "mer": "me",
    "merchent": "merchant",
    "mesage": "message",
    "mesages": "messages",
    "mesaging": "messaging",
    "meself": "myself",
    "messaged": "messages",
    "messagig": "messaging",
    "messahing": "messaging",
    "messaing": "messaging",
    "messanger": "messenger",
    "messanging": "messaging",
    "messasging": "messaging",
    "messd": "messed",
    "messeaging": "messaging",
    "messege": "message",
    "messeges": "messages",
    "messeging": "messaging",
    "messengr": "messenger",
    "messgaing": "messaging",
    "messge": "message",
    "messges": "messages",
    "messging": "messaging",
    "messig": "messing",
    "messiging": "messaging",
    "messnger": "messenger",
    "messsage": "message",
    "messsaging": "messaging",
    "mest": "best",
    "mesting": "meeting",
    "metion": "mention",
    "metriod": "metroid",
    "metter": "matter",
    "mewans": "means",
    "mex": "me",
    "mexcan": "mexican",
    "mexicab": "mexican",
    "mey": "me",
    "mey": "my",
    "mf": "me",
    "mf": "my",
    "mfe": "me",
    "mght": "might",
    "mgiht": "might",
    "mgs": "mms",
    "mh": "me",
    "mh": "my",
    "mia": "ima",
    "mia": "via",
    "mic": "mac",
    "mic": "pic",
    "micahel": "michael",
    "mich": "much",
    "micky": "mickey",
    "micosoft": "microsoft",
    "midddle": "middle",
    "midle": "middle",
    "mids": "kids",
    "midwifes": "midwives",
    "mie": "me",
    "mifi": "wifi",
    "migfht": "might",
    "mighht": "might",
    "mighta": "might",
    "mightt": "might",
    "migt": "might",
    "mihgt": "might",
    "mii": "wii",
    "miight": "might",
    "miiss": "miss",
    "mikey": "miley",
    "mil": "mail",
    "milano": "milan",
    "miliey": "miley",
    "milion": "million",
    "millenium": "millennium",
    "milliion": "million",
    "millionare": "millionaire",
    "millionn": "million",
    "milllion": "million",
    "millon": "million",
    "milo": "mild",
    "mim": "sim",
    "mims": "mms",
    "ming": "mind",
    "minght": "might",
    "minnimum": "minimum",
    "mins": "mine",
    "mins": "miss",
    "mintendo": "nintendo",
    "mintue": "minute",
    "minu": "min",
    "minuite": "minute",
    "minvites": "invites",
    "mioght": "might",
    "miphone": "iphone",
    "miqht": "might",
    "mircosoft": "microsoft",
    "mis": "his",
    "mis": "is",
    "mis": "miss",
    "misd": "miss",
    "mish": "miss",
    "mising": "missing",
    "missd": "missed",
    "missn": "miss",
    "misss": "miss",
    "mistery": "mystery",
    "misxtape": "mixtape",
    "mit": "fit",
    "mit": "hit",
    "mit": "it",
    "mith": "with",
    "mits": "hits",
    "mixd": "mild",
    "mj": "me",
    "mj": "my",
    "mjc": "mac",
    "mjor": "major",
    "mk": "my",
    "mkae": "make",
    "mke": "make",
    "mke": "me",
    "mkes": "makes",
    "mking": "making",
    "mkm": "mom",
    "mley": "miley",
    "mls": "mms",
    "mma": "mms",
    "mmario": "mario",
    "mmay": "may",
    "mmis": "mms",
    "mmm": "mms",
    "mmo": "mms",
    "mmos": "mms",
    "mmr": "mms",
    "mms": "moms",
    "mms": "ms",
    "mms": "sms",
    "mmss": "mms",
    "mmy": "my",
    "mn": "an",
    "mn": "en",
    "mn": "in",
    "mn": "m",
    "mn": "man",
    "mn": "me",
    "mn": "my",
    "mn": "on",
    "mna": "man",
    "mnn": "man",
    "mnoday": "monday",
    "mnth": "month",
    "mnths": "months",
    "mny": "many",
    "mny": "my",
    "mobilex": "mobile",
    "mobily": "mobile",
    "moble": "mobile",
    "moblie": "mobile",
    "mobo": "mono",
    "moday": "today",
    "modded": "modder",
    "moe": "me",
    "moe": "more",
    "moeny": "money",
    "moey": "money",
    "mof": "mo",
    "moght": "might",
    "mogo": "mono",
    "moi": "roi",
    "moives": "movies",
    "mojor": "major",
    "mold": "cold",
    "momment": "moment",
    "momo": "mom",
    "momths": "months",
    "momy": "mom",
    "momz": "mom",
    "momz": "moms",
    "mon": "on",
    "monent": "moment",
    "monoploy": "monopoly",
    "monoply": "monopoly",
    "monst": "most",
    "monthi": "month",
    "monthz": "months",
    "monty": "month",
    "mony": "money",
    "moogle": "google",
    "moohie": "mophie",
    "moore": "more",
    "moorning": "morning",
    "mophine": "mophie",
    "mophio": "mophie",
    "mopre": "more",
    "mor": "for",
    "moring": "morning",
    "morining": "morning",
    "mornig": "morning",
    "mornign": "morning",
    "mornng": "morning",
    "mornting": "morning",
    "mororola": "motorola",
    "morphie": "mophie",
    "morre": "more",
    "morring": "morning",
    "morrning": "morning",
    "morse": "more",
    "mortor": "motor",
    "moses": "doses",
    "moses": "moves",
    "mosh": "most",
    "moster": "monster",
    "mot": "got",
    "mot": "most",
    "mot": "not",
    "moto": "motto",
    "motorolla": "motorola",
    "mounths": "months",
    "mountian": "mountain",
    "moviee": "movie",
    "moviess": "movies",
    "moviez": "movie",
    "moxie": "movie",
    "mozillia": "mozilla",
    "mozt": "most",
    "mozzilla": "mozilla",
    "mp": "map",
    "mp": "me",
    "mp": "my",
    "mp": "up",
    "mplayer": "player",
    "mpm": "mom",
    "mpp": "app",
    "mpr": "npr",
    "mprovements": "improvements",
    "mps": "maps",
    "mps": "mms",
    "mr": "me",
    "mr": "my",
    "mr": "or",
    "mrc": "mac",
    "mre": "me",
    "mre": "more",
    "mroe": "more",
    "mroning": "morning",
    "mrs": "mms",
    "ms": "as",
    "ms": "is",
    "ms": "me",
    "ms": "mms",
    "ms": "my",
    "ms": "sms",
    "ms": "us",
    "msc": "mac",
    "mse": "me",
    "mske": "make",
    "msm": "mms",
    "msn": "hsn",
    "msn": "man",
    "msot": "most",
    "mspace": "myspace",
    "mss": "mms",
    "mst": "est",
    "mst": "most",
    "mst": "must",
    "msy": "may",
    "mt": "it",
    "mt": "my",
    "mte": "me",
    "mthe": "the",
    "mtv": "tv",
    "mty": "my",
    "muc": "mac",
    "mucg": "much",
    "muchh": "much",
    "mucho": "much",
    "mucht": "much",
    "mudic": "music",
    "mught": "might",
    "muh": "much",
    "muic": "music",
    "muich": "much",
    "muisc": "music",
    "multitaking": "multitasking",
    "murdock": "murdoch",
    "musch": "much",
    "musem": "museum",
    "musial": "musical",
    "musica": "music",
    "musik": "music",
    "musin": "music",
    "musnt": "must",
    "musrt": "must",
    "musta": "must",
    "musti": "must",
    "mutch": "much",
    "mutiple": "multiple",
    "muuch": "much",
    "muusic": "music",
    "muy": "my",
    "mv": "my",
    "mvc": "mac",
    "mvp": "map",
    "mvs": "mms",
    "mw": "me",
    "mw": "my",
    "mweb": "web",
    "mx": "my",
    "mya": "my",
    "myabe": "maybe",
    "myapace": "myspace",
    "myb": "my",
    "mybe": "maybe",
    "mye": "my",
    "myelf": "myself",
    "myh": "my",
    "myi": "my",
    "myn": "my",
    "mypantene": "mypantone",
    "mysace": "myspace",
    "myselg": "myself",
    "myslef": "myself",
    "myst": "mist",
    "myst": "most",
    "mystry": "mystery",
    "myt": "my",
    "myu": "my",
    "myy": "my",
    "mz": "my",
    "na": "a",
    "na": "an",
    "na": "ne",
    "na": "no",
    "nabout": "about",
    "nad": "and",
    "nade": "made",
    "nakes": "makes",
    "naking": "making",
    "nam": "am",
    "namer": "names",
    "namerica": "america",
    "namez": "name",
    "nan": "can",
    "nanchuk": "nunchuk",
    "nand": "and",
    "nant": "want",
    "nao": "no",
    "naon": "nano",
    "napp": "nap",
    "narsty": "nasty",
    "nas": "as",
    "nas": "has",
    "nasel": "nasal",
    "nat": "at",
    "nat": "not",
    "natched": "watched",
    "nate": "hate",
    "nathional": "national",
    "natinal": "national",
    "natuional": "national",
    "naw": "new",
    "naw": "now",
    "nb": "n",
    "nb": "no",
    "nbb": "bb",
    "nbc": "abc",
    "nbc": "bbc",
    "nbo": "no",
    "nbs": "nbc",
    "ncan": "can",
    "ncase": "case",
    "nd": "ad",
    "nd": "and",
    "nd": "end",
    "nd": "n",
    "nd": "ny",
    "ndian": "indian",
    "ndo": "no",
    "ndont": "dont",
    "nds": "ds",
    "ne": "be",
    "ne": "me",
    "ne": "n",
    "ne": "no",
    "ne": "one",
    "ne": "we",
    "nea": "new",
    "nead": "need",
    "neally": "really",
    "nearch": "search",
    "nec": "new",
    "nect": "next",
    "ned": "bed",
    "ned": "need",
    "ned": "new",
    "nedd": "need",
    "neddles": "needles",
    "nedxt": "next",
    "neec": "need",
    "needa": "need",
    "needa": "needs",
    "needc": "need",
    "needd": "need",
    "neededc": "needed",
    "needet": "needed",
    "needz": "need",
    "needz": "needs",
    "neeed": "need",
    "neeeds": "needs",
    "neeeed": "needed",
    "neen": "need",
    "neer": "need",
    "neer": "never",
    "nees": "need",
    "nees": "needs",
    "neew": "need",
    "neew": "new",
    "neg": "new",
    "negtive": "negative",
    "neh": "new",
    "neice": "niece",
    "neing": "being",
    "nelw": "new",
    "nem": "new",
    "nember": "number",
    "nentendo": "nintendo",
    "neo": "new",
    "neo": "no",
    "ner": "new",
    "nerd": "need",
    "nerds": "needs",
    "nervs": "nerves",
    "nes": "new",
    "nes": "news",
    "nesxt": "next",
    "netfilx": "netflix",
    "netnewsware": "netnewswire",
    "netnewwire": "netnewswire",
    "netter": "better",
    "netwoking": "networking",
    "netwoorking": "networking",
    "netwroking": "networking",
    "neu": "new",
    "neveer": "never",
    "neverr": "never",
    "nevewr": "never",
    "nevr": "never",
    "nevrr": "never",
    "newa": "new",
    "newb": "new",
    "neweast": "newest",
    "neweswt": "newest",
    "newnewswire": "netnewswire",
    "newq": "new",
    "newsa": "news",
    "newss": "news",
    "newst": "newest",
    "newst": "news",
    "newu": "news",
    "neww": "new",
    "neww": "news",
    "newws": "news",
    "newy": "new",
    "nex": "new",
    "nexgt": "next",
    "nextg": "next",
    "nexto": "next",
    "nexy": "next",
    "ney": "new",
    "nfl": "nfb",
    "nft": "nfb",
    "ng": "no",
    "nget": "get",
    "nght": "night",
    "ngo": "go",
    "ni": "i",
    "ni": "in",
    "ni": "no",
    "nicce": "nice",
    "nich": "nice",
    "nici": "nice",
    "nickk": "nick",
    "nighmare": "nightmare",
    "nightt": "night",
    "nigth": "night",
    "nii": "wii",
    "niight": "night",
    "nike": "like",
    "nike": "nice",
    "nikia": "nokia",
    "nile": "nine",
    "nin": "in",
    "nindendo": "nintendo",
    "ninendo": "nintendo",
    "ninetendo": "nintendo",
    "ninetndo": "nintendo",
    "ning": "bing",
    "ning": "king",
    "ning": "ping",
    "ninitendo": "nintendo",
    "nintedno": "nintendo",
    "nintedo": "nintendo",
    "nintenbo": "nintendo",
    "nintendi": "nintendo",
    "nintendio": "nintendo",
    "nintendoo": "nintendo",
    "nintendow": "nintendo",
    "ninteno": "nintendo",
    "nintentdo": "nintendo",
    "nintento": "nintendo",
    "nintindo": "nintendo",
    "nintnedo": "nintendo",
    "niot": "not",
    "nis": "is",
    "nite": "nice",
    "nite": "note",
    "nite": "site",
    "nitendo": "nintendo",
    "nivites": "invites",
    "nj": "n",
    "nj": "no",
    "nj": "ny",
    "njoy": "enjoy",
    "nk": "no",
    "nkew": "new",
    "nlog": "blog",
    "nlove": "love",
    "nly": "only",
    "nm": "im",
    "nm": "no",
    "nme": "name",
    "nmeed": "need",
    "nmot": "not",
    "nmy": "my",
    "nned": "need",
    "nneed": "need",
    "nnew": "new",
    "nnot": "not",
    "nnow": "now",
    "nnw": "new",
    "nnw": "now",
    "nobel": "noble",
    "noe": "no",
    "noe": "not",
    "noe": "now",
    "noew": "new",
    "nof": "of",
    "noh": "now",
    "noi": "no",
    "noit": "not",
    "nokai": "nokia",
    "nokie": "nokia",
    "nom": "not",
    "nom": "now",
    "non": "no",
    "non": "not",
    "non": "now",
    "non": "on",
    "non": "son",
    "noo": "no",
    "noo": "not",
    "noo": "now",
    "noone": "none",
    "noop": "loop",
    "noot": "not",
    "nopt": "not",
    "nopw": "now",
    "noraml": "normal",
    "norbal": "normal",
    "noris": "norris",
    "normail": "normal",
    "nornal": "normal",
    "northen": "northern",
    "nost": "most",
    "nota": "not",
    "notfier": "notifier",
    "noth": "not",
    "nother": "another",
    "nothig": "nothing",
    "nothign": "nothing",
    "nothinq": "nothing",
    "nothng": "nothing",
    "notifcation": "notification",
    "notifcations": "notifications",
    "notifer": "notifier",
    "notiications": "notifications",
    "notiiced": "noticed",
    "noto": "not",
    "nott": "not",
    "notting": "nothing",
    "notus": "notes",
    "nou": "now",
    "nout": "not",
    "nov": "no",
    "nov": "not",
    "nov": "now",
    "nows": "knows",
    "nowt": "not",
    "nowt": "now",
    "noww": "now",
    "noy": "not",
    "noyification": "notification",
    "np": "up",
    "nph": "npr",
    "npp": "app",
    "npwhere": "nowhere",
    "nr": "or",
    "nrews": "news",
    "nrl": "url",
    "ns": "as",
    "ns": "us",
    "nsmb": "smb",
    "nso": "no",
    "nstead": "instead",
    "nsw": "new",
    "nt": "at",
    "nt": "dnt",
    "nt": "it",
    "nt": "no",
    "nt": "not",
    "nter": "enter",
    "nternet": "internet",
    "nto": "to",
    "ntop": "top",
    "nu": "no",
    "nu": "u",
    "nubmer": "number",
    "numchuck": "nunchuck",
    "numer": "number",
    "nunchuk": "nunchuck",
    "nuncuck": "nunchuck",
    "nup": "up",
    "nur": "our",
    "nust": "just",
    "nute": "nude",
    "nuthing": "nothing",
    "nutrality": "neutrality",
    "nvention": "invention",
    "nver": "never",
    "nvitation": "invitation",
    "nvite": "invite",
    "nvites": "invites",
    "nvo": "no",
    "nw": "new",
    "nw": "now",
    "nwe": "new",
    "nwo": "no",
    "nwo": "two",
    "nxt": "next",
    "nxt": "not",
    "ny": "any",
    "ny": "by",
    "ny": "my",
    "ny": "no",
    "nyc": "ny",
    "nyce": "nice",
    "nyone": "anyone",
    "nys": "nyc",
    "nyt": "net",
    "nyt": "not",
    "nz": "no",
    "oabama": "obama",
    "oalm": "palm",
    "oan": "on",
    "oand": "and",
    "oarange": "orange",
    "ob": "fb",
    "ob": "job",
    "ob": "of",
    "ob": "on",
    "obamao": "obama",
    "obame": "obama",
    "obe": "one",
    "obessed": "obsessed",
    "oboma": "obama",
    "obsesssed": "obsessed",
    "obssesed": "obsessed",
    "obssessed": "obsessed",
    "obtion": "option",
    "oc": "doc",
    "oc": "of",
    "oc": "on",
    "oc": "os",
    "oc": "pc",
    "ochochinco": "ochocinco",
    "ocial": "social",
    "ocme": "come",
    "ocnvite": "convite",
    "ocr": "or",
    "ocr": "our",
    "oct": "out",
    "octover": "october",
    "octuber": "october",
    "od": "do",
    "od": "god",
    "od": "of",
    "od": "old",
    "od": "on",
    "od": "or",
    "odea": "idea",
    "oder": "order",
    "oder": "over",
    "odered": "ordered",
    "odf": "of",
    "oding": "doing",
    "odor": "door",
    "ods": "ads",
    "oe": "one",
    "oe": "we",
    "oen": "on",
    "oen": "one",
    "oen": "own",
    "oer": "over",
    "oer": "per",
    "ofa": "of",
    "ofc": "of",
    "ofer": "offer",
    "offa": "off",
    "offcers": "officers",
    "offcially": "officially",
    "offereing": "offering",
    "offf": "off",
    "officailly": "officially",
    "offical": "official",
    "offically": "officially",
    "officals": "officials",
    "officiaal": "official",
    "officialy": "official",
    "officialy": "officially",
    "officialy": "officials",
    "officically": "officially",
    "officilly": "officially",
    "officle": "office",
    "offie": "office",
    "offivial": "official",
    "oficial": "official",
    "oficially": "officially",
    "ofp": "of",
    "ofr": "for",
    "ofr": "or",
    "ofter": "after",
    "og": "of",
    "og": "on",
    "og": "or",
    "oget": "get",
    "ogh": "oh",
    "ohey": "hey",
    "ohf": "of",
    "ohh": "ahh",
    "ohh": "oh",
    "ohk": "ok",
    "ohmg": "omg",
    "ohne": "one",
    "ohone": "phone",
    "ohs": "os",
    "oi": "i",
    "oi": "of",
    "oi": "on",
    "oi": "or",
    "oif": "of",
    "oii": "wii",
    "oin": "in",
    "oin": "on",
    "oine": "one",
    "oing": "going",
    "oinkmemt": "oinkment",
    "oit": "it",
    "oj": "of",
    "oj": "on",
    "ok": "of",
    "ok": "on",
    "ok": "or",
    "ok": "os",
    "ok": "uk",
    "oka": "ok",
    "okia": "nokia",
    "ol": "lol",
    "ol": "of",
    "ol": "on",
    "olaying": "playing",
    "oldy": "old",
    "ole": "old",
    "ole": "one",
    "olean": "ocean",
    "oled": "old",
    "oline": "line",
    "olly": "only",
    "olny": "only",
    "olso": "also",
    "olympia": "olympic",
    "om": "im",
    "om": "mom",
    "om": "nom",
    "om": "of",
    "om": "on",
    "om": "or",
    "om": "os",
    "oman": "man",
    "ome": "home",
    "ome": "one",
    "ome": "some",
    "omfg": "omg",
    "omgg": "omg",
    "omgz": "omg",
    "oming": "coming",
    "ona": "on",
    "ona": "one",
    "onb": "on",
    "onbe": "one",
    "ond": "and",
    "ond": "old",
    "onee": "one",
    "onely": "lonely",
    "oness": "ones",
    "onew": "new",
    "onew": "one",
    "onf": "of",
    "ong": "long",
    "onh": "on",
    "onl": "one",
    "onlay": "only",
    "onley": "only",
    "online": "onlien",
    "onlly": "only",
    "onlt": "only",
    "onlu": "only",
    "onlyl": "only",
    "onmy": "only",
    "onn": "on",
    "onna": "gonna",
    "onnly": "only",
    "ono": "mono",
    "ono": "one",
    "onr": "one",
    "ont": "dont",
    "ont": "on",
    "ont": "out",
    "ontil": "until",
    "onu": "on",
    "onver": "over",
    "onw": "own",
    "onwers": "owners",
    "ony": "any",
    "ony": "on",
    "ony": "only",
    "onyl": "only",
    "oo": "do",
    "oo": "go",
    "oo": "of",
    "oo": "oh",
    "oo": "on",
    "oo": "or",
    "oo": "os",
    "oo": "so",
    "oo": "to",
    "oo": "too",
    "ooff": "off",
    "oogle": "google",
    "ooh": "oh",
    "oon": "on",
    "ooo": "too",
    "ooo": "woo",
    "ooo": "zoo",
    "oor": "for",
    "oor": "or",
    "oot": "got",
    "oot": "out",
    "oout": "out",
    "oow": "now",
    "opctober": "october",
    "ope": "hope",
    "openion": "opinion",
    "ophone": "iphone",
    "oping": "hoping",
    "opinionn": "opinion",
    "opinon": "opinion",
    "opinons": "opinions",
    "opn": "on",
    "opne": "one",
    "opnion": "option",
    "oportunity": "opportunity",
    "oposite": "opposite",
    "opp": "app",
    "opperating": "operating",
    "oppertunity": "opportunity",
    "oppisite": "opposite",
    "opps": "apps",
    "oppsoed": "opposed",
    "opt": "out",
    "opther": "other",
    "optimise": "optimize",
    "optimised": "optimized",
    "optimiser": "optimizer",
    "optimzed": "optimized",
    "optimzer": "optimizer",
    "optmizer": "optimizer",
    "optomized": "optimized",
    "oragnge": "orange",
    "oranage": "orange",
    "orc": "or",
    "orderd": "ordered",
    "orf": "off",
    "org": "or",
    "organise": "organize",
    "organised": "organized",
    "organises": "organizes",
    "orginal": "original",
    "origional": "original",
    "orignal": "original",
    "origonal": "original",
    "oriinal": "original",
    "ornage": "orange",
    "ort": "sort",
    "os": "as",
    "os": "is",
    "os": "ms",
    "os": "of",
    "os": "on",
    "os": "op",
    "os": "or",
    "os": "so",
    "os": "us",
    "osama": "obama",
    "osm": "os",
    "oso": "so",
    "oss": "os",
    "ost": "out",
    "osx": "os",
    "ot": "at",
    "ot": "got",
    "ot": "it",
    "ot": "not",
    "ot": "of",
    "ot": "on",
    "ot": "or",
    "ot": "out",
    "ot": "to",
    "otehr": "other",
    "oter": "other",
    "oth": "both",
    "othe": "the",
    "othr": "other",
    "otimizer": "optimizer",
    "otld": "told",
    "otp": "top",
    "ots": "its",
    "ott": "out",
    "otuch": "touch",
    "ou": "of",
    "ou": "on",
    "ou": "or",
    "ou": "os",
    "ou": "you",
    "oubreaks": "outbreaks",
    "ouf": "of",
    "oug": "out",
    "ouh": "out",
    "oui": "out",
    "oun": "own",
    "ouo": "out",
    "ourt": "out",
    "outa": "out",
    "outbreakk": "outbreak",
    "outbreat": "outbreak",
    "outreaks": "outbreaks",
    "outswll": "outsell",
    "outt": "out",
    "outtta": "outta",
    "ouu": "out",
    "ouut": "out",
    "ouutbreak": "outbreak",
    "ouy": "out",
    "ouyt": "out",
    "ov": "of",
    "ov": "on",
    "ovah": "ova",
    "ovar": "over",
    "ove": "love",
    "ove": "one",
    "overe": "over",
    "ovfer": "over",
    "ovner": "owner",
    "ovr": "or",
    "ovr": "our",
    "ovr": "over",
    "owh": "oh",
    "ownrs": "owners",
    "ownz": "own",
    "ownz": "owns",
    "owrking": "working",
    "owt": "out",
    "owuld": "would",
    "oww": "wow",
    "oy": "my",
    "oy": "on",
    "oyt": "out",
    "oyu": "you",
    "paar": "para",
    "paarking": "parking",
    "pac": "mac",
    "pacfic": "pacific",
    "pacifc": "pacific",
    "pademic": "pandemic",
    "paeg": "page",
    "pager": "page",
    "pagers": "pages",
    "pagez": "pages",
    "paim": "pain",
    "pais": "paris",
    "paitently": "patiently",
    "paitents": "patients",
    "pak": "pack",
    "pak": "pay",
    "pake": "make",
    "pake": "take",
    "pala": "para",
    "palce": "place",
    "palin": "pain",
    "pallm": "palm",
    "paly": "play",
    "palying": "paying",
    "palying": "playing",
    "pamdemic": "pandemic",
    "pand": "and",
    "paperr": "paper",
    "paps": "apps",
    "param": "para",
    "parang": "padang",
    "paranoraml": "paranormal",
    "parinoia": "paranoia",
    "paris": "parts",
    "parntership": "partnership",
    "paros": "paris",
    "parrt": "part",
    "parter": "partner",
    "partership": "partnership",
    "particpated": "participated",
    "partisipate": "participate",
    "pas": "has",
    "pas": "pass",
    "pas": "was",
    "patiencly": "patiently",
    "patnership": "partnership",
    "payd": "paid",
    "paye": "page",
    "payed": "played",
    "pazific": "pacific",
    "pb": "cb",
    "pb": "fb",
    "pb": "pc",
    "pbest": "best",
    "pc": "dc",
    "pc": "pic",
    "pc": "ppc",
    "pckage": "package",
    "pcs": "pics",
    "pd": "id",
    "pda": "da",
    "pdf": "pdq",
    "pdt": "put",
    "pe": "me",
    "pe": "pre",
    "pe": "we",
    "peaple": "people",
    "pease": "please",
    "pecause": "because",
    "pecent": "percent",
    "pecentage": "percentage",
    "ped": "bed",
    "peice": "peace",
    "peice": "piece",
    "peice": "price",
    "peiple": "people",
    "pelase": "please",
    "pendemic": "pandemic",
    "peole": "people",
    "peope": "people",
    "peopel": "people",
    "peopele": "people",
    "peoplea": "people",
    "peoplr": "people",
    "peoplt": "people",
    "peoplw": "people",
    "peopole": "people",
    "peoud": "proud",
    "peparing": "preparing",
    "peple": "people",
    "pepole": "people",
    "percautions": "precautions",
    "pereparing": "preparing",
    "perfer": "prefer",
    "perfet": "perfect",
    "perhpas": "perhaps",
    "perosn": "person",
    "perpare": "prepare",
    "perpared": "prepared",
    "personalise": "personalize",
    "personn": "person",
    "pespi": "pepsi",
    "peuple": "people",
    "pevent": "prevent",
    "peview": "preview",
    "peview": "review",
    "pf": "of",
    "pff": "off",
    "pg": "pig",
    "pgae": "page",
    "pge": "page",
    "pges": "pages",
    "pgot": "got",
    "phanton": "phantom",
    "phat": "that",
    "phat": "what",
    "pheonix": "phoenix",
    "philipines": "philippines",
    "phne": "phone",
    "pho": "who",
    "phobe": "phone",
    "phobos": "photos",
    "phoe": "phone",
    "phoen": "phone",
    "phond": "phone",
    "phoner": "phone",
    "phonje": "phone",
    "phonography": "photography",
    "phont": "phone",
    "phoone": "phone",
    "phot": "shot",
    "photochop": "photoshop",
    "photog": "photo",
    "photog": "photos",
    "photohop": "photoshop",
    "photoshopp": "photoshop",
    "photoshot": "photoshop",
    "photoshp": "photoshop",
    "photosop": "photoshop",
    "photshop": "photoshop",
    "phtotoshop": "photoshop",
    "phusical": "physical",
    "piacked": "picked",
    "pibg": "ping",
    "pic": "pc",
    "pic": "pig",
    "pic": "ppc",
    "pice": "pic",
    "pice": "piece",
    "pickinp": "picking",
    "picolo": "piccolo",
    "pics": "pigs",
    "picss": "pics",
    "pict": "pic",
    "pict": "pics",
    "pictre": "picture",
    "pictres": "pictures",
    "picts": "pics",
    "pictue": "picture",
    "picturee": "picture",
    "picu": "pics",
    "picutre": "picture",
    "picutres": "pictures",
    "picuture": "picture",
    "pieace": "piece",
    "piecw": "piece",
    "pigggy": "piggy",
    "piggly": "piggy",
    "pigy": "pig",
    "pigy": "piggy",
    "pii": "wii",
    "piint": "point",
    "pik": "pic",
    "pik": "pick",
    "piks": "pics",
    "pikture": "picture",
    "pilling": "filling",
    "pim": "him",
    "pim": "im",
    "pind": "ping",
    "pingle": "single",
    "piq": "pic",
    "piratei": "pirate",
    "pishing": "pissing",
    "pisisng": "pissing",
    "pissess": "pisses",
    "pissinq": "pissing",
    "pissn": "piss",
    "pisssing": "pissing",
    "pistures": "pictures",
    "pitcture": "picture",
    "pitures": "pictures",
    "pivtures": "pictures",
    "pix": "fix",
    "pix": "mix",
    "pix": "pic",
    "pix": "pie",
    "pix": "pig",
    "pix": "six",
    "pixs": "pics",
    "pkay": "play",
    "pkaying": "playing",
    "plaay": "play",
    "plaayed": "played",
    "plaaying": "playing",
    "plaese": "please",
    "plah": "play",
    "plaing": "playing",
    "plam": "palm",
    "plam": "play",
    "planer": "planner",
    "planit": "planet",
    "plannning": "planning",
    "plano": "plans",
    "plase": "please",
    "plass": "pass",
    "plat": "play",
    "platforn": "platform",
    "playd": "play",
    "playd": "played",
    "playe": "play",
    "playibg": "playing",
    "playign": "playing",
    "playiin": "playin",
    "playiing": "playing",
    "playimg": "playing",
    "playinf": "playing",
    "playingg": "playing",
    "playinh": "playing",
    "playinn": "playin",
    "playinn": "playing",
    "playinng": "playing",
    "playinq": "playin",
    "playinq": "playing",
    "playling": "playing",
    "playn": "play",
    "playng": "playing",
    "playnig": "playing",
    "playoing": "playing",
    "playon": "playin",
    "playong": "playing",
    "playy": "play",
    "playyed": "played",
    "pleaase": "please",
    "pleae": "please",
    "pleasse": "please",
    "pleaze": "please",
    "pleazse": "please",
    "pleease": "please",
    "plese": "please",
    "plez": "plz",
    "plist": "list",
    "pliz": "plz",
    "pllenty": "plenty",
    "plone": "phone",
    "plrase": "please",
    "pls": "plz",
    "plsce": "place",
    "plsying": "playing",
    "pludge": "plunge",
    "pluged": "plugged",
    "pluss": "plus",
    "pluz": "plz",
    "plx": "plz",
    "plya": "play",
    "plyin": "playin",
    "plzz": "plz",
    "pm": "dm",
    "pm": "im",
    "pm": "m",
    "pmaybe": "maybe",
    "pn": "on",
    "pnd": "and",
    "png": "pig",
    "png": "ping",
    "pngs": "pigs",
    "pnly": "only",
    "pnn": "cnn",
    "pnumonia": "pneumonia",
    "poblem": "problem",
    "poeple": "people",
    "poisening": "poisoning",
    "poisining": "poisoning",
    "poket": "pocket",
    "pol": "ppl",
    "pon": "on",
    "poo": "boo",
    "poo": "too",
    "poosible": "possible",
    "pople": "people",
    "popolar": "popular",
    "populair": "popular",
    "populer": "popular",
    "popupar": "popular",
    "por": "for",
    "por": "or",
    "por": "pro",
    "portble": "portable",
    "portect": "protect",
    "ported": "posted",
    "posative": "positive",
    "posibility": "possibility",
    "posible": "possible",
    "positivee": "positive",
    "positve": "positive",
    "poss": "post",
    "possable": "possible",
    "possbile": "possible",
    "possble": "possible",
    "possiable": "possible",
    "possibe": "possible",
    "possibel": "possible",
    "possibilty": "possibility",
    "possiblr": "possible",
    "possilbe": "possible",
    "possile": "possible",
    "possing": "pissing",
    "posssible": "possible",
    "postg": "post",
    "postiive": "positive",
    "postion": "position",
    "postitive": "positive",
    "postive": "positive",
    "postoned": "postponed",
    "potencial": "potential",
    "potenyial": "potential",
    "poto": "photo",
    "pouplar": "popular",
    "pow": "now",
    "powerd": "powered",
    "powerfull": "powerful",
    "powrful": "powerful",
    "ppc": "pc",
    "ppc": "ppl",
    "ppiggy": "piggy",
    "ppl": "ppc",
    "pplaying": "playing",
    "pple": "apple",
    "pple": "ppl",
    "pplz": "ppl",
    "ppp": "app",
    "ppp": "ppl",
    "ppssible": "possible",
    "ppt": "put",
    "pr": "or",
    "pr": "ur",
    "pra": "para",
    "pra": "pro",
    "praay": "pray",
    "prary": "pray",
    "prayy": "pray",
    "prblems": "problems",
    "pre": "are",
    "pre": "pro",
    "preapred": "prepared",
    "precvent": "prevent",
    "predicitve": "predictive",
    "predident": "president",
    "pree": "pre",
    "preety": "pretty",
    "preffer": "prefer",
    "pregant": "pregnant",
    "preita": "prieta",
    "preivew": "preview",
    "prengancy": "pregnancy",
    "prepaired": "prepared",
    "prepapred": "prepared",
    "preparez": "prepares",
    "preperation": "preparation",
    "prepered": "prepared",
    "preping": "prepping",
    "pres": "press",
    "presdent": "president",
    "presenation": "presentation",
    "presentaion": "presentation",
    "preson": "person",
    "pretect": "protect",
    "pretent": "prevent",
    "prettty": "pretty",
    "pretweet": "retweet",
    "prety": "pretty",
    "prevalnt": "prevalent",
    "prevenative": "preventative",
    "prevening": "preventing",
    "preventataive": "preventative",
    "prevetative": "preventative",
    "prevew": "preview",
    "prevntion": "prevention",
    "preyers": "prayers",
    "prez": "pre",
    "pri": "pro",
    "priata": "prieta",
    "pricem": "price",
    "prics": "price",
    "prietta": "prieta",
    "pritty": "pretty",
    "prnt": "print",
    "proaganda": "propaganda",
    "prob": "pro",
    "probabaly": "probably",
    "probaby": "probably",
    "probally": "probably",
    "probaly": "probably",
    "probbably": "probably",
    "probelms": "problems",
    "probibly": "probably",
    "problably": "probably",
    "problema": "problem",
    "problemas": "problems",
    "problens": "problems",
    "problesm": "problems",
    "problums": "problems",
    "proboably": "probably",
    "probobly": "probably",
    "probs": "probe",
    "proccess": "process",
    "proce": "price",
    "proces": "process",
    "proctector": "protector",
    "profect": "project",
    "profesional": "professional",
    "proft": "profit",
    "prog": "pro",
    "projcector": "projector",
    "projekt": "project",
    "prol": "pro",
    "promese": "promise",
    "prono": "promo",
    "propect": "prospect",
    "propganda": "propaganda",
    "prople": "people",
    "prostest": "protest",
    "protech": "protect",
    "protecter": "protector",
    "protos": "photos",
    "protoshop": "photoshop",
    "pround": "proud",
    "provin": "proven",
    "prqy": "pray",
    "prt": "part",
    "prt": "rt",
    "prtty": "pretty",
    "prvent": "prevent",
    "prventative": "preventative",
    "ps": "as",
    "ps": "ds",
    "ps": "gps",
    "ps": "is",
    "ps": "os",
    "ps": "pc",
    "ps": "pls",
    "ps": "us",
    "ps": "vs",
    "pse": "pre",
    "pstbuy": "pdtbuy",
    "psunami": "tsunami",
    "psymptoms": "symptoms",
    "ptoblems": "problems",
    "pts": "its",
    "ptwo": "two",
    "pu": "up",
    "publick": "public",
    "publik": "public",
    "puc": "pic",
    "puero": "puerto",
    "puerto": "peurto",
    "puls": "plus",
    "pune": "zune",
    "pupl": "pulp",
    "pupular": "popular",
    "pur": "our",
    "pur": "put",
    "purcahse": "purchase",
    "purchaces": "purchases",
    "purchuse": "purchase",
    "purhase": "purchase",
    "pushn": "push",
    "puta": "put",
    "putn": "put",
    "putz": "put",
    "puzzier": "puzzler",
    "pwanage": "pwnage",
    "pwange": "pwnage",
    "pwe": "we",
    "pwease": "please",
    "pwebhost": "wpwebhost",
    "pwer": "power",
    "pwetty": "pretty",
    "pwn": "own",
    "pwners": "owners",
    "pwnge": "pwnage",
    "pwople": "people",
    "py": "my",
    "pyt": "put",
    "pz": "plz",
    "pzl": "plz",
    "qa": "a",
    "qame": "game",
    "qames": "games",
    "qare": "are",
    "qave": "gave",
    "qave": "have",
    "qb": "b",
    "qcommercial": "commercial",
    "qe": "e",
    "qet": "get",
    "qet": "set",
    "qettin": "gettin",
    "qetting": "getting",
    "qi": "i",
    "qii": "wii",
    "qin": "win",
    "qirl": "girl",
    "qith": "with",
    "qive": "give",
    "qlad": "glad",
    "qn": "in",
    "qo": "do",
    "qo": "go",
    "qo": "to",
    "qoin": "goin",
    "qoite": "quite",
    "qol": "lol",
    "qonna": "gonna",
    "qood": "good",
    "qore": "more",
    "qos": "os",
    "qot": "got",
    "qot": "not",
    "qotta": "gotta",
    "qry": "try",
    "qs": "is",
    "qs": "us",
    "qtf": "wtf",
    "qtweet": "tweet",
    "qtwitter": "twitter",
    "quailty": "quality",
    "quakery": "quackery",
    "quarentine": "quarantine",
    "quartely": "quarterly",
    "que": "due",
    "queastion": "question",
    "queeen": "queen",
    "quesitions": "questions",
    "quesitons": "questions",
    "quess": "guess",
    "questoin": "question",
    "queston": "question",
    "questtion": "question",
    "quetion": "question",
    "quietely": "quietly",
    "quik": "quick",
    "quitar": "guitar",
    "qwhy": "why",
    "ra": "a",
    "rabids": "rabbids",
    "racibg": "racing",
    "rad": "bad",
    "rad": "dad",
    "rad": "had",
    "rad": "read",
    "radion": "radio",
    "radiou": "radio",
    "rady": "ready",
    "rae": "are",
    "raesort": "resort",
    "raint": "rain",
    "rality": "reality",
    "rankings": "ranking",
    "rankngs": "rankings",
    "ranslate": "translate",
    "ranyone": "anyone",
    "raod": "road",
    "rapple": "apple",
    "rar": "bar",
    "rar": "car",
    "rases": "cases",
    "rass": "ass",
    "rathen": "rather",
    "raymain": "rayman",
    "rb": "rt",
    "rc": "pc",
    "rc": "rt",
    "rcord": "record",
    "rd": "rid",
    "rdropbox": "dropbox",
    "rdying": "dying",
    "reaader": "reader",
    "reaading": "reading",
    "reaally": "really",
    "reaaly": "really",
    "reacation": "reaction",
    "readdy": "ready",
    "reade": "ready",
    "readee": "reader",
    "readeer": "reader",
    "readinq": "reading",
    "readr": "reader",
    "readyy": "ready",
    "reaeder": "reader",
    "realease": "release",
    "realeased": "released",
    "realeasing": "releasing",
    "realey": "really",
    "realise": "realize",
    "realised": "realized",
    "realite": "reality",
    "realizd": "realized",
    "realizied": "realized",
    "reallky": "really",
    "reallly": "really",
    "reallt": "really",
    "reallx": "really",
    "reallyt": "really",
    "reallyy": "really",
    "realt": "real",
    "realy": "ready",
    "realy": "real",
    "realy": "really",
    "realyy": "really",
    "realzied": "realized",
    "reaon": "reason",
    "reaosn": "reason",
    "rearly": "really",
    "reasd": "read",
    "reasearch": "research",
    "reaser": "reader",
    "reasion": "reason",
    "reasln": "reason",
    "reasn": "reason",
    "reasoon": "reason",
    "reasson": "reason",
    "reat": "read",
    "reat": "rest",
    "reate": "create",
    "reay": "ready",
    "recapcha": "recaptcha",
    "recapctha": "recaptcha",
    "recaptacha": "recaptcha",
    "reccieve": "recieve",
    "reccommend": "recommend",
    "reccommendations": "recommendations",
    "receieved": "received",
    "recesion": "recession",
    "recesssion": "recession",
    "recevied": "received",
    "reciecve": "recieve",
    "reciepe": "recipe",
    "recieve": "receive",
    "recieved": "received",
    "recive": "receive",
    "recived": "received",
    "reciver": "recover",
    "recocer": "recover",
    "recomend": "recommend",
    "recomendation": "recommendation",
    "recomendations": "recommendations",
    "recommand": "recommend",
    "recommandations": "recommendations",
    "recomment": "recommend",
    "recommnd": "recommend",
    "recommnedations": "recommendations",
    "recommondations": "recommendations",
    "recommrnd": "recommend",
    "recoverd": "recover",
    "recoverd": "recovered",
    "recoverimg": "recovering",
    "recoveringg": "recovering",
    "recoverying": "recovering",
    "recovvering": "recovering",
    "recuvering": "recovering",
    "reday": "ready",
    "rediculous": "ridiculous",
    "redue": "reduce",
    "redy": "ready",
    "reead": "read",
    "reeally": "really",
    "reeboot": "reboot",
    "reeder": "reader",
    "refer": "prefer",
    "referrence": "reference",
    "referrring": "referring",
    "refue": "refuse",
    "refular": "regular",
    "refuseniks": "refusniks",
    "reggular": "regular",
    "regioster": "register",
    "registerd": "registered",
    "regluar": "regular",
    "regu": "reg",
    "regualar": "regular",
    "regualr": "regular",
    "reguarding": "regarding",
    "regulart": "regular",
    "reially": "really",
    "reid": "read",
    "reid": "rid",
    "reinds": "reminds",
    "rejcted": "rejected",
    "rel": "rea",
    "rel": "real",
    "relaized": "realized",
    "relalised": "realised",
    "relaly": "really",
    "relased": "related",
    "relased": "released",
    "releast": "release",
    "releif": "relief",
    "relese": "release",
    "releses": "releases",
    "reley": "rely",
    "relised": "realised",
    "relize": "realize",
    "relized": "realized",
    "relly": "really",
    "remail": "email",
    "remeber": "remember",
    "remebered": "remembered",
    "remeidy": "remedy",
    "rememberd": "remembered",
    "remembr": "remember",
    "rememeber": "remember",
    "rememvbered": "remembered",
    "remine": "remind",
    "reminiding": "reminding",
    "remiond": "remind",
    "remmber": "remember",
    "remore": "remote",
    "remotly": "remotely",
    "reninds": "reminds",
    "reomved": "removed",
    "repalace": "replace",
    "replacemant": "replacement",
    "replecement": "replacement",
    "reponse": "response",
    "reportd": "reported",
    "reporteda": "reported",
    "reportng": "reporting",
    "repost": "report",
    "reprts": "reports",
    "repsonse": "response",
    "reputatin": "reputation",
    "req": "reg",
    "reqadies": "readies",
    "requast": "request",
    "requestd": "request",
    "requestd": "requested",
    "requestet": "requested",
    "requiered": "required",
    "reqular": "regular",
    "resataurant": "restaurant",
    "reserach": "research",
    "resest": "reset",
    "reseult": "result",
    "resh": "fresh",
    "reslease": "release",
    "reslts": "results",
    "reson": "reason",
    "resored": "restored",
    "resorta": "resort",
    "resotre": "restore",
    "resoure": "resource",
    "resp": "rest",
    "resperatory": "respiratory",
    "respitatory": "respiratory",
    "responisble": "responsible",
    "resport": "resort",
    "resposible": "responsible",
    "resquest": "request",
    "resrt": "resort",
    "resson": "reason",
    "restoreing": "restoring",
    "restration": "restoration",
    "restuarant": "restaurant",
    "resturant": "restaurant",
    "resutls": "results",
    "resuts": "results",
    "rething": "rethink",
    "retoring": "restoring",
    "returnd": "returned",
    "retweting": "retweeting",
    "reular": "regular",
    "reults": "results",
    "reveived": "received",
    "revew": "review",
    "revieew": "review",
    "revies": "review",
    "revolotion": "revolution",
    "revoloution": "revolution",
    "revovering": "recovering",
    "rewiew": "review",
    "rght": "right",
    "rhan": "than",
    "rhapsdy": "rhapsody",
    "rhe": "the",
    "rhit": "hit",
    "rhought": "thought",
    "ri": "i",
    "ria": "rim",
    "ric": "rip",
    "richtor": "richter",
    "ricter": "richter",
    "ricther": "richter",
    "rid": "did",
    "rid": "rip",
    "ridding": "kidding",
    "riden": "ride",
    "riends": "friends",
    "rif": "if",
    "rightt": "right",
    "righty": "right",
    "rigntones": "ringtones",
    "rigt": "right",
    "rigth": "right",
    "riight": "right",
    "riite": "rite",
    "ringone": "ringtone",
    "ringotones": "ringtones",
    "ringtines": "ringtones",
    "ringtonea": "ringtones",
    "ringtunes": "ringtones",
    "rio": "rip",
    "riqht": "right",
    "ris": "rid",
    "rit": "it",
    "riting": "writing",
    "rj": "rt",
    "rjust": "just",
    "rlz": "plz",
    "rm": "arm",
    "rm": "im",
    "rmaps": "maps",
    "rmember": "remember",
    "rmy": "my",
    "rn": "in",
    "rn": "run",
    "rnd": "and",
    "ro": "or",
    "ro": "so",
    "ro": "to",
    "roasd": "road",
    "rochocinco": "ochocinco",
    "rocj": "rock",
    "rockbank": "rockband",
    "rocketsu": "rockets",
    "rockk": "rock",
    "rockss": "rocks",
    "rockt": "rocks",
    "rom": "from",
    "rom": "room",
    "rome": "come",
    "rome": "home",
    "rome": "role",
    "rome": "rose",
    "rome": "some",
    "ron": "on",
    "rong": "wrong",
    "rongtone": "ringtone",
    "roon": "room",
    "rooom": "room",
    "ror": "or",
    "ros": "pros",
    "roth": "both",
    "rouncd": "round",
    "rounf": "round",
    "roy": "boy",
    "rrad": "read",
    "rre": "are",
    "rreader": "reader",
    "rs": "is",
    "rsa": "usa",
    "rss": "ass",
    "rsync": "sync",
    "rt": "art",
    "rt": "at",
    "rt": "it",
    "rt": "r",
    "rta": "rt",
    "rtbots": "robots",
    "rtf": "rt",
    "rthe": "the",
    "rti": "rt",
    "rtm": "rt",
    "rto": "to",
    "rtp": "rt",
    "rts": "its",
    "rts": "rss",
    "rtweet": "retweet",
    "rty": "rt",
    "ru": "u",
    "rubert": "rupert",
    "rugular": "regular",
    "rulles": "rules",
    "rumer": "rumor",
    "runing": "running",
    "runining": "running",
    "runn": "run",
    "runnig": "running",
    "runnng": "running",
    "runnning": "running",
    "runnung": "running",
    "rurns": "turns",
    "rus": "us",
    "rv": "rt",
    "rweally": "really",
    "rx": "rt",
    "rxn": "run",
    "ry": "my",
    "ry": "try",
    "ryt": "rt",
    "sa": "a",
    "sa": "as",
    "sa": "sc",
    "sa": "so",
    "sacared": "scared",
    "safarai": "safari",
    "saftey": "safety",
    "sahot": "shot",
    "saidd": "said",
    "saids": "said",
    "saif": "said",
    "saiid": "said",
    "saince": "since",
    "salk": "talk",
    "sals": "sale",
    "sam": "am",
    "sam": "fam",
    "sam": "say",
    "samao": "samoa",
    "samoan": "samoa",
    "samoha": "samoa",
    "samon": "samoan",
    "samona": "samoa",
    "samoo": "samoa",
    "samor": "samoa",
    "samos": "samoa",
    "samual": "samuel",
    "san": "an",
    "san": "can",
    "san": "son",
    "sanatizer": "sanitizer",
    "sandox": "sandbox",
    "sanitizeer": "sanitizer",
    "sanitzer": "sanitizer",
    "santitizer": "sanitizer",
    "santizer": "sanitizer",
    "sanyjay": "sanjay",
    "sao": "san",
    "sars": "says",
    "sars": "stars",
    "sars": "wars",
    "sart": "start",
    "sarted": "started",
    "sarting": "starting",
    "sas": "as",
    "sas": "has",
    "sase": "sale",
    "sasonal": "seasonal",
    "sasve": "save",
    "satelite": "satellite",
    "saudia": "saudi",
    "sawg": "swag",
    "saww": "saw",
    "sayd": "said",
    "sayd": "says",
    "sayi": "say",
    "sayig": "saying",
    "sayimg": "saying",
    "sayn": "say",
    "sayss": "says",
    "sayy": "say",
    "sayy": "says",
    "sayz": "says",
    "sb": "sc",
    "sb": "so",
    "sbould": "should",
    "sbrin": "brin",
    "sc": "so",
    "scaared": "scared",
    "scam": "scan",
    "scard": "scared",
    "scaredd": "scared",
    "scarep": "scared",
    "sceen": "scene",
    "sceen": "screen",
    "scheduler": "scheduled",
    "schhol": "school",
    "schhool": "school",
    "schillr": "schiller",
    "schimdt": "schmidt",
    "schmit": "schmidt",
    "schol": "school",
    "scholl": "school",
    "schooll": "school",
    "schoool": "school",
    "schould": "should",
    "scik": "sick",
    "scince": "since",
    "sck": "sick",
    "sckool": "school",
    "scmidt": "schmidt",
    "sco": "so",
    "scool": "school",
    "scoped": "scored",
    "scot": "shot",
    "scott": "scots",
    "screan": "screen",
    "screeen": "screen",
    "screeenshot": "screenshot",
    "screem": "screen",
    "screenr": "screen",
    "screenshopt": "screenshot",
    "scren": "screen",
    "screne": "screen",
    "scured": "scared",
    "sd": "hd",
    "sd": "so",
    "sdiewiki": "sidewiki",
    "sdk": "idk",
    "sdo": "do",
    "sdore": "sore",
    "se": "be",
    "se": "he",
    "se": "me",
    "se": "see",
    "se": "she",
    "se": "so",
    "se": "use",
    "seaaon": "season",
    "seaarch": "search",
    "seaasonal": "seasonal",
    "seach": "search",
    "seached": "searched",
    "seacrh": "search",
    "seak": "speak",
    "sean": "seen",
    "seaon": "season",
    "seaonal": "seasonal",
    "seaoson": "season",
    "searach": "search",
    "searcg": "search",
    "searchd": "search",
    "searchingg": "searching",
    "searcjed": "searched",
    "searck": "search",
    "searh": "search",
    "searhing": "searching",
    "searies": "series",
    "seasame": "sesame",
    "seaseon": "season",
    "seasion": "season",
    "seasme": "sesame",
    "seasn": "season",
    "seasnal": "seasonal",
    "seasoal": "seasonal",
    "seasom": "season",
    "seasonale": "seasonal",
    "seasonall": "seasonal",
    "seasonl": "seasonal",
    "seasrch": "search",
    "seasson": "season",
    "seaszon": "season",
    "secod": "second",
    "secong": "second",
    "secound": "second",
    "sed": "see",
    "sed": "send",
    "sed": "used",
    "sedning": "sending",
    "seea": "see",
    "seear": "swear",
    "seee": "see",
    "seeems": "seems",
    "seeen": "seen",
    "seeiing": "seeing",
    "seein": "seen",
    "seel": "see",
    "seel": "sell",
    "seeling": "selling",
    "seens": "seems",
    "seent": "sent",
    "seeoms": "seems",
    "seeu": "see",
    "seing": "being",
    "seirious": "serious",
    "sejt": "sent",
    "sel": "see",
    "sel": "sell",
    "selebes": "celebes",
    "seling": "selling",
    "sellign": "selling",
    "sellingq": "selling",
    "sellling": "selling",
    "selln": "sell",
    "sellnig": "selling",
    "sem": "see",
    "sem": "seem",
    "sem": "seo",
    "sem": "set",
    "semd": "send",
    "semoa": "samoa",
    "semptoms": "symptoms",
    "sen": "see",
    "sen": "seen",
    "senc": "send",
    "sence": "sense",
    "sence": "since",
    "sendd": "send",
    "sendig": "sending",
    "sendn": "send",
    "sendng": "sending",
    "sendt": "sent",
    "sendy": "send",
    "senf": "send",
    "sens": "send",
    "sents": "sent",
    "seo": "see",
    "seo": "sem",
    "seo": "set",
    "seo": "so",
    "seoing": "seeing",
    "sep": "set",
    "seper": "super",
    "sept": "sent",
    "sept": "set",
    "ser": "see",
    "serach": "search",
    "seraches": "searches",
    "seraching": "searching",
    "serch": "search",
    "serched": "searched",
    "serches": "searches",
    "serems": "seems",
    "sergej": "sergey",
    "sergy": "sergey",
    "seriogs": "serious",
    "seriosly": "seriously",
    "seriosuly": "seriously",
    "sert": "set",
    "servival": "survival",
    "servived": "survived",
    "seson": "season",
    "sesonal": "seasonal",
    "sessages": "messages",
    "seth": "set",
    "setttings": "settings",
    "setuff": "stuff",
    "sevice": "service",
    "sewine": "swine",
    "sext": "next",
    "sext": "sex",
    "sext": "text",
    "sey": "say",
    "sey": "sky",
    "sez": "see",
    "sez": "set",
    "sf": "if",
    "sf": "of",
    "sf": "so",
    "sflu": "flu",
    "sfn": "son",
    "sfo": "seo",
    "sfo": "so",
    "sg": "so",
    "sgs": "usgs",
    "shaby": "shabby",
    "shal": "shall",
    "shawn": "shaun",
    "sheck": "check",
    "shee": "see",
    "shee": "she",
    "shen": "she",
    "shen": "when",
    "shep": "she",
    "sher": "her",
    "shetchbook": "sketchbook",
    "shiat": "shit",
    "shid": "shit",
    "shiet": "shit",
    "shii": "shit",
    "shiit": "shit",
    "shince": "since",
    "shiney": "shiny",
    "shite": "shit",
    "shite": "site",
    "shite": "white",
    "shitt": "shit",
    "shitz": "shit",
    "shiz": "shit",
    "shleep": "sleep",
    "shmidt": "schmidt",
    "sho": "so",
    "sho": "who",
    "shoild": "should",
    "shold": "should",
    "sholud": "should",
    "sholuld": "should",
    "shoping": "shopping",
    "shor": "shot",
    "shos": "shots",
    "shost": "shot",
    "shot_": "shot",
    "shota": "shots",
    "shotage": "shortage",
    "shotd": "shots",
    "shote": "shots",
    "shoti": "shot",
    "shotr": "shot",
    "shotsa": "shots",
    "shott": "shot",
    "shoty": "shot",
    "shotz": "shot",
    "shou": "shot",
    "shoud": "should",
    "shoudl": "should",
    "shouid": "should",
    "shoukd": "should",
    "shoukld": "should",
    "shoula": "shoulda",
    "shoulda": "should",
    "shouldd": "should",
    "shouldda": "shoulda",
    "shouldi": "should",
    "shouldn": "should",
    "shouldv": "should",
    "shoulf": "should",
    "shoulg": "should",
    "shouold": "should",
    "shoutout": "shootout",
    "shouw": "show",
    "showd": "showed",
    "shre": "share",
    "shrome": "chrome",
    "shrt": "short",
    "shrtage": "shortage",
    "sht": "shit",
    "sht": "shot",
    "shts": "shots",
    "shtt": "shot",
    "shu": "she",
    "shuff": "stuff",
    "shuffel": "shuffle",
    "shuld": "should",
    "shuold": "should",
    "shure": "sure",
    "shwine": "swine",
    "shwo": "show",
    "shxt": "shit",
    "shxt": "shot",
    "shyt": "shit",
    "shyt": "shot",
    "siad": "said",
    "sicc": "sick",
    "sice": "since",
    "sich": "sick",
    "sicka": "sick",
    "sicking": "picking",
    "sickk": "sick",
    "sicko": "sick",
    "sicks": "sucks",
    "sicky": "sick",
    "sicn": "sick",
    "sid": "said",
    "siderwiki": "sidewiki",
    "sidewicki": "sidewiki",
    "sidewike": "sidewiki",
    "sidewikik": "sidewiki",
    "sidewikki": "sidewiki",
    "sidwiki": "sidewiki",
    "sie": "side",
    "sie": "site",
    "sig": "big",
    "sigend": "signed",
    "sighn": "sign",
    "sighned": "signed",
    "signd": "sign",
    "signd": "signed",
    "signt": "sign",
    "signu": "sign",
    "siick": "sick",
    "siiting": "sitting",
    "sik": "sick",
    "sikewiki": "sidewiki",
    "sikk": "sick",
    "sil": "sis",
    "sim": "him",
    "sim": "im",
    "sim": "sis",
    "sime": "some",
    "sime": "time",
    "simiar": "similar",
    "similiar": "similar",
    "simillar": "similar",
    "simliar": "similar",
    "simm": "sim",
    "simpletweet": "simplytweet",
    "simpliest": "simplest",
    "simptom": "symptom",
    "simptoms": "symptoms",
    "simular": "similar",
    "sinc": "sync",
    "singlepayer": "isinglepayer",
    "sinple": "simple",
    "sinuse": "sinus",
    "sirus": "virus",
    "sist": "sis",
    "siter": "sister",
    "sitewiki": "sidewiki",
    "sith": "site",
    "sith": "with",
    "sitiing": "sitting",
    "sitll": "still",
    "sitn": "site",
    "sitt": "sit",
    "sittig": "sitting",
    "sittiing": "sitting",
    "sittng": "sitting",
    "sittting": "sitting",
    "siwne": "swine",
    "sixk": "sick",
    "siy": "sky",
    "sj": "so",
    "sjould": "should",
    "sk": "ask",
    "sk": "so",
    "sk": "uk",
    "skecth": "sketch",
    "skee": "see",
    "sketcuup": "sketchup",
    "skpe": "skype",
    "skpye": "skype",
    "skreen": "screen",
    "skye": "skype",
    "skyy": "sky",
    "slater": "later",
    "slayed": "played",
    "sleeep": "sleep",
    "sleepng": "sleeping",
    "slike": "like",
    "sline": "swine",
    "slite": "site",
    "sllep": "sleep",
    "slove": "love",
    "sloww": "slow",
    "slwine": "swine",
    "sm": "am",
    "sm": "fm",
    "sm": "m",
    "sm": "sim",
    "sm": "so",
    "sm": "sum",
    "smah": "smash",
    "smail": "mail",
    "smaill": "small",
    "smaking": "making",
    "smal": "small",
    "sme": "me",
    "sme": "same",
    "sme": "some",
    "smeone": "someone",
    "smewhere": "somewhere",
    "smim": "slim",
    "smine": "swine",
    "smll": "small",
    "smmer": "summer",
    "smrtphone": "smartphone",
    "sms": "mms",
    "smt": "sit",
    "sn": "an",
    "sn": "so",
    "sn": "son",
    "snd": "and",
    "snd": "send",
    "sned": "send",
    "sneding": "sending",
    "sneeezed": "sneezed",
    "sneek": "sneak",
    "snes": "nes",
    "snipper": "sniper",
    "snoy": "snow",
    "snt": "sent",
    "snta": "santa",
    "snyc": "sync",
    "snycing": "syncing",
    "soc": "doc",
    "soc": "so",
    "soc": "son",
    "socal": "social",
    "soe": "so",
    "soe": "some",
    "soem": "some",
    "soemone": "someone",
    "soemthing": "something",
    "sof": "of",
    "sofaa": "sofa",
    "sohuld": "should",
    "soild": "solid",
    "soley": "solely",
    "solor": "solar",
    "som": "so",
    "som": "sum",
    "soma": "some",
    "somach": "stomach",
    "soman": "woman",
    "sombody": "somebody",
    "somebdy": "somebody",
    "somebidy": "somebody",
    "somebudy": "somebody",
    "somehting": "something",
    "somemone": "someone",
    "somenone": "someone",
    "someoe": "someone",
    "someoen": "someone",
    "someome": "someone",
    "somer": "some",
    "somes": "comes",
    "somet": "some",
    "somethig": "something",
    "somethign": "something",
    "somethingg": "something",
    "somethinng": "something",
    "somethinq": "something",
    "somethng": "something",
    "someting": "something",
    "somm": "some",
    "somngs": "songs",
    "somoa": "samoa",
    "somoan": "samoan",
    "somone": "someone",
    "soms": "some",
    "somthing": "something",
    "sonce": "since",
    "sonds": "sounds",
    "sone": "one",
    "sone": "some",
    "soneone": "someone",
    "songz": "song",
    "songz": "songs",
    "soninc": "sonic",
    "sonn": "son",
    "sonn": "soon",
    "sont": "dont",
    "sony": "son",
    "soo": "so",
    "soo": "too",
    "soom": "soon",
    "soome": "some",
    "sooo": "soon",
    "soood": "sooo",
    "soooi": "sooo",
    "sooon": "soon",
    "sooool": "soooo",
    "soore": "sore",
    "soory": "sorry",
    "soprry": "sorry",
    "sor": "for",
    "sorce": "sore",
    "sorta": "sort",
    "sory": "sorry",
    "sory": "sort",
    "sotre": "store",
    "souch": "such",
    "souind": "sound",
    "sould": "should",
    "sould": "sold",
    "sould": "would",
    "soundz": "sounds",
    "sountrack": "soundtrack",
    "sounz": "sound",
    "soupy": "soup",
    "sourced": "sources",
    "sourh": "south",
    "sownloaded": "downloaded",
    "sox": "box",
    "soz": "so",
    "sp": "so",
    "sp": "up",
    "spaish": "spanish",
    "spart": "part",
    "speach": "speech",
    "speack": "speak",
    "spead": "spread",
    "speading": "spreading",
    "speaka": "speak",
    "speakk": "speak",
    "spech": "speech",
    "speek": "speak",
    "speel": "spell",
    "speen": "speed",
    "speical": "special",
    "spftware": "software",
    "spirts": "sports",
    "spmething": "something",
    "spoarts": "sports",
    "sponsered": "sponsored",
    "spoorts": "sports",
    "sporify": "spotify",
    "sporst": "sports",
    "sporta": "sports",
    "sportss": "sports",
    "sportys": "sports",
    "sportz": "sports",
    "spose": "spoke",
    "spp": "app",
    "sppose": "suppose",
    "spprts": "sports",
    "spps": "apps",
    "spreadint": "spreading",
    "spreadn": "spread",
    "spreaing": "spreading",
    "spred": "spread",
    "spreeding": "spreading",
    "sprot": "sport",
    "sprots": "sports",
    "sqaure": "square",
    "sqine": "swine",
    "squard": "squared",
    "sr": "or",
    "sranding": "standing",
    "sreading": "spreading",
    "sreads": "spreads",
    "sreen": "screen",
    "sreet": "street",
    "srory": "story",
    "srry": "sorry",
    "srt": "sort",
    "srtikes": "strikes",
    "srts": "sorts",
    "sruck": "struck",
    "sry": "say",
    "sry": "try",
    "ss": "as",
    "ss": "ass",
    "ss": "is",
    "ss": "so",
    "ss": "us",
    "ssearch": "search",
    "ssee": "see",
    "ssend": "send",
    "ssid": "said",
    "ssme": "same",
    "ssn": "son",
    "sso": "seo",
    "sson": "soon",
    "ssooo": "sooo",
    "ssounds": "sounds",
    "sstar": "star",
    "sstill": "still",
    "sstupid": "stupid",
    "sswine": "swine",
    "st": "at",
    "st": "it",
    "st": "sat",
    "st": "set",
    "st": "sit",
    "staart": "start",
    "stady": "stay",
    "staet": "start",
    "standardz": "standards",
    "starb": "start",
    "starbukcs": "starbucks",
    "starr": "star",
    "startbucks": "starbucks",
    "startd": "start",
    "startd": "started",
    "starthing": "starting",
    "startign": "starting",
    "startinq": "starting",
    "startn": "start",
    "startng": "starting",
    "startt": "start",
    "starz": "start",
    "stat": "start",
    "stat": "stay",
    "statbucks": "starbucks",
    "stats": "starts",
    "stats": "state",
    "stats": "status",
    "statt": "stats",
    "staty": "stay",
    "staus": "status",
    "stayd": "stay",
    "stayn": "stay",
    "stck": "stick",
    "stcks": "sticks",
    "stdents": "students",
    "stdney": "sydney",
    "ste": "see",
    "steet": "street",
    "steets": "streets",
    "steetview": "streetview",
    "stell": "tell",
    "steph": "step",
    "sthere": "there",
    "sthing": "thing",
    "stiil": "still",
    "stiill": "still",
    "stikes": "strikes",
    "stil": "still",
    "stilk": "still",
    "stilll": "still",
    "stils": "still",
    "stime": "time",
    "stine": "swine",
    "stipidest": "stupidest",
    "stirkes": "strikes",
    "stl": "stil",
    "stll": "still",
    "stlupid": "stupid",
    "stngs": "songs",
    "sto": "to",
    "stoach": "stomach",
    "stoled": "stole",
    "stomace": "stomach",
    "stomack": "stomach",
    "stomah": "stomach",
    "stomch": "stomach",
    "stomich": "stomach",
    "stommach": "stomach",
    "stomuch": "stomach",
    "stong": "strong",
    "stoped": "stopped",
    "stopp": "stop",
    "stopre": "store",
    "stor": "star",
    "storn": "storm",
    "storng": "strong",
    "stoumach": "stomach",
    "stp": "stop",
    "stps": "steps",
    "str": "star",
    "straght": "straight",
    "stran": "strain",
    "strang": "strand",
    "strans": "strand",
    "straon": "strain",
    "stread": "spread",
    "streading": "spreading",
    "streap": "strep",
    "streeet": "street",
    "streek": "street",
    "streetsview": "streetview",
    "streetveiw": "streetview",
    "streeview": "streetview",
    "strepp": "strep",
    "strept": "strep",
    "stret": "street",
    "stretet": "street",
    "stright": "straight",
    "strng": "strong",
    "strom": "storm",
    "strore": "store",
    "strret": "street",
    "strt": "start",
    "strucks": "struck",
    "strugging": "struggling",
    "struggleing": "struggling",
    "strugling": "struggling",
    "sttill": "still",
    "sttlement": "settlement",
    "stuch": "stuck",
    "studends": "students",
    "studing": "studying",
    "studioi": "studio",
    "studyy": "study",
    "stuf": "stuff",
    "stuggling": "struggling",
    "stuk": "stuck",
    "stull": "still",
    "stumach": "stomach",
    "stuped": "stupid",
    "stupud": "stupid",
    "stuuf": "stuff",
    "stya": "stay",
    "styll": "still",
    "su": "so",
    "su": "us",
    "subcribe": "subscribe",
    "subsidesu": "subsides",
    "succeptible": "susceptible",
    "succes": "success",
    "succesful": "successful",
    "succombed": "succumbed",
    "succumed": "succumbed",
    "suceptible": "susceptible",
    "sucha": "such",
    "suchh": "such",
    "sucidegirls": "suicidegirls",
    "suckas": "sucks",
    "sucksd": "sucks",
    "suckss": "sucks",
    "sucky": "lucky",
    "sucky": "sucks",
    "suckz": "sucks",
    "suddon": "sudden",
    "suden": "sudden",
    "sudents": "students",
    "sudgest": "suggest",
    "suea": "sues",
    "sufering": "suffering",
    "sufferng": "suffering",
    "suffle": "shuffle",
    "sufing": "surfing",
    "sugah": "sugar",
    "sugest": "suggest",
    "suggestiong": "suggestions",
    "suggst": "suggest",
    "sui": "sun",
    "suiciidegirls": "suicidegirls",
    "suine": "swine",
    "suk": "suck",
    "suks": "sucks",
    "sumantra": "sumatra",
    "sumatera": "sumatra",
    "sumatrai": "sumatra",
    "sumatran": "sumatra",
    "sumbitted": "submitted",
    "sumer": "summer",
    "sumoa": "samoa",
    "sumptoms": "symptoms",
    "sumtra": "sumatra",
    "sunami": "tsunami",
    "sunch": "lunch",
    "sundtrack": "soundtrack",
    "sunmitted": "submitted",
    "suoppose": "suppose",
    "suped": "super",
    "supergluded": "superglued",
    "supid": "stupid",
    "supose": "suppose",
    "suposed": "supposed",
    "suppoed": "supposed",
    "supportn": "support",
    "supporty": "support",
    "supposd": "supposed",
    "suppossed": "supposed",
    "suppost": "suppose",
    "suppot": "support",
    "suppposed": "supposed",
    "suppsed": "supposed",
    "supr": "super",
    "suprise": "surprise",
    "suprised": "surprised",
    "suprising": "surprising",
    "supsended": "suspended",
    "suqks": "sucks",
    "sur": "our",
    "surffering": "suffering",
    "suring": "surfing",
    "surpirsed": "surprised",
    "surpised": "surprised",
    "surpose": "suppose",
    "surposed": "supposed",
    "surprisef": "surprised",
    "survice": "service",
    "survied": "survived",
    "survivd": "survived",
    "survuved": "survived",
    "sus": "bus",
    "susbcribe": "subscribe",
    "suscribe": "subscribe",
    "susected": "suspected",
    "suseptible": "susceptible",
    "sute": "sure",
    "suz": "cuz",
    "sva": "sa",
    "sved": "saved",
    "svine": "swine",
    "svn": "sun",
    "sw": "saw",
    "sw": "so",
    "swagga": "swagg",
    "swaggg": "swagg",
    "swaine": "swine",
    "swang": "swag",
    "swar": "swear",
    "swein": "swin",
    "sweine": "swine",
    "swet": "sweet",
    "swgg": "swag",
    "swhine": "swine",
    "swian": "swin",
    "swibe": "swine",
    "swich": "switch",
    "swiched": "switched",
    "swicthed": "switched",
    "swicthing": "switching",
    "swie": "swine",
    "swien": "swine",
    "swiene": "swine",
    "swife": "swine",
    "swiine": "swine",
    "swike": "swine",
    "swime": "swine",
    "swin": "win",
    "swina": "swine",
    "swinbe": "swine",
    "swince": "swine",
    "swind": "swine",
    "swinde": "swine",
    "swiner": "swine",
    "swiney": "swine",
    "swinf": "swine",
    "swinfe": "swine",
    "swinie": "swine",
    "swinle": "swine",
    "swinn": "swine",
    "swinne": "swine",
    "swinr": "swine",
    "swint": "swine",
    "swinw": "swine",
    "swinwe": "swine",
    "swiny": "swine",
    "switchn": "switch",
    "swith": "switch",
    "swithed": "switched",
    "swithing": "switching",
    "switter": "twitter",
    "switvched": "switched",
    "swkine": "swine",
    "swn": "own",
    "swne": "swine",
    "swnine": "swine",
    "swone": "swine",
    "swop": "swap",
    "swotch": "switch",
    "swqne": "swine",
    "swtch": "switch",
    "swtich": "switch",
    "swtiched": "switched",
    "swune": "swine",
    "swwine": "swine",
    "swyne": "swine",
    "sx": "six",
    "sx": "so",
    "sx": "x",
    "sy": "by",
    "sy": "my",
    "sy": "say",
    "sycks": "sucks",
    "sycning": "syncing",
    "sympoms": "symptoms",
    "sympotoms": "symptoms",
    "sympthoms": "symptoms",
    "symptomms": "symptoms",
    "symptomns": "symptoms",
    "symptomss": "symptoms",
    "symptomsu": "symptoms",
    "symptomz": "symptoms",
    "sympton": "symptom",
    "symptonms": "symptoms",
    "symptons": "symptoms",
    "sympyoms": "symptoms",
    "symtom": "symptom",
    "symtoms": "symptoms",
    "symtpoms": "symptoms",
    "symttoms": "symptoms",
    "syncd": "sync",
    "syncd": "syncs",
    "synce": "sync",
    "synces": "syncs",
    "synch": "sync",
    "synch": "syncs",
    "synching": "syncing",
    "synchs": "syncs",
    "synd": "send",
    "synicing": "syncing",
    "syns": "sync",
    "sypmtoms": "symptoms",
    "syptom": "symptom",
    "syptoms": "symptoms",
    "sys": "says",
    "sysmptom": "symptom",
    "sysmptoms": "symptoms",
    "systen": "system",
    "systm": "system",
    "sysytem": "system",
    "sytem": "system",
    "taalked": "talked",
    "tabblet": "tablet",
    "tae": "the",
    "taht": "that",
    "tahu": "tau",
    "taike": "take",
    "tajes": "takes",
    "tak": "talk",
    "takd": "take",
    "taked": "naked",
    "takie": "take",
    "takig": "taking",
    "takiing": "taking",
    "takin": "taken",
    "takinng": "taking",
    "takinq": "taking",
    "takking": "talking",
    "takling": "talking",
    "takn": "take",
    "takn": "taken",
    "takng": "taking",
    "takoing": "taking",
    "taliking": "talking",
    "taling": "talking",
    "talkd": "talk",
    "talkg": "talk",
    "talkign": "talking",
    "talkiing": "talking",
    "talkimg": "talking",
    "talkingg": "talking",
    "talkinq": "talking",
    "talkk": "talk",
    "talkn": "talk",
    "tallk": "talk",
    "tallking": "talking",
    "tams": "dams",
    "tanked": "ranked",
    "tanking": "taking",
    "tapi": "api",
    "tase": "case",
    "tatsunoku": "tatsunoko",
    "taunami": "tsunami",
    "tawking": "taking",
    "tay": "pay",
    "tb": "mb",
    "tb": "to",
    "tbat": "that",
    "tbe": "be",
    "tbe": "the",
    "tc": "htc",
    "tc": "to",
    "tc": "tv",
    "tcc": "fcc",
    "td": "id",
    "td": "to",
    "td": "tv",
    "tday": "today",
    "tdm": "dm",
    "tdoing": "doing",
    "te": "he",
    "te": "me",
    "te": "the",
    "te": "to",
    "teaccher": "teacher",
    "teacherr": "teacher",
    "teachr": "teacher",
    "teady": "ready",
    "teaffic": "traffic",
    "teamates": "teammates",
    "teamd": "teams",
    "teather": "tether",
    "teather": "weather",
    "teathering": "tethering",
    "teck": "tech",
    "tecnology": "technology",
    "teecher": "teacher",
    "teeetdeck": "tweetdeck",
    "teel": "tell",
    "teen": "been",
    "teen": "then",
    "teengae": "teenage",
    "teetdeck": "tweetdeck",
    "teether": "tether",
    "teeting": "tweeting",
    "teh": "the",
    "tehe": "the",
    "tehn": "then",
    "teitter": "twitter",
    "tek": "ten",
    "tekus": "telus",
    "tel": "tell",
    "telcom": "telecom",
    "tellimg": "telling",
    "telll": "tell",
    "telll": "tells",
    "telln": "tell",
    "telln": "tells",
    "tellus": "telus",
    "tels": "tell",
    "tem": "team",
    "tem": "ten",
    "teme": "theme",
    "temtped": "tempted",
    "tenis": "tennis",
    "tere": "there",
    "terible": "terrible",
    "teriible": "terrible",
    "terthering": "tethering",
    "tese": "these",
    "tesing": "testing",
    "testign": "testing",
    "testingy": "testing",
    "testsed": "tested",
    "testung": "testing",
    "tesy": "test",
    "tet": "test",
    "teuls": "telus",
    "teweet": "tweet",
    "tewplates": "templates",
    "texing": "texting",
    "texted": "tested",
    "texting": "testing",
    "teying": "trying",
    "tf": "if",
    "tfe": "the",
    "tfo": "to",
    "tg": "to",
    "tgat": "that",
    "tge": "the",
    "tghe": "the",
    "tghinking": "thinking",
    "tgink": "think",
    "tgis": "this",
    "tgv": "tv",
    "th": "to",
    "th": "tv",
    "tha": "the",
    "thaa": "that",
    "thaanks": "thanks",
    "thaat": "that",
    "thab": "than",
    "thad": "that",
    "thae": "than",
    "thae": "the",
    "thai": "that",
    "thaink": "think",
    "thaknk": "thank",
    "thaks": "thanks",
    "thana": "than",
    "thang": "than",
    "thang": "thing",
    "thangs": "things",
    "thankd": "thanks",
    "thankgs": "thanks",
    "thankk": "thank",
    "thankss": "thanks",
    "thanku": "thanks",
    "thankx": "thanks",
    "thanky": "thank",
    "thankz": "thanks",
    "thanl": "thank",
    "thann": "than",
    "thanq": "than",
    "thans": "thanks",
    "thansk": "thanks",
    "thanx": "than",
    "thanx": "thank",
    "thanxs": "thanks",
    "thaqt": "that",
    "thar": "that",
    "thara": "thera",
    "thare": "there",
    "thas": "has",
    "thas": "that",
    "thas": "thats",
    "thass": "thats",
    "thast": "that",
    "thatd": "that",
    "thati": "that",
    "thatl": "that",
    "thatn": "that",
    "thatnks": "thanks",
    "thats": "whats",
    "thatsz": "thats",
    "thatt": "that",
    "thatv": "that",
    "thaty": "that",
    "thatz": "that",
    "thatz": "thats",
    "thaught": "thought",
    "thave": "have",
    "thax": "thx",
    "thay": "that",
    "thay": "they",
    "thaz": "that",
    "thc": "the",
    "thd": "the",
    "thea": "the",
    "theat": "that",
    "theb": "the",
    "theb": "then",
    "thed": "the",
    "theee": "these",
    "theee": "three",
    "theere": "there",
    "theey": "they",
    "thei": "the",
    "theit": "their",
    "thel": "the",
    "themez": "themes",
    "themm": "them",
    "thems": "themes",
    "theng": "then",
    "theni": "then",
    "thenk": "thank",
    "thenks": "thanks",
    "thenn": "then",
    "theo": "the",
    "theose": "those",
    "ther": "the",
    "ther": "them",
    "ther": "then",
    "ther": "they",
    "thera": "there",
    "theral": "thera",
    "therei": "there",
    "therer": "there",
    "therez": "there",
    "therma": "thera",
    "thero": "thera",
    "theroy": "theory",
    "thers": "thera",
    "thers": "there",
    "thers": "theres",
    "theru": "thera",
    "theru": "there",
    "therw": "there",
    "therwise": "otherwise",
    "thery": "theory",
    "therz": "there",
    "thes": "them",
    "thes": "they",
    "thesee": "these",
    "thess": "these",
    "thet": "that",
    "thet": "the",
    "thet": "they",
    "thether": "tether",
    "thethering": "tethering",
    "thetre": "there",
    "theu": "the",
    "theu": "they",
    "thewre": "there",
    "theyd": "they",
    "theyr": "their",
    "theyr": "they",
    "theyre": "there",
    "theyt": "they",
    "theze": "these",
    "thf": "the",
    "thg": "the",
    "thge": "the",
    "thgt": "that",
    "thh": "the",
    "thhank": "thank",
    "thhat": "that",
    "thhe": "the",
    "thhink": "think",
    "thhs": "this",
    "thi": "the",
    "thia": "this",
    "thibg": "thing",
    "thibk": "think",
    "thid": "this",
    "thie": "the",
    "thie": "this",
    "thier": "their",
    "thig": "this",
    "thign": "thing",
    "thigns": "things",
    "thigs": "things",
    "thihg": "thing",
    "thii": "this",
    "thiings": "things",
    "thiink": "think",
    "thiinking": "thinking",
    "thiis": "this",
    "thik": "think",
    "thiking": "thinking",
    "thikn": "think",
    "thikngs": "things",
    "thimk": "think",
    "thinbk": "think",
    "thinck": "think",
    "thingd": "things",
    "thingg": "thing",
    "thingi": "thing",
    "thinging": "thinking",
    "thingo": "thing",
    "thingy": "thing",
    "thingy": "things",
    "thingz": "things",
    "thining": "thinking",
    "thinka": "think",
    "thinka": "thinks",
    "thinkg": "thing",
    "thinkg": "think",
    "thinki": "think",
    "thinkingg": "thinking",
    "thinkinn": "thinking",
    "thinkinq": "thinking",
    "thinkk": "think",
    "thinkking": "thinking",
    "thinkn": "think",
    "thinkn": "thinkin",
    "thinkng": "thinking",
    "thinkong": "thinking",
    "thinkr": "think",
    "thinkss": "thinks",
    "thinkz": "think",
    "thinl": "think",
    "thinng": "thing",
    "thinos": "things",
    "thinq": "thing",
    "thinq": "think",
    "thir": "their",
    "thisb": "this",
    "thise": "those",
    "thisnk": "think",
    "thiss": "this",
    "thisx": "this",
    "thiught": "thought",
    "thiw": "this",
    "thiz": "this",
    "thje": "the",
    "thjis": "this",
    "thks": "this",
    "thl": "the",
    "thl": "thx",
    "thm": "the",
    "thn": "than",
    "thn": "the",
    "thn": "then",
    "thnaks": "thanks",
    "thng": "thing",
    "thngs": "things",
    "thnik": "think",
    "thnk": "thank",
    "thnk": "think",
    "thnkin": "thinkin",
    "thnking": "thinking",
    "thnks": "thanks",
    "thnks": "thinks",
    "tho": "the",
    "tho": "to",
    "tho": "too",
    "tho": "tro",
    "tho": "who",
    "thoat": "that",
    "thoat": "throat",
    "thoe": "the",
    "thoery": "theory",
    "thoes": "those",
    "thoese": "those",
    "thoght": "thought",
    "thoguht": "thought",
    "thois": "this",
    "thoiught": "thought",
    "thom": "them",
    "thonk": "think",
    "thoose": "those",
    "thoroat": "throat",
    "thos": "this",
    "thoseb": "those",
    "thoses": "those",
    "thot": "that",
    "thoughht": "thought",
    "thoughti": "thought",
    "thougt": "thought",
    "thougth": "thought",
    "thougths": "thoughts",
    "thougts": "thoughts",
    "thouhgt": "thought",
    "thouht": "thought",
    "thouigh": "though",
    "thounsands": "thousands",
    "thouqht": "thought",
    "thourht": "thought",
    "thousadns": "thousands",
    "thouse": "those",
    "thow": "show",
    "thqat": "that",
    "thr": "the",
    "thre": "the",
    "thre": "there",
    "threa": "thera",
    "thrm": "them",
    "thro": "thru",
    "throad": "throat",
    "throatd": "throat",
    "throath": "throat",
    "throught": "thought",
    "throught": "through",
    "throut": "throat",
    "throuth": "through",
    "thrs": "this",
    "ths": "the",
    "ths": "this",
    "thse": "the",
    "thsi": "this",
    "thsoe": "those",
    "tht": "that",
    "tht": "the",
    "thta": "that",
    "thts": "thats",
    "thts": "this",
    "thu": "the",
    "thught": "thought",
    "thunk": "think",
    "thunking": "thinking",
    "thur": "thru",
    "thura": "thera",
    "thw": "the",
    "thwe": "the",
    "thwy": "they",
    "thx": "the",
    "thxs": "this",
    "thye": "the",
    "thying": "trying",
    "thyng": "thing",
    "thynk": "think",
    "thys": "this",
    "thz": "the",
    "tiday": "today",
    "tiem": "time",
    "tierd": "tired",
    "tiggered": "triggered",
    "tihng": "thing",
    "tihnk": "think",
    "tii": "wii",
    "tiime": "time",
    "tike": "time",
    "til": "stil",
    "tild": "told",
    "tim": "him",
    "tim": "im",
    "timf": "time",
    "timie": "time",
    "timme": "time",
    "tink": "link",
    "tink": "think",
    "tinsy": "tiny",
    "tio": "to",
    "tipe": "type",
    "tipps": "tips",
    "tipz": "tips",
    "tis": "his",
    "tis": "is",
    "tis": "its",
    "tis": "this",
    "tite": "time",
    "tither": "either",
    "tither": "tether",
    "titterific": "twitterific",
    "tiwtter": "twitter",
    "tj": "to",
    "tjat": "that",
    "tje": "the",
    "tjink": "think",
    "tjis": "this",
    "tk": "to",
    "tk": "tv",
    "tkae": "take",
    "tke": "take",
    "tkes": "takes",
    "tko": "to",
    "tkx": "thx",
    "tl": "to",
    "tlak": "talk",
    "tld": "told",
    "tlels": "tells",
    "tlist": "list",
    "tlk": "talk",
    "tlked": "talked",
    "tlkin": "talkin",
    "tlking": "talking",
    "tm": "to",
    "tm": "tv",
    "tme": "the",
    "tme": "time",
    "tmo": "to",
    "tmo": "too",
    "tmobile": "mobile",
    "tmorrow": "tomorrow",
    "tn": "in",
    "tn": "on",
    "tn": "to",
    "tne": "the",
    "tnink": "think",
    "tnot": "not",
    "toaday": "today",
    "toally": "totally",
    "tob": "to",
    "toc": "to",
    "toc": "top",
    "todaay": "today",
    "todat": "today",
    "todayy": "today",
    "todd": "told",
    "todday": "today",
    "todl": "told",
    "todo": "too",
    "todsay": "today",
    "todya": "today",
    "tog": "to",
    "toh": "to",
    "toh": "top",
    "tok": "to",
    "toke": "take",
    "toko": "too",
    "tol": "to",
    "toldd": "told",
    "toled": "told",
    "tols": "told",
    "tomarrow": "tomorrow",
    "tomerrow": "tomorrow",
    "tommorrow": "tomorrow",
    "tomoorow": "tomorrow",
    "tomorow": "tomorrow",
    "tomorroww": "tomorrow",
    "tomorrrow": "tomorrow",
    "tomorrwo": "tomorrow",
    "tomrorow": "tomorrow",
    "tonz": "tons",
    "toobar": "toolbar",
    "tooblar": "toolbar",
    "tooday": "today",
    "tooh": "too",
    "tooke": "took",
    "tookit": "toolkit",
    "tooks": "looks",
    "tooks": "took",
    "toolabr": "toolbar",
    "toon": "ton",
    "toon": "too",
    "tooo": "too",
    "toook": "took",
    "toooo": "soooo",
    "topicsi": "topics",
    "topo": "top",
    "topoic": "topic",
    "torm": "form",
    "tory": "story",
    "tos": "os",
    "tos": "top",
    "tosay": "today",
    "totallyy": "totally",
    "totaly": "totally",
    "toto": "too",
    "tottally": "totally",
    "tou": "ton",
    "tou": "you",
    "toube": "tube",
    "touble": "trouble",
    "tought": "thought",
    "toughts": "thoughts",
    "touh": "tour",
    "touvh": "touch",
    "toworrow": "tomorrow",
    "toying": "trying",
    "toyko": "tokyo",
    "toyus": "toys",
    "tp": "to",
    "tp": "top",
    "tp": "up",
    "tpld": "told",
    "tq": "to",
    "tq": "tv",
    "tqake": "take",
    "tr": "to",
    "tra": "try",
    "traanslator": "translator",
    "trabsfer": "transfer",
    "trackera": "tracker",
    "trafific": "traffic",
    "trailor": "trailer",
    "trak": "track",
    "tranding": "trending",
    "trandsmap": "trendsmap",
    "tranfer": "transfer",
    "tranform": "transform",
    "tranlate": "translate",
    "tranlator": "translator",
    "transalte": "translate",
    "transelate": "translate",
    "transer": "transfer",
    "transfor": "transfer",
    "translage": "translate",
    "translete": "translate",
    "transmiter": "transmitter",
    "traslate": "translate",
    "tratment": "treatment",
    "travl": "travel",
    "traying": "trying",
    "tre": "are",
    "tre": "the",
    "treament": "treatment",
    "treatmernt": "treatment",
    "treatn": "treat",
    "treding": "trending",
    "tredning": "trending",
    "tremours": "tremors",
    "trendig": "trending",
    "trendign": "trending",
    "trendind": "trending",
    "trendinq": "trending",
    "trenging": "trending",
    "trening": "trending",
    "treo": "trey",
    "trey": "they",
    "trey": "try",
    "trhe": "the",
    "trhew": "threw",
    "trhough": "through",
    "trhying": "trying",
    "tride": "tried",
    "tring": "trying",
    "tris": "this",
    "triying": "trying",
    "trnaslate": "translate",
    "troat": "throat",
    "troble": "trouble",
    "troubel": "trouble",
    "trought": "thought",
    "trrrible": "terrible",
    "trthering": "tethering",
    "tru": "thru",
    "tru": "try",
    "trued": "tried",
    "truning": "turning",
    "truns": "runs",
    "tryd": "try",
    "tryed": "tried",
    "tryen": "tryin",
    "tryign": "trying",
    "tryijng": "trying",
    "tryina": "trying",
    "tryina": "tryna",
    "tryingg": "trying",
    "tryinh": "trying",
    "tryinng": "trying",
    "tryinq": "trying",
    "tryint": "trying",
    "tryke": "trike",
    "tryn": "try",
    "tryng": "trying",
    "trynin": "tryin",
    "trynna": "tryna",
    "tryying": "trying",
    "ts": "is",
    "ts": "its",
    "ts": "to",
    "ts": "us",
    "tsken": "taken",
    "tsnami": "tsunami",
    "tsnunami": "tsunami",
    "tsuami": "tsunami",
    "tsuanami": "tsunami",
    "tsuanmi": "tsunami",
    "tsumami": "tsunami",
    "tsuname": "tsunami",
    "tsunmai": "tsunami",
    "tsunomi": "tsunami",
    "tt": "at",
    "tt": "it",
    "tt": "to",
    "ttc": "htc",
    "tthe": "the",
    "tthere": "there",
    "tthink": "think",
    "tthis": "this",
    "ttied": "tried",
    "ttime": "time",
    "tto": "to",
    "ttried": "tried",
    "ttrying": "trying",
    "tts": "its",
    "ttweet": "tweet",
    "tty": "try",
    "tu": "su",
    "tu": "to",
    "tu": "u",
    "tue": "the",
    "tuen": "turn",
    "tunami": "tsunami",
    "tunned": "tuned",
    "tunr": "turn",
    "tupe": "type",
    "tuped": "typed",
    "turm": "turn",
    "turnd": "turns",
    "turs": "turns",
    "tusnami": "tsunami",
    "tutning": "turning",
    "tuturial": "tutorial",
    "tv": "av",
    "tv": "iv",
    "tv": "to",
    "tvc": "tv",
    "tvm": "tv",
    "tvu": "tv",
    "tw": "tv",
    "twan": "than",
    "twas": "was",
    "twatter": "twitter",
    "twattering": "twittering",
    "twatting": "twitting",
    "twave": "wave",
    "tweat": "tweet",
    "tweating": "tweeting",
    "tweats": "tweets",
    "tweeddeck": "tweetdeck",
    "tweedeck": "tweetdeck",
    "tweeet": "tweet",
    "tweeeting": "tweeting",
    "tweeing": "tweeting",
    "tweeite": "tweetie",
    "tweekdeck": "tweetdeck",
    "tweeks": "tweets",
    "tweeks": "weeks",
    "tween": "tweet",
    "tweens": "tweets",
    "tweeps": "tweets",
    "tweetd": "tweet",
    "tweetd": "tweeted",
    "tweetddeck": "tweetdeck",
    "tweetdecl": "tweetdeck",
    "tweetdeek": "tweetdeck",
    "tweetdesk": "tweetdeck",
    "tweetdexk": "tweetdeck",
    "tweete": "tweetie",
    "tweeteck": "tweetdeck",
    "tweething": "tweeting",
    "tweeti": "tweet",
    "tweetibng": "tweeting",
    "tweetimg": "tweeting",
    "tweetin": "tweetie",
    "tweetinfg": "tweeting",
    "tweetme": "tweetie",
    "tweetmeant": "tweetment",
    "tweetn": "tweet",
    "tweetong": "tweeting",
    "tweettdeck": "tweetdeck",
    "tweetue": "tweetie",
    "tweetung": "tweeting",
    "tweety": "tweet",
    "tweety": "tweets",
    "tweew": "tweet",
    "twet": "tweet",
    "twetdeck": "tweetdeck",
    "tweting": "tweeting",
    "twett": "tweet",
    "twetterific": "twitterific",
    "twettie": "tweetie",
    "twetting": "tweeting",
    "twetty": "tweety",
    "twhen": "when",
    "twi": "two",
    "twii": "wii",
    "twiiter": "twitter",
    "twiitter": "twitter",
    "twitboy": "twitbot",
    "twitear": "twittear",
    "twiter": "twitter",
    "twiterific": "twitterific",
    "twitering": "twittering",
    "twittar": "twitter",
    "twittear": "twitter",
    "twittendo": "twitteando",
    "twitteo": "twitter",
    "twitterando": "twitteando",
    "twitterfic": "twitterific",
    "twitteri": "twitter",
    "twitterifuc": "twitterific",
    "twitteriic": "twitterific",
    "twitteriric": "twitterific",
    "twittern": "twitter",
    "twitterr": "twitter",
    "twitterrffic": "twitterrific",
    "twitterriffic": "twitterrific",
    "twittert": "twitter",
    "twitterz": "twitter",
    "twittet": "twitter",
    "twittr": "twitter",
    "twittre": "twitter",
    "twittter": "twitter",
    "twottering": "twittering",
    "twought": "thought",
    "twoughts": "thoughts",
    "twrtter": "twitter",
    "twtter": "twitter",
    "twwet": "tweet",
    "twwets": "tweets",
    "twwitter": "twitter",
    "tx": "to",
    "tx": "x",
    "txt": "text",
    "txts": "texts",
    "ty": "my",
    "ty": "to",
    "ty": "toy",
    "tyelenol": "tylenol",
    "tyenol": "tylenol",
    "tyeped": "typed",
    "tyhe": "the",
    "tyhphoon": "typhoon",
    "tyll": "till",
    "tylonol": "tylenol",
    "tyme": "time",
    "tyo": "to",
    "tyoe": "type",
    "tyou": "you",
    "typ": "top",
    "typd": "typed",
    "typer": "type",
    "typingg": "typing",
    "typo": "type",
    "typoon": "typhoon",
    "typr": "type",
    "tyr": "try",
    "tyring": "trying",
    "tyype": "type",
    "tzeet": "tweet",
    "ua": "a",
    "ua": "ui",
    "ua": "uk",
    "uae": "use",
    "ub": "u",
    "ub": "ui",
    "ub": "uk",
    "ub": "us",
    "ubar": "bar",
    "uber": "user",
    "ublic": "public",
    "uc": "u",
    "uc": "uk",
    "uc": "up",
    "uc": "us",
    "ucan": "can",
    "ud": "u",
    "ud": "up",
    "uda": "da",
    "udate": "update",
    "udated": "updated",
    "udating": "updating",
    "ude": "use",
    "udge": "judge",
    "udpate": "update",
    "ue": "us",
    "ue": "use",
    "uers": "users",
    "ues": "use",
    "uf": "of",
    "uf": "u",
    "uf": "uk",
    "ug": "u",
    "ug": "ui",
    "ug": "us",
    "uget": "get",
    "ugg": "ugh",
    "uggh": "ugh",
    "ugot": "got",
    "ugrade": "upgrade",
    "ugraded": "upgraded",
    "uh": "u",
    "uh": "ugh",
    "uh": "uk",
    "uh": "up",
    "uh": "ur",
    "uh": "us",
    "uhat": "that",
    "uhave": "have",
    "uhg": "ugh",
    "uhh": "ugh",
    "ui": "i",
    "ui": "u",
    "ui": "uk",
    "ui": "up",
    "ui": "ur",
    "ui": "us",
    "ui": "ux",
    "uid": "did",
    "uid": "id",
    "uing": "using",
    "uis": "is",
    "uk": "u",
    "uk": "ui",
    "uk": "up",
    "uk": "ur",
    "uk": "us",
    "uke": "use",
    "uknow": "know",
    "uks": "us",
    "ul": "u",
    "ul": "ur",
    "ul": "us",
    "ulimatum": "ultimatum",
    "ulitimate": "ultimate",
    "ull": "all",
    "ull": "full",
    "ull": "pull",
    "ulocked": "unlocked",
    "ulrimate": "ultimate",
    "ultmate": "ultimate",
    "ulu": "flu",
    "um": "am",
    "um": "im",
    "um": "u",
    "um": "uk",
    "um": "up",
    "um": "ur",
    "um": "us",
    "uma": "ima",
    "umac": "mac",
    "umma": "imma",
    "un": "an",
    "un": "fun",
    "un": "in",
    "un": "on",
    "un": "run",
    "un": "sun",
    "un": "u",
    "un": "uk",
    "un": "up",
    "un": "us",
    "uname": "name",
    "unblock": "unlock",
    "unclock": "unlock",
    "und": "and",
    "undaer": "under",
    "underdstand": "understand",
    "undersrand": "understand",
    "understnad": "understand",
    "understnd": "understand",
    "undertand": "understand",
    "undertsand": "understand",
    "undestand": "understand",
    "undewr": "under",
    "une": "use",
    "ungle": "tungle",
    "uni": "ui",
    "unlcoked": "unlocked",
    "unleased": "unleashed",
    "unleashng": "unleashing",
    "unloack": "unlock",
    "unlocced": "unlocked",
    "unloced": "unlocked",
    "unlockd": "unlock",
    "unlockd": "unlocked",
    "unlockedb": "unlocked",
    "unlok": "unlock",
    "unloked": "unlocked",
    "unlook": "unlock",
    "unluck": "unlock",
    "unno": "dunno",
    "uno": "no",
    "unock": "unlock",
    "unocked": "unlocked",
    "unpdates": "updates",
    "unred": "unread",
    "unstead": "instead",
    "untill": "until",
    "unvelied": "unveiled",
    "unvieled": "unveiled",
    "unvitation": "invitation",
    "unvite": "invite",
    "uo": "to",
    "uou": "you",
    "upadate": "update",
    "upadating": "updating",
    "upadte": "update",
    "upc": "pc",
    "upc": "up",
    "upc": "ups",
    "updataing": "updating",
    "updatd": "updated",
    "updatde": "update",
    "updatedd": "updated",
    "updater": "update",
    "updaters": "updates",
    "updatewd": "updated",
    "updatig": "updating",
    "updatinn": "updating",
    "updatinq": "updating",
    "updatn": "update",
    "updatred": "updated",
    "updatung": "updating",
    "updatwe": "update",
    "updaye": "update",
    "updgrade": "upgrade",
    "updload": "upload",
    "updte": "update",
    "upfates": "updates",
    "upg": "up",
    "upgade": "upgrade",
    "upgaded": "upgraded",
    "upgarde": "upgrade",
    "upgarding": "upgrading",
    "upgraged": "upgraded",
    "upgrated": "upgraded",
    "upgrde": "upgrade",
    "upgrded": "upgraded",
    "upgreded": "upgraded",
    "uphone": "iphone",
    "uping": "using",
    "uplaying": "playing",
    "uplead": "upload",
    "uploed": "upload",
    "upo": "up",
    "upoad": "upload",
    "upoaded": "uploaded",
    "upolad": "upload",
    "upp": "up",
    "upposed": "supposed",
    "uptate": "update",
    "uptated": "updated",
    "upy": "up",
    "uq": "up",
    "ur": "ar",
    "ur": "er",
    "ur": "or",
    "ur": "our",
    "ur": "pr",
    "ur": "u",
    "ur": "uk",
    "ur": "up",
    "ur": "us",
    "ur": "yr",
    "urbanapoon": "urbanspoon",
    "ure": "are",
    "ure": "use",
    "urea": "area",
    "urequested": "requested",
    "urgh": "ugh",
    "url": "ur",
    "urs": "us",
    "usa": "us",
    "usa": "usd",
    "usa": "use",
    "usaw": "saw",
    "usb": "us",
    "usb": "use",
    "usc": "us",
    "usc": "use",
    "usd": "us",
    "usd": "use",
    "usd": "used",
    "usee": "see",
    "useers": "users",
    "useflu": "useful",
    "usefull": "useful",
    "useing": "using",
    "uselss": "useless",
    "usem": "use",
    "usen": "use",
    "usename": "username",
    "userd": "users",
    "useres": "users",
    "userful": "useful",
    "userz": "users",
    "usey": "use",
    "usf": "us",
    "usg": "us",
    "usig": "using",
    "usiing": "using",
    "usimg": "using",
    "usinga": "using",
    "usingg": "using",
    "usinng": "using",
    "usinq": "using",
    "usn": "us",
    "usng": "using",
    "usning": "using",
    "uso": "use",
    "usp": "use",
    "usr": "us",
    "usr": "use",
    "usre": "sure",
    "usrs": "users",
    "uss": "us",
    "usses": "uses",
    "ussues": "issues",
    "ust": "just",
    "ustream": "stream",
    "usu": "us",
    "usu": "use",
    "usued": "used",
    "usuers": "users",
    "ut": "at",
    "ut": "but",
    "ut": "it",
    "ut": "out",
    "ut": "rt",
    "ut": "u",
    "ut": "up",
    "uta": "usa",
    "utake": "take",
    "utell": "tell",
    "util": "until",
    "uts": "its",
    "uu": "u",
    "uugh": "ugh",
    "uus": "us",
    "uv": "u",
    "uv": "us",
    "uve": "ive",
    "uw": "uk",
    "uw": "up",
    "ux": "u",
    "ux": "ui",
    "ux": "uk",
    "ux": "up",
    "uy": "u",
    "uy": "up",
    "uyou": "you",
    "uz": "us",
    "va": "a",
    "vaacine": "vaccine",
    "vaca": "vac",
    "vaccaination": "vaccination",
    "vaccanations": "vaccinations",
    "vacccine": "vaccine",
    "vacccines": "vaccines",
    "vaccfine": "vaccine",
    "vaccianted": "vaccinated",
    "vaccicnation": "vaccination",
    "vaccinaded": "vaccinated",
    "vaccinatons": "vaccinations",
    "vaccince": "vaccine",
    "vaccined": "vaccines",
    "vaccinep": "vaccine",
    "vacciness": "vaccines",
    "vaccinez": "vaccine",
    "vaccins": "vaccines",
    "vaccintion": "vaccination",
    "vaccnation": "vaccination",
    "vaccne": "vaccine",
    "vaciine": "vaccine",
    "vacinate": "vaccinate",
    "vacinated": "vaccinated",
    "vacination": "vaccination",
    "vacine": "vaccine",
    "vacines": "vaccines",
    "vack": "back",
    "vacsine": "vaccine",
    "vacvine": "vaccine",
    "vai": "via",
    "valler": "valley",
    "vand": "and",
    "vanna": "wanna",
    "vanuato": "vanuatu",
    "variaty": "variety",
    "varification": "verification",
    "vascine": "vaccine",
    "vaunatu": "vanuatu",
    "vavccination": "vaccination",
    "vave": "wave",
    "vaxine": "vacine",
    "vay": "pay",
    "vb": "mb",
    "vc": "dc",
    "vc": "vs",
    "vcant": "cant",
    "vdeos": "videos",
    "vdo": "do",
    "ve": "be",
    "ve": "e",
    "ve": "ive",
    "ve": "me",
    "ve": "we",
    "veery": "very",
    "vefore": "before",
    "veiw": "view",
    "ven": "even",
    "ver": "ever",
    "ver": "her",
    "ver": "over",
    "verey": "very",
    "verison": "verizon",
    "verison": "version",
    "verizion": "verizon",
    "vero": "very",
    "verry": "very",
    "versiion": "version",
    "versjon": "version",
    "verson": "version",
    "vert": "very",
    "vertual": "virtual",
    "veryone": "everyone",
    "veryt": "very",
    "verzion": "verizon",
    "vesion": "version",
    "veted": "voted",
    "vew": "few",
    "vew": "view",
    "vey": "very",
    "vf": "of",
    "vgood": "good",
    "vha": "via",
    "vhrome": "chrome",
    "vi": "di",
    "vi": "i",
    "viaa": "via",
    "vicitms": "victims",
    "vick": "pick",
    "vick": "sick",
    "victem": "victim",
    "victems": "victims",
    "victimcs": "victims",
    "victin": "victim",
    "viction": "fiction",
    "victoms": "victims",
    "victums": "victims",
    "vid": "aid",
    "vid": "did",
    "vid": "id",
    "vid": "kid",
    "vid": "rid",
    "vid": "via",
    "videeo": "video",
    "videl": "video",
    "videoo": "video",
    "videot": "video",
    "vidio": "video",
    "vidjeos": "videos",
    "vidoe": "video",
    "vidoes": "videos",
    "vids": "bids",
    "vids": "kids",
    "viedo": "video",
    "viet": "diet",
    "vieww": "view",
    "vifeo": "video",
    "vii": "wii",
    "vil": "via",
    "vill": "will",
    "vimeo": "video",
    "vin": "in",
    "vioce": "voice",
    "violatd": "violated",
    "vip": "tip",
    "vip": "via",
    "vip": "voip",
    "virsus": "virus",
    "virtural": "virtual",
    "viruse": "virus",
    "vis": "is",
    "vist": "visit",
    "vistit": "visit",
    "vistors": "visitors",
    "vit": "it",
    "vitaman": "vitamin",
    "vitaminc": "vitamin",
    "vite": "vote",
    "vitim": "victim",
    "vitimin": "vitamin",
    "vius": "virus",
    "viz": "via",
    "vknow": "know",
    "vlick": "click",
    "vlog": "blog",
    "vm": "am",
    "vm": "im",
    "vm": "vs",
    "vmail": "gmail",
    "vmail": "mail",
    "vms": "mms",
    "vn": "an",
    "vneed": "need",
    "vo": "go",
    "vo": "to",
    "vocie": "voice",
    "vodafine": "vodafone",
    "vodfone": "vodafone",
    "voer": "over",
    "vogage": "vonage",
    "voicd": "voice",
    "voicemall": "voicemail",
    "voive": "voice",
    "volkswagon": "volkswagen",
    "vollyball": "volleyball",
    "volp": "voip",
    "von": "on",
    "vonamge": "vonage",
    "vonder": "wonder",
    "vonnage": "vonage",
    "voo": "too",
    "vooice": "voice",
    "vop": "top",
    "vor": "for",
    "vore": "vote",
    "vorking": "working",
    "vou": "you",
    "vouce": "voice",
    "vradio": "radio",
    "vrs": "vs",
    "vry": "very",
    "vs": "as",
    "vs": "is",
    "vs": "os",
    "vt": "at",
    "vt": "it",
    "vto": "to",
    "vuew": "view",
    "vurtual": "virtual",
    "vury": "very",
    "vwallpaper": "wallpaper",
    "vwas": "was",
    "vwave": "wave",
    "vwpwebhost": "wpwebhost",
    "vy": "my",
    "vz": "vs",
    "vza": "via",
    "wa": "a",
    "wa": "w",
    "wa": "we",
    "waa": "was",
    "waait": "wait",
    "waaiting": "waiting",
    "waanna": "wanna",
    "waant": "want",
    "waas": "was",
    "waat": "what",
    "waats": "whats",
    "waave": "wave",
    "waay": "way",
    "wabble": "wobble",
    "wabe": "wave",
    "wabt": "want",
    "wac": "war",
    "wace": "wave",
    "wach": "wash",
    "wach": "watch",
    "wached": "watched",
    "waching": "watching",
    "wacked": "walked",
    "wackey": "wacky",
    "wacthing": "watching",
    "wae": "was",
    "wae": "wave",
    "waether": "weather",
    "waether": "whether",
    "waev": "wave",
    "wafe": "wave",
    "wah": "was",
    "wah": "way",
    "waht": "what",
    "wahtever": "whatever",
    "wai": "was",
    "wai": "wii",
    "waiing": "waiting",
    "wainting": "waiting",
    "waiste": "waste",
    "waisted": "wasted",
    "waite": "write",
    "waiti": "wait",
    "waitig": "waiting",
    "waitimng": "waiting",
    "waitinf": "waiting",
    "waitn": "wait",
    "waitng": "waiting",
    "waitning": "waiting",
    "waitt": "wait",
    "waitz": "wait",
    "waj": "way",
    "wak": "way",
    "waker": "water",
    "waku": "wake",
    "wal": "wall",
    "walching": "watching",
    "walfram": "wolfram",
    "walkd": "walked",
    "wallgreens": "walgreens",
    "wallppers": "wallpapers",
    "walpaper": "wallpaper",
    "walt": "walk",
    "wana": "wanna",
    "wana": "want",
    "wanan": "wanna",
    "wanetd": "wanted",
    "wang": "want",
    "wann": "want",
    "wannaa": "wanna",
    "wannah": "wanna",
    "wanne": "wanna",
    "wanned": "wanted",
    "wannna": "wanna",
    "wannt": "want",
    "wanst": "want",
    "wanta": "wanna",
    "wanta": "want",
    "wantd": "want",
    "wantd": "wants",
    "wantn": "want",
    "wanto": "want",
    "wantr": "want",
    "wantt": "want",
    "wanty": "want",
    "wantz": "want",
    "wany": "any",
    "wanz": "want",
    "waoit": "wait",
    "warefare": "warfare",
    "warewolf": "werewolf",
    "warnung": "warning",
    "warrenty": "warranty",
    "wasent": "wasnt",
    "washi": "wash",
    "washingt": "washing",
    "wasn": "was",
    "wasnt": "want",
    "wass": "was",
    "wastle": "waste",
    "wasx": "was",
    "wasy": "easy",
    "wasy": "ways",
    "wasys": "ways",
    "wasz": "was",
    "wat": "at",
    "wat": "want",
    "wat": "was",
    "wat": "way",
    "wat": "what",
    "watchd": "watched",
    "watchhing": "watching",
    "watchig": "watching",
    "watchimg": "watching",
    "watchingg": "watching",
    "watchn": "watch",
    "watchted": "watched",
    "watcing": "watching",
    "wate": "hate",
    "wate": "wave",
    "wated": "wanted",
    "watever": "whatever",
    "wath": "watch",
    "wath": "with",
    "watiching": "watching",
    "wating": "waiting",
    "wating": "wanting",
    "watned": "wanted",
    "wats": "was",
    "wats": "whats",
    "watter": "water",
    "wav": "was",
    "wav": "way",
    "wava": "wave",
    "wavd": "wave",
    "wavebord": "waveboard",
    "waven": "wave",
    "wavev": "wave",
    "wavew": "wave",
    "wavey": "wave",
    "wavez": "wave",
    "wavie": "wave",
    "wavte": "wave",
    "wavv": "wave",
    "wavve": "wave",
    "wavves": "waves",
    "wavw": "wave",
    "waw": "way",
    "wawe": "wave",
    "wawes": "waves",
    "wayy": "way",
    "waz": "was",
    "waz": "way",
    "waze": "wave",
    "wb": "bb",
    "wb": "we",
    "wb": "web",
    "wbsite": "website",
    "wci": "wii",
    "wd": "w",
    "wd": "we",
    "wd": "xd",
    "wdi": "wii",
    "weae": "wear",
    "weally": "really",
    "weatbher": "weather",
    "webb": "web",
    "webding": "wedding",
    "webiste": "website",
    "webmastr": "webmaster",
    "webmatser": "webmaster",
    "webstie": "website",
    "weee": "wee",
    "weee": "week",
    "weeek": "week",
    "weeekend": "weekend",
    "weeeks": "weeks",
    "weekendo": "weekend",
    "weekened": "weekend",
    "weekk": "week",
    "weeknd": "weekend",
    "weet": "tweet",
    "weet": "week",
    "weill": "will",
    "weired": "weird",
    "weith": "with",
    "wek": "week",
    "wel": "web",
    "wel": "well",
    "wellcome": "welcome",
    "welll": "well",
    "wellz": "well",
    "welome": "welcome",
    "welp": "well",
    "wennt": "went",
    "wents": "wants",
    "wentz": "went",
    "weorks": "works",
    "wer": "war",
    "wer": "we",
    "wer": "wear",
    "werd": "were",
    "werid": "weird",
    "werk": "work",
    "werking": "working",
    "werks": "works",
    "werre": "were",
    "wesite": "website",
    "weste": "waste",
    "weve": "wave",
    "wf": "of",
    "wf": "wtf",
    "wft": "wtf",
    "wgat": "wat",
    "wgat": "what",
    "wgb": "web",
    "wgich": "which",
    "wh": "we",
    "wha": "who",
    "wha": "why",
    "whaat": "what",
    "whaever": "whatever",
    "whaf": "what",
    "whah": "what",
    "whan": "what",
    "whan": "when",
    "whant": "want",
    "whant": "what",
    "whar": "what",
    "whare": "where",
    "whart": "what",
    "whas": "has",
    "whas": "was",
    "whas": "whats",
    "whata": "what",
    "whatb": "what",
    "whatch": "watch",
    "whatching": "watching",
    "whatd": "what",
    "whateer": "whatever",
    "whatevr": "whatever",
    "whati": "what",
    "whats": "thats",
    "whatt": "what",
    "whatts": "whats",
    "whatwver": "whatever",
    "whaty": "what",
    "whatz": "what",
    "whatz": "whats",
    "whay": "what",
    "whay": "why",
    "whch": "which",
    "whe": "the",
    "whe": "we",
    "whe": "who",
    "wheather": "weather",
    "wheck": "check",
    "whee": "when",
    "whee": "where",
    "whem": "when",
    "wheni": "when",
    "whenn": "when",
    "whent": "went",
    "wheny": "when",
    "wher": "her",
    "wher": "when",
    "wherr": "where",
    "wheter": "whether",
    "whew": "when",
    "whick": "which",
    "whiel": "while",
    "whiich": "which",
    "whike": "while",
    "whill": "will",
    "whille": "while",
    "whilw": "while",
    "whish": "which",
    "whish": "wish",
    "whitch": "which",
    "whith": "which",
    "whith": "with",
    "whithout": "without",
    "whle": "while",
    "whle": "whole",
    "whn": "when",
    "whn": "why",
    "whnt": "what",
    "whod": "who",
    "whoo": "who",
    "whoo": "woo",
    "whould": "should",
    "whould": "would",
    "whow": "how",
    "whow": "wow",
    "whr": "why",
    "whre": "where",
    "whrn": "when",
    "whst": "what",
    "wht": "what",
    "wht": "who",
    "wht": "why",
    "wht": "wit",
    "whta": "what",
    "whtatever": "whatever",
    "whtever": "whatever",
    "whth": "with",
    "whther": "whether",
    "whts": "whats",
    "whut": "what",
    "whuts": "whats",
    "whwn": "when",
    "whyd": "why",
    "whyh": "why",
    "whyy": "why",
    "wi": "i",
    "wi": "w",
    "wi": "wii",
    "wi": "wv",
    "wiat": "wait",
    "wiating": "waiting",
    "wibi": "wii",
    "wic": "wii",
    "wich": "which",
    "wich": "wish",
    "wich": "with",
    "wid": "did",
    "wid": "wild",
    "wid": "win",
    "wid": "wit",
    "widespead": "widespread",
    "wie": "win",
    "wieght": "weight",
    "wierd": "weird",
    "wiew": "view",
    "wif": "if",
    "wif": "wii",
    "wif": "win",
    "wif": "wit",
    "wifey": "wife",
    "wifi": "wii",
    "wih": "wii",
    "wih": "win",
    "wih": "with",
    "wihout": "without",
    "wiht": "with",
    "wii": "wifi",
    "wii": "win",
    "wii": "wit",
    "wiife": "wife",
    "wiig": "wii",
    "wiii": "wii",
    "wiil": "will",
    "wiill": "will",
    "wiin": "win",
    "wiit": "wit",
    "wiith": "with",
    "wiji": "wii",
    "wike": "like",
    "wike": "woke",
    "wiki": "wifi",
    "wiki": "wii",
    "wikth": "with",
    "wil": "wii",
    "wil": "will",
    "wil": "win",
    "wiling": "willing",
    "wilk": "will",
    "williamx": "williams",
    "willl": "will",
    "willling": "willing",
    "willy": "will",
    "wimdow": "window",
    "winder": "winner",
    "winder": "wonder",
    "windown": "window",
    "wining": "winning",
    "winnning": "winning",
    "winnser": "winner",
    "winodws": "windows",
    "wint": "went",
    "wioth": "with",
    "wip": "wii",
    "wip": "win",
    "wiphone": "iphone",
    "wirh": "with",
    "wirte": "write",
    "wirth": "with",
    "wis": "wii",
    "wisdespread": "widespread",
    "wishh": "wish",
    "wishn": "wish",
    "wisi": "wish",
    "wita": "with",
    "witd": "with",
    "witha": "with",
    "withb": "with",
    "withen": "within",
    "withh": "with",
    "withi": "with",
    "withing": "within",
    "withoyt": "without",
    "witht": "with",
    "withu": "with",
    "witih": "with",
    "witj": "with",
    "witm": "with",
    "witout": "without",
    "witrhout": "without",
    "witter": "twitter",
    "wittering": "twittering",
    "wittle": "little",
    "wity": "with",
    "witz": "with",
    "wiull": "will",
    "wiuth": "with",
    "wiv": "wii",
    "wiv": "win",
    "wiv": "wit",
    "wive": "wave",
    "wixh": "with",
    "wiz": "wii",
    "wizh": "wish",
    "wjhat": "what",
    "wk": "ok",
    "wk": "uk",
    "wk": "we",
    "wke": "woke",
    "wks": "was",
    "wlak": "walk",
    "wlakee": "walkee",
    "wlcome": "welcome",
    "wlf": "wtf",
    "wlk": "walk",
    "wll": "will",
    "wlrote": "wrote",
    "wm": "am",
    "wm": "we",
    "wm": "wv",
    "wmore": "more",
    "wnat": "want",
    "wnats": "wants",
    "wnen": "when",
    "wnidows": "windows",
    "wnna": "wanna",
    "wnt": "dnt",
    "wnt": "want",
    "wnt": "went",
    "wnt": "wit",
    "wnt": "wont",
    "wnted": "wanted",
    "wnts": "wants",
    "wny": "why",
    "woant": "want",
    "woant": "wont",
    "wobbble": "wobble",
    "wodering": "wondering",
    "wodner": "wonder",
    "woek": "woke",
    "woeking": "working",
    "woerk": "work",
    "wofram": "wolfram",
    "wohle": "whole",
    "woice": "voice",
    "woild": "would",
    "woith": "with",
    "woiuld": "would",
    "wok": "work",
    "wokee": "woke",
    "woking": "working",
    "wokr": "work",
    "wokring": "working",
    "wokrs": "works",
    "woks": "works",
    "wole": "whole",
    "wolrd": "world",
    "womder": "wonder",
    "womens": "women",
    "womnder": "wonder",
    "wondee": "wonder",
    "wondeful": "wonderful",
    "wondeirng": "wondering",
    "wonderfull": "wonderful",
    "wonderling": "wondering",
    "wonderng": "wondering",
    "wonderr": "wonder",
    "wondes": "wonders",
    "wondr": "wonder",
    "wondreing": "wondering",
    "wondrful": "wonderful",
    "wondring": "wondering",
    "woner": "wonder",
    "wong": "won",
    "wong": "wont",
    "wong": "wrong",
    "wonidering": "wondering",
    "wonly": "only",
    "wonna": "wanna",
    "wonnder": "wonder",
    "wooble": "wobble",
    "wooo": "woo",
    "woop": "woo",
    "wooried": "worried",
    "woorks": "works",
    "wor": "for",
    "worc": "work",
    "wordpresss": "wordpress",
    "worh": "worth",
    "workd": "work",
    "workd": "works",
    "workds": "works",
    "workersl": "workers",
    "workf": "work",
    "workg": "work",
    "workig": "working",
    "workign": "working",
    "workinn": "working",
    "workinq": "working",
    "workk": "work",
    "workn": "work",
    "workn": "works",
    "workss": "works",
    "workth": "worth",
    "worky": "work",
    "worl": "work",
    "worle": "world",
    "worls": "works",
    "worls": "world",
    "wornder": "wonder",
    "worng": "wrong",
    "worring": "working",
    "worrk": "work",
    "worrld": "world",
    "worrried": "worried",
    "worser": "worse",
    "worstt": "worst",
    "worx": "work",
    "wory": "work",
    "wory": "worry",
    "wos": "was",
    "wosh": "wish",
    "wot": "got",
    "wot": "not",
    "wot": "wat",
    "woth": "with",
    "woth": "worth",
    "wothout": "without",
    "wotking": "working",
    "woud": "would",
    "woudl": "would",
    "wouid": "would",
    "woukd": "would",
    "woukld": "would",
    "woulb": "would",
    "woulda": "would",
    "wouldd": "would",
    "wouldnt": "couldnt",
    "wouldt": "would",
    "woulld": "would",
    "woulndt": "wouldnt",
    "woulnt": "wouldnt",
    "woulod": "would",
    "woulsd": "would",
    "wounder": "wonder",
    "woundering": "wondering",
    "wount": "wont",
    "wouold": "would",
    "wouoldnt": "wouldnt",
    "wourth": "worth",
    "wout": "out",
    "wowuld": "would",
    "wp": "up",
    "wp": "we",
    "wpb": "web",
    "wpi": "wii",
    "wpisode": "episode",
    "wpuld": "would",
    "wqe": "we",
    "wqill": "will",
    "wqs": "was",
    "wr": "or",
    "wr": "r",
    "wr": "war",
    "wrd": "word",
    "wre": "are",
    "wre": "were",
    "writte": "write",
    "writting": "writing",
    "wrk": "work",
    "wrkers": "workers",
    "wrking": "working",
    "wrks": "works",
    "wrld": "world",
    "wrng": "wrong",
    "wrning": "warning",
    "wrok": "work",
    "wrold": "world",
    "wrost": "worst",
    "wrst": "worst",
    "wrt": "rt",
    "wrt": "wit",
    "wrth": "with",
    "ws": "as",
    "ws": "is",
    "ws": "was",
    "wsa": "was",
    "wsh": "wish",
    "wsiting": "waiting",
    "wsnt": "want",
    "wssh": "wash",
    "wtaching": "watching",
    "wtb": "wtf",
    "wtc": "wtf",
    "wtch": "watch",
    "wtff": "wtf",
    "wtfh": "wtf",
    "wth": "with",
    "wth": "wtf",
    "wthile": "while",
    "wtih": "with",
    "wtp": "wtf",
    "wts": "its",
    "wts": "was",
    "wuld": "would",
    "wun": "win",
    "wunder": "wonder",
    "wunt": "want",
    "wunt": "wnt",
    "wuold": "would",
    "wurk": "work",
    "wus": "was",
    "wut": "but",
    "wut": "out",
    "wut": "put",
    "wuth": "with",
    "wuts": "cuts",
    "wuts": "puts",
    "wuv": "luv",
    "wuz": "cuz",
    "wvae": "wave",
    "wve": "wave",
    "ww": "we",
    "wwant": "want",
    "wwar": "war",
    "wwe": "we",
    "wwhat": "what",
    "wwhen": "when",
    "wwi": "wii",
    "wwii": "wii",
    "wwith": "with",
    "wy": "my",
    "wy": "way",
    "wy": "why",
    "xa": "a",
    "xan": "can",
    "xbox": "box",
    "xcept": "except",
    "xchange": "change",
    "xcited": "excited",
    "xclusive": "exclusive",
    "xcode": "code",
    "xcuse": "excuse",
    "xd": "ad",
    "xd": "hd",
    "xgps": "gps",
    "xii": "wii",
    "xing": "ping",
    "xk": "uk",
    "xl": "x",
    "xm": "am",
    "xm": "fm",
    "xm": "im",
    "xnd": "and",
    "xo": "so",
    "xo": "to",
    "xome": "come",
    "xos": "os",
    "xp": "ap",
    "xp": "up",
    "xp": "xd",
    "xplain": "explain",
    "xps": "gps",
    "xs": "is",
    "xstand": "stand",
    "xt": "it",
    "xtra": "extra",
    "xx": "x",
    "xx": "xd",
    "xxploring": "exploring",
    "ya": "a",
    "ya": "da",
    "ya": "y",
    "ya": "yr",
    "yaa": "yay",
    "yaay": "yay",
    "yack": "back",
    "yaeh": "yeah",
    "yaho": "yahoo",
    "yahooo": "yahoo",
    "yall": "all",
    "yall": "call",
    "yall": "fall",
    "yall": "hall",
    "yan": "an",
    "yan": "can",
    "yaoo": "yahoo",
    "yar": "yay",
    "yas": "has",
    "yass": "mass",
    "yay": "day",
    "yay": "gay",
    "yay": "may",
    "yay": "pay",
    "yay": "say",
    "yay": "way",
    "yays": "says",
    "yayy": "yay",
    "yds": "ads",
    "yeaa": "yeah",
    "yeaa": "year",
    "yeaah": "yeah",
    "yeahh": "yeah",
    "yeam": "yeah",
    "yeap": "yeah",
    "yearh": "year",
    "yeasterday": "yesterday",
    "yeats": "years",
    "yeay": "yay",
    "yee": "yet",
    "yeh": "yeah",
    "yeh": "yehh",
    "yep": "yea",
    "yep": "yes",
    "yep": "yet",
    "yer": "her",
    "yer": "yea",
    "yer": "year",
    "yer": "yes",
    "yese": "yes",
    "yeseterday": "yesterday",
    "yesh": "yeah",
    "yesh": "yes",
    "yess": "yes",
    "yest": "yes",
    "yest": "yet",
    "yesteday": "yesterday",
    "yesterdayy": "yesterday",
    "yesterrday": "yesterday",
    "yestserday": "yesterday",
    "yesturday": "yesterday",
    "yett": "yet",
    "yetz": "yet",
    "yey": "hey",
    "yey": "yay",
    "yey": "yes",
    "yg": "y",
    "yhe": "the",
    "yhing": "thing",
    "yhink": "think",
    "yhoo": "yahoo",
    "yhu": "you",
    "yi": "i",
    "yim": "sim",
    "yiou": "you",
    "yit": "it",
    "yiu": "you",
    "ym": "im",
    "ym": "my",
    "ymail": "email",
    "ymail": "gmail",
    "yn": "in",
    "yn": "on",
    "yo": "do",
    "yo": "go",
    "yo": "no",
    "yo": "so",
    "yo": "to",
    "yo": "y",
    "yoi": "you",
    "yoiu": "you",
    "yoka": "yoga",
    "yom": "you",
    "yoo": "you",
    "yoou": "you",
    "yoprk": "york",
    "yoqa": "yoga",
    "yor": "for",
    "yor": "you",
    "yor": "your",
    "york": "work",
    "yoru": "your",
    "yot": "you",
    "yotube": "youtube",
    "youa": "you",
    "youc": "you",
    "youd": "you",
    "youe": "you",
    "youe": "your",
    "youg": "you",
    "youh": "you",
    "youh": "your",
    "youi": "you",
    "youj": "you",
    "youl": "you",
    "youn": "your",
    "younce": "pounce",
    "youor": "your",
    "yourelf": "yourself",
    "yourr": "your",
    "yourslef": "yourself",
    "yourt": "your",
    "yous": "your",
    "youself": "yourself",
    "yout": "out",
    "yout": "you",
    "yout": "your",
    "youtbe": "youtube",
    "youtubee": "youtube",
    "youu": "you",
    "youu": "your",
    "youv": "you",
    "youy": "your",
    "youz": "you",
    "yoy": "you",
    "yp": "up",
    "ype": "type",
    "ypu": "you",
    "ypur": "your",
    "yr": "or",
    "yr": "r",
    "yr": "ur",
    "yrd": "yr",
    "yrs": "yes",
    "yrying": "trying",
    "yt": "it",
    "yt": "rt",
    "yt": "yet",
    "ytakin": "takin",
    "ythat": "that",
    "ything": "thing",
    "ytu": "you",
    "yu": "u",
    "yu": "you",
    "yuck": "fuck",
    "yuck": "luck",
    "yuck": "suck",
    "yucky": "lucky",
    "yuo": "you",
    "yuou": "you",
    "yup": "up",
    "yur": "our",
    "yur": "ur",
    "yur": "your",
    "yurns": "turns",
    "yust": "just",
    "yuu": "you",
    "yweet": "tweet",
    "yy": "by",
    "yyou": "you",
    "za": "a",
    "zack": "back",
    "zand": "and",
    "zapp": "app",
    "zbt": "abt",
    "ze": "be",
    "ze": "me",
    "zeland": "zealand",
    "zend": "end",
    "zend": "send",
    "zhe": "the",
    "zi": "i",
    "zillion": "million",
    "zillions": "millions",
    "zilliw": "zillow",
    "zin": "win",
    "zine": "line",
    "ziphone": "iphone",
    "zish": "wish",
    "zit": "it",
    "zm": "am",
    "zo": "so",
    "zombielanda": "zombieland",
    "zomg": "omg",
    "zooz": "zoo",
    "zshare": "share",
    "zune": "tune",
    "zwine": "swine",
}
